@@ -44,6 +44,7 @@ struct _GdaReportEnginePrivate {
 	xmlNodePtr    spec;
 	xmlNodePtr    result;
 	GHashTable   *objects;
+	gchar        *output_dir;
 };
 
 /* properties */
@@ -52,7 +53,8 @@ enum
         PROP_0,
 	PROP_SPEC_NODE,
 	PROP_SPEC_STRING,
-	PROP_SPEC_FILE
+	PROP_SPEC_FILE,
+	PROP_OUTPUT_DIR
 };
 
 static void gda_report_engine_class_init (GdaReportEngineClass *klass);
@@ -92,6 +94,17 @@ gda_report_engine_class_init (GdaReportEngineClass *klass)
 					 g_param_spec_string ("spec-string", NULL, NULL, NULL, G_PARAM_WRITABLE));
 	g_object_class_install_property (object_class, PROP_SPEC_FILE,
 					 g_param_spec_string ("spec-filename", NULL, NULL, NULL, G_PARAM_WRITABLE));
+	/**
+	 * GdaReportEngine::output-directory:
+	 *
+	 * Defines the directory in which any file generated by the report engine will be stored;
+	 * if not specified the current working directory is used.
+	 *
+	 * Since: 5.0.3
+	 */
+	g_object_class_install_property (object_class, PROP_OUTPUT_DIR,
+					 g_param_spec_string ("output-directory", NULL, NULL,
+							      NULL, G_PARAM_WRITABLE | G_PARAM_READABLE));
 }
 
 static void
@@ -99,6 +112,7 @@ gda_report_engine_init (GdaReportEngine *eng, G_GNUC_UNUSED GdaReportEngineClass
 {
 	eng->priv = g_new0 (GdaReportEnginePrivate, 1);
 	eng->priv->objects = g_hash_table_new_full (g_str_hash, g_str_equal, g_free, g_object_unref);
+	eng->priv->output_dir = NULL;
 }
 
 static void
@@ -125,6 +139,8 @@ gda_report_engine_dispose (GObject *object)
 			eng->priv->spec = NULL;
 		}
 
+		g_free (eng->priv->output_dir);
+
 		g_free (eng->priv);
 		eng->priv = NULL;
 	}
@@ -210,6 +226,10 @@ gda_report_engine_set_property (GObject *object,
 			}
 			break;
 		}
+		case PROP_OUTPUT_DIR:
+			g_free (eng->priv->output_dir);
+			eng->priv->output_dir = g_value_dup_string (value);
+			break;
 		default:
 			G_OBJECT_WARN_INVALID_PROPERTY_ID (object, param_id, pspec);
 			break;
@@ -231,6 +251,9 @@ gda_report_engine_get_property (GObject *object,
 		case PROP_SPEC_NODE: 
 			g_value_set_pointer (value, eng->priv->spec);
 			break;
+		case PROP_OUTPUT_DIR:
+			g_value_set_string (value, eng->priv->output_dir);
+			break;
 		default:
 			G_OBJECT_WARN_INVALID_PROPERTY_ID (object, param_id, pspec);
 			break;
@@ -1176,7 +1199,7 @@ gtype_equal (gconstpointer a, gconstpointer b)
  * Converts @value to a string
  */
 static xmlNodePtr
-value_to_node (G_GNUC_UNUSED GdaReportEngine *engine, G_GNUC_UNUSED RunContext *context, const GValue *value, GdaSet *options)
+value_to_node (GdaReportEngine *engine, G_GNUC_UNUSED RunContext *context, const GValue *value, GdaSet *options)
 {
 	xmlNodePtr retnode = NULL;
 	GdaHolder *converter = NULL;
@@ -1236,7 +1259,12 @@ value_to_node (G_GNUC_UNUSED GdaReportEngine *engine, G_GNUC_UNUSED RunContext *
 				if (array[0] && !strcmp (array[0], "richtext")) {
 					if (array[1] && !strcmp (array[1], "docbook")) {
 						retnode = xmlNewNode (NULL, BAD_CAST "para");
-						parse_rich_text_to_docbook (retnode, str);
+						parse_rich_text_to_docbook (engine, retnode, str);
+						converted = TRUE;
+					}
+					else if (array[1] && !strcmp (array[1], "html")) {
+						retnode = xmlNewNode (NULL, BAD_CAST "p");
+						parse_rich_text_to_html (engine, retnode, str);
 						converted = TRUE;
 					}
 				}
