@@ -1,7 +1,6 @@
 /*
- * Copyright (C) 2009 - 2012 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2009 - 2011 Vivien Malerba <malerba@gnome-db.org>
  * Copyright (C) 2010 David King <davidk@openismus.com>
- * Copyright (C) 2011 Murray Cumming <murrayc@murrayc.com>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -20,7 +19,6 @@
  */
 
 #include <libgda/libgda.h>
-#include <glib/gi18n-lib.h>
 #include "gdaui-entry-combo.h"
 #include "gdaui-combo.h"
 #include "gdaui-data-store.h"
@@ -54,6 +52,7 @@ static const GValue   *gdaui_entry_combo_get_ref_value     (GdauiDataEntry *de);
 static void            gdaui_entry_combo_set_value_default (GdauiDataEntry *de, const GValue * value);
 static void            gdaui_entry_combo_set_attributes    (GdauiDataEntry *de, guint attrs, guint mask);
 static GdaValueAttribute gdaui_entry_combo_get_attributes    (GdauiDataEntry *de);
+static gboolean        gdaui_entry_combo_can_expand  (GdauiDataEntry *de, gboolean horiz);
 static void            gdaui_entry_combo_grab_focus        (GdauiDataEntry *de);
 static void            gdaui_entry_combo_set_unknown_color (GdauiDataEntry *de, gdouble red, gdouble green,
 							    gdouble blue, gdouble alpha);
@@ -71,10 +70,10 @@ enum {
  * used.
  */
 typedef struct {
-	GdaSetNode   *node;
-	GValue       *value;
-	GValue       *value_orig;
-	GValue       *value_default;
+	GdaSetNode *node;
+	const GValue       *value;    /* we don't own the value, since it belongs to a GdaDataModel => don't free it */
+	GValue             *value_orig;
+	GValue             *value_default;
 } ComboNode;
 #define COMBO_NODE(x) ((ComboNode*)(x))
 
@@ -143,6 +142,7 @@ gdaui_entry_combo_data_entry_init (GdauiDataEntryIface *iface)
         iface->set_attributes = gdaui_entry_combo_set_attributes;
         iface->get_attributes = gdaui_entry_combo_get_attributes;
         iface->get_handler = NULL;
+        iface->can_expand = gdaui_entry_combo_can_expand;
 	iface->grab_focus = gdaui_entry_combo_grab_focus;
 	iface->set_unknown_color = gdaui_entry_combo_set_unknown_color;
 }
@@ -291,10 +291,10 @@ void _gdaui_entry_combo_construct (GdauiEntryCombo* combo, GdauiSet *paramlist,
 		ComboNode *cnode = g_new0 (ComboNode, 1);
 		
 		cnode->node = GDA_SET_NODE (list->data);
-		cnode->value = NULL;
+		cnode->value = gda_holder_get_value (cnode->node->holder);
 		combo->priv->combo_nodes = g_slist_append (combo->priv->combo_nodes, cnode);
 
-		values = g_slist_append (values, (GValue *) gda_holder_get_value (cnode->node->holder));
+		values = g_slist_append (values, (GValue *) cnode->value);
 		if (gda_holder_get_not_null (cnode->node->holder))
 			null_possible = FALSE;
 	}
@@ -305,24 +305,18 @@ void _gdaui_entry_combo_construct (GdauiEntryCombo* combo, GdauiSet *paramlist,
 					    combo->priv->source->shown_n_cols, 
 					    combo->priv->source->shown_cols_index);
 	g_object_set (G_OBJECT (entry), "as-list", TRUE, NULL);
+	g_signal_connect (G_OBJECT (entry), "changed",
+			  G_CALLBACK (combo_contents_changed_cb), combo);
 
 	gdaui_entry_shell_pack_entry (GDAUI_ENTRY_SHELL (combo), entry);
 	gtk_widget_show (entry);
 	combo->priv->combo_entry = entry;
 
-	if (values) {
-		_gdaui_combo_set_selected_ext (GDAUI_COMBO (entry), values, NULL);
-		gdaui_entry_combo_set_reference_values (combo, values);
-		g_slist_free (values);
-	}
-
+	_gdaui_combo_set_selected_ext (GDAUI_COMBO (entry), values, NULL);
+	g_slist_free (values);
 	gdaui_combo_add_null (GDAUI_COMBO (entry), combo->priv->null_possible);
 
 	combo->priv->data_valid = combo->priv->null_possible ? TRUE : FALSE;
-
-	combo_contents_changed_cb ((GdauiCombo*) entry, combo);
-	g_signal_connect (G_OBJECT (entry), "changed",
-			  G_CALLBACK (combo_contents_changed_cb), combo);
 }
 
 static void
@@ -358,9 +352,12 @@ gdaui_entry_combo_dispose (GObject *object)
 			for (list = combo->priv->combo_nodes; list; list = list->next) {
 				ComboNode *node = COMBO_NODE (list->data);
 
-				gda_value_free (node->value);
-				gda_value_free (node->value_orig);
-				gda_value_free (node->value_default);
+				if (node->value)
+					node->value = NULL; /* don't free that value since we have not copied it */
+				if (node->value_orig)
+					gda_value_free (node->value_orig);
+				if (node->value_default)
+					gda_value_free (node->value_default);
 				g_free (node);
 			}
 			g_slist_free (combo->priv->combo_nodes);
@@ -444,12 +441,9 @@ combo_contents_changed_cb (G_GNUC_UNUSED GdauiCombo *entry, GdauiEntryCombo *com
 		for (list = combo->priv->combo_nodes; list; list = list->next) {
 			ComboNode *node = COMBO_NODE (list->data);
 
-			gda_value_free (node->value);
 			gtk_tree_model_get (model, &iter, node->node->source_column, &(node->value), -1);
-			if (node->value)
-				node->value = gda_value_copy (node->value);
-			/*g_print ("%s (%p): Set Combo Node value to %s (%p)\n", __FUNCTION__, combo, 
-			  node->value ? gda_value_stringify (node->value) : "Null", node->value);*/
+			/*g_print ("%s(): Set Combo Node value to %s\n", __FUNCTION__,
+			  node->value ? gda_value_stringify (node->value) : "Null");*/
 		}
 		
 		g_signal_emit_by_name (G_OBJECT (combo), "status-changed");
@@ -513,11 +507,8 @@ gdaui_entry_combo_set_values (GdauiEntryCombo *combo, GSList *values)
 			/* adjusting the values */
 			for (list = combo->priv->combo_nodes; list; list = list->next) {
 				node = COMBO_NODE (list->data);
-				gda_value_free (node->value);
 				gtk_tree_model_get (model, &iter, node->node->source_column,
 						    &(node->value), -1);
-				if (node->value)
-					node->value = gda_value_copy (node->value);
 			}
 			
 			combo->priv->null_forced = FALSE;
@@ -529,10 +520,8 @@ gdaui_entry_combo_set_values (GdauiEntryCombo *combo, GSList *values)
 	}
 	else  { /* set to NULL */
 		GSList *list;
-		for (list = combo->priv->combo_nodes; list; list = list->next) {
-			gda_value_free (COMBO_NODE (list->data)->value);
+		for (list = combo->priv->combo_nodes; list; list = list->next)
 			COMBO_NODE (list->data)->value = NULL;
-		}
 
 		if (combo->priv->null_possible) {
 			real_combo_block_signals (combo);
@@ -1029,6 +1018,19 @@ gdaui_entry_combo_get_attributes (GdauiDataEntry *iface)
 	return retval;
 }
 
+
+static gboolean
+gdaui_entry_combo_can_expand (GdauiDataEntry *iface, G_GNUC_UNUSED gboolean horiz)
+{
+	GdauiEntryCombo *combo;
+
+	g_return_val_if_fail (iface && GDAUI_IS_ENTRY_COMBO (iface), FALSE);
+	combo = GDAUI_ENTRY_COMBO (iface);
+	g_return_val_if_fail (combo->priv, FALSE);
+
+	return FALSE;
+}
+
 static void
 gdaui_entry_combo_grab_focus (GdauiDataEntry *iface)
 {
