@@ -1,7 +1,6 @@
 /*
- * Copyright (C) 2009 - 2012 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2009 - 2011 Vivien Malerba <malerba@gnome-db.org>
  * Copyright (C) 2010 David King <davidk@openismus.com>
- * Copyright (C) 2011 Murray Cumming <murrayc@murrayc.com>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -60,6 +59,7 @@ static GtkWidget *create_entry (GdauiEntryWrapper *mgwrap);
 static void       real_set_value (GdauiEntryWrapper *mgwrap, const GValue *value);
 static GValue    *real_get_value (GdauiEntryWrapper *mgwrap);
 static void       connect_signals(GdauiEntryWrapper *mgwrap, GCallback modify_cb, GCallback activate_cb);
+static gboolean   can_expand (GdauiEntryWrapper *mgwrap, gboolean horiz);
 static void       set_editable (GdauiEntryWrapper *mgwrap, gboolean editable);
 static void       grab_focus (GdauiEntryWrapper *mgwrap);
 
@@ -138,6 +138,7 @@ gdaui_entry_common_time_class_init (GdauiEntryCommonTimeClass * class)
 	GDAUI_ENTRY_WRAPPER_CLASS (class)->real_set_value = real_set_value;
 	GDAUI_ENTRY_WRAPPER_CLASS (class)->real_get_value = real_get_value;
 	GDAUI_ENTRY_WRAPPER_CLASS (class)->connect_signals = connect_signals;
+	GDAUI_ENTRY_WRAPPER_CLASS (class)->can_expand = can_expand;
 	GDAUI_ENTRY_WRAPPER_CLASS (class)->set_editable = set_editable;
 	GDAUI_ENTRY_WRAPPER_CLASS (class)->grab_focus = grab_focus;
 
@@ -503,6 +504,12 @@ connect_signals (GdauiEntryWrapper *mgwrap, GCallback modify_cb, GCallback activ
 	}
 }
 
+static gboolean
+can_expand (G_GNUC_UNUSED GdauiEntryWrapper *mgwrap, G_GNUC_UNUSED gboolean horiz)
+{
+	return FALSE;
+}
+
 static void
 set_editable (GdauiEntryWrapper *mgwrap, gboolean editable)
 {
@@ -793,7 +800,7 @@ date_day_selected_double_click (G_GNUC_UNUSED GtkCalendar *calendar, GdauiEntryC
 }
 
 
-static gboolean popup_grab_on_window (GtkWidget *widget, guint32 activate_time);
+static gboolean popup_grab_on_window (GdkWindow *window, guint32 activate_time);
 static void position_popup (GdauiEntryCommonTime *mgtim);
 static void
 date_calendar_choose_cb (GtkWidget *button, GdauiEntryCommonTime *mgtim)
@@ -863,7 +870,7 @@ date_calendar_choose_cb (GtkWidget *button, GdauiEntryCommonTime *mgtim)
 
         /* popup window */
         /* Temporarily grab pointer and keyboard, copied from GnomeDateEdit */
-        if (!popup_grab_on_window (button, gtk_get_current_event_time ()))
+        if (!popup_grab_on_window (gtk_widget_get_window (button), gtk_get_current_event_time ()))
                 return;
 
         position_popup (mgtim);
@@ -906,31 +913,22 @@ date_calendar_choose_cb (GtkWidget *button, GdauiEntryCommonTime *mgtim)
 		gtk_window_move (GTK_WINDOW (mgtim->priv->window), root_x, root_y);
 
         gtk_widget_grab_focus (mgtim->priv->date);
-        popup_grab_on_window (mgtim->priv->window,
+        popup_grab_on_window (gtk_widget_get_window (mgtim->priv->window),
                               gtk_get_current_event_time ());
 }
 
 static gboolean
-popup_grab_on_window (GtkWidget *widget, guint32 activate_time)
+popup_grab_on_window (GdkWindow *window, guint32 activate_time)
 {
-	GdkDeviceManager *manager;
-	GdkDevice *pointer;
-	GdkWindow *window;
-	window = gtk_widget_get_window (widget);
-	manager = gdk_display_get_device_manager (gtk_widget_get_display (widget));
-	pointer = gdk_device_manager_get_client_pointer (manager);
-        if (gdk_device_grab (pointer, window, GDK_OWNERSHIP_WINDOW, TRUE,
-			     GDK_BUTTON_PRESS_MASK | GDK_BUTTON_RELEASE_MASK |
-			     GDK_POINTER_MOTION_MASK,
-			     NULL, activate_time) == GDK_GRAB_SUCCESS) {
-		GdkDevice *keyb;
-		keyb = gdk_device_get_associated_device (pointer);
-                if (gdk_device_grab (keyb, window, GDK_OWNERSHIP_WINDOW, TRUE,
-				     GDK_KEY_PRESS_MASK | GDK_KEY_RELEASE_MASK, NULL, activate_time) ==
-		    GDK_GRAB_SUCCESS)
+        if ((gdk_pointer_grab (window, TRUE,
+                               GDK_BUTTON_PRESS_MASK | GDK_BUTTON_RELEASE_MASK |
+                               GDK_POINTER_MOTION_MASK,
+                               NULL, NULL, activate_time) == 0)) {
+                if (gdk_keyboard_grab (window, TRUE,
+                                       activate_time) == 0)
                         return TRUE;
                 else {
-                        gdk_device_ungrab (pointer, activate_time);
+                        gdk_pointer_ungrab (activate_time);
                         return FALSE;
                 }
         }
@@ -945,7 +943,7 @@ position_popup (GdauiEntryCommonTime *mgtim)
         GtkRequisition req_minimum, req_natural;
 
         gtk_widget_get_preferred_size (mgtim->priv->window, &req_minimum,
-				       &req_natural);
+                &req_natural);
 
         gdk_window_get_origin (gtk_widget_get_window (mgtim->priv->date_button), &x, &y);
 	GtkAllocation alloc;
