@@ -149,8 +149,6 @@ gdaui_entry_shell_init (GdauiEntryShell *shell)
 						 "-GtkArrow-arrow-scaling: 0.4;\n"
 						 "margin: 0;\n"
 						 "padding: 0;\n"
-						 "xthickness: 0;\n"
-						 "ythickness: 0;\n"
 						 "border-style: none;\n"
 						 "border-width: 0;\n"
 						 "-GtkButton-default-border: 0;\n"
@@ -478,7 +476,7 @@ gdaui_entry_shell_refresh (GdauiEntryShell *shell)
 
 /**
  * gdaui_entry_shell_set_unknown:
- * @shell: the GdauiEntryShell widget to refresh
+ * @shell: the #GdauiEntryShell widget to refresh
  * @unknown: set to %TRUE if @shell's contents is unavailable and should not be modified
  *
  * Defines if @shell's contents is in an undefined state (shows or hides @shell's contents)
@@ -490,3 +488,24 @@ gdaui_entry_shell_set_unknown (GdauiEntryShell *shell, gboolean unknown)
 
 	widget_embedder_set_valid ((WidgetEmbedder*) shell->priv->embedder, !unknown);
 }
+
+/**
+ * gdaui_entry_shell_set_ucolor:
+ * @shell: a #GdauiEntryShell
+ * @red: the red component of a color
+ * @green: the green component of a color
+ * @blue: the blue component of a color
+ * @alpha: the alpha component of a color
+ *
+ * Defines the color to be used when @de displays an invalid value. Any value not
+ * between 0. and 1. will result in the default hard coded values to be used (grayish).
+ *
+ * Since: 5.0.3
+ */
+void
+gdaui_entry_shell_set_ucolor (GdauiEntryShell *shell, gdouble red, gdouble green,
+			      gdouble blue, gdouble alpha)
+{
+	g_return_if_fail (GDAUI_IS_ENTRY_SHELL (shell));
+	widget_embedder_set_ucolor ((WidgetEmbedder*) shell->priv->embedder, red, green, blue, alpha);
+}
