@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2009 - 2011 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2009 - 2010 Vivien Malerba <malerba@gnome-db.org>
  * Copyright (C) 2010 David King <davidk@openismus.com>
  *
  * This library is free software; you can redistribute it and/or
@@ -276,38 +276,20 @@ gdaui_numeric_entry_set_property (GObject *object,
                         entry->priv->nb_decimals = g_value_get_uint (value);
                         break;
                 case PROP_DECIMAL_SEP: {
-			gchar sep;
-#if GLIB_CHECK_VERSION(2,32,0)
-                        sep = (gchar) g_value_get_schar (value);
-#else
-                        sep = g_value_get_char (value);
-#endif
+                        gchar sep = g_value_get_char (value);
                         if ((sep == 0) || (sep == '+') || (sep == '-'))
                                 g_warning (_("Decimal separator cannot be the '%c' character"), sep ? sep : '0');
                         else {
-#if GLIB_CHECK_VERSION(2,32,0)
-                                entry->priv->decimal_sep = (gchar) g_value_get_schar (value);
-#else
-				entry->priv->decimal_sep = g_value_get_char (value);
-#endif
+                                entry->priv->decimal_sep = g_value_get_char (value);
                         }
                         break;
                 }
                 case PROP_THOUSANDS_SEP: {
-			gchar sep;
-#if GLIB_CHECK_VERSION(2,32,0)
-                        sep = (gchar) g_value_get_schar (value);
-#else
-                        sep = g_value_get_char (value);
-#endif
+                        gchar sep = g_value_get_char (value);
                         if ((sep == '+') || (sep == '-') || (sep == '_'))
                                 g_warning (_("Decimal thousands cannot be the '%c' character"), sep);
                         else {
-#if GLIB_CHECK_VERSION(2,32,0)
-                                entry->priv->thousands_sep = (gchar) g_value_get_schar (value);
-#else
-				entry->priv->thousands_sep = g_value_get_char (value);
-#endif
+                                entry->priv->thousands_sep = g_value_get_char (value);
                         }
                         break;
                 }
@@ -338,18 +320,10 @@ gdaui_numeric_entry_get_property (GObject *object,
                         g_value_set_uint (value, entry->priv->nb_decimals);
                         break;
                 case PROP_DECIMAL_SEP:
-#if GLIB_CHECK_VERSION(2,32,0)
-                        g_value_set_schar (value, (gint8) entry->priv->decimal_sep);
-#else
                         g_value_set_char (value, entry->priv->decimal_sep);
-#endif
                         break;
                 case PROP_THOUSANDS_SEP:
-#if GLIB_CHECK_VERSION(2,32,0)
-                        g_value_set_schar (value, (gint8) entry->priv->thousands_sep);
-#else
                         g_value_set_char (value, entry->priv->thousands_sep);
-#endif
                         break;
                 default:
                         G_OBJECT_WARN_INVALID_PROPERTY_ID (object, param_id, pspec);
