@@ -54,10 +54,6 @@ static void gdaui_combo_get_property (GObject *object,
 static void gdaui_combo_dispose      (GObject *object);
 static void gdaui_combo_finalize     (GObject *object);
 
-static void gdaui_combo_get_preferred_width (GtkWidget *widget,
-					     gint *minimum_size,
-					     gint *natural_size);
-
 /* GdauiDataSelector interface */
 static void              gdaui_combo_selector_init (GdauiDataSelectorIface *iface);
 static GdaDataModel     *combo_selector_get_model (GdauiDataSelector *iface);
@@ -76,6 +72,7 @@ enum {
 
 /* get a pointer to the parents to be able to call their destructor */
 static GObjectClass *parent_class = NULL;
+static GtkCssProvider *css_provider = NULL;
 
 /*
  * GdauiCombo class implementation
@@ -124,8 +121,6 @@ gdaui_combo_class_init (GdauiComboClass *klass)
 	object_class->dispose = gdaui_combo_dispose;
 	object_class->finalize = gdaui_combo_finalize;
 
-	GTK_WIDGET_CLASS (klass)->get_preferred_width = gdaui_combo_get_preferred_width;
-
 	/* add class properties */
 	g_object_class_install_property (object_class, PROP_MODEL,
 					 g_param_spec_object ("model", _("The data model to display"), NULL, 
@@ -165,6 +160,18 @@ gdaui_combo_init (GdauiCombo *combo, G_GNUC_UNUSED GdauiComboClass *klass)
 	gtk_combo_box_set_wrap_width (GTK_COMBO_BOX (combo), 0);
 	combo->priv->changed_id = g_signal_connect (combo, "changed",
 						    G_CALLBACK (selection_changed_cb), NULL);
+
+	if (!css_provider) {
+		css_provider = gtk_css_provider_new ();
+		gtk_css_provider_load_from_data (css_provider,
+						 "#gdaui-combo-as-list {\n"
+						 "-GtkComboBox-appears-as-list : 1;\n"
+						 "-GtkComboBox-arrow-size : 5}",
+						 -1, NULL);
+	}
+	gtk_style_context_add_provider (gtk_widget_get_style_context ((GtkWidget*) combo),
+					GTK_STYLE_PROVIDER (css_provider),
+					GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
 }
 
 static void
@@ -211,16 +218,10 @@ gdaui_combo_set_property (GObject *object,
 				       0, NULL);
 		break;
 	case PROP_AS_LIST: {
-		GtkStyleContext *style;
-		style = gtk_widget_get_style_context (GTK_WIDGET (combo));
-		if (g_value_get_boolean (value)) {
-			gtk_style_context_remove_class (style, "gdaui-combo-normal");
-			gtk_style_context_add_class (style, "gdaui-combo-as-list");
-		}
-		else {
-			gtk_style_context_remove_class (style, "gdaui-combo-as-list");
-			gtk_style_context_add_class (style, "gdaui-combo-normal");
-		}
+		if (g_value_get_boolean (value))
+			gtk_widget_set_name ((GtkWidget*) combo, "gdaui-combo-as-list");
+		else
+			gtk_widget_set_name ((GtkWidget*) combo, NULL);
 		break;
 	}
 	default :
@@ -255,19 +256,6 @@ gdaui_combo_get_property (GObject *object,
 	}
 }
 
-static void
-gdaui_combo_get_preferred_width (GtkWidget *widget,
-				 gint *minimum_size,
-				 gint *natural_size)
-{
-#define MINSIZE 50
-	GTK_WIDGET_CLASS (parent_class)->get_preferred_width (widget, minimum_size, natural_size);
-	if (minimum_size && (*minimum_size > MINSIZE))
-		*minimum_size = MINSIZE;
-	if (natural_size && (*natural_size > MINSIZE))
-		*natural_size = MINSIZE;
-}
-
 static void
 gdaui_combo_dispose (GObject *object)
 {
