@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2009 Bas Driessen <bas.driessen@xobas.com>
- * Copyright (C) 2009 - 2012 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2009 - 2010 Vivien Malerba <malerba@gnome-db.org>
  * Copyright (C) 2010 David King <davidk@openismus.com>
  *
  * This library is free software; you can redistribute it and/or
@@ -29,7 +29,6 @@ enum {
 	STATUS_CHANGED,
 	CONTENTS_VALID,
 	EXPAND_CHANGED,
-	VALIDATE,
 	LAST_SIGNAL
 };
 
@@ -65,7 +64,6 @@ gdaui_data_entry_get_type (void)
 		};
 
 		type = g_type_register_static (G_TYPE_INTERFACE, "GdauiDataEntry", &info, 0);
-		g_type_interface_add_prerequisite (type, GTK_TYPE_WIDGET);
 	}
 	return type;
 }
@@ -120,19 +118,6 @@ gdaui_data_entry_iface_init (gpointer g_class)
 				      NULL, NULL,
 				      _gdaui_marshal_VOID__VOID,
 				      G_TYPE_NONE, 0);
-		/**
-		 * GdauiDataEntry::contents-valid: (skip)
-		 * @model: the #GdauiDataEntry
-		 * @error: a #GError to set erros to or NULL
-		 *
-		 * Gets emitted when data entered to the #GdaDataEntry widget must be validated.
-		 *
-		 * For bindings use #gdaui_data_entry_validate function.
-		 *
-		 * Returns: TRUE when the data was successfull validated, FALSE otherwise.
-		 *
-		 * Deprecated: 5.2.0
-		 */
 		gdaui_data_entry_signals[CONTENTS_VALID] =
 			g_signal_new ("contents-valid",
 				      GDAUI_TYPE_DATA_ENTRY,
@@ -244,7 +229,7 @@ gdaui_data_entry_get_value (GdauiDataEntry *de)
 }
 
 /**
- * gdaui_data_entry_content_is_valid: (skip)
+ * gdaui_data_entry_content_is_valid:
  * @de: a #GtkWidget object which implements the #GdauiDataEntry interface
  * @error: (allow-none): a place to store an error, or %NULL
  *
@@ -257,8 +242,6 @@ gdaui_data_entry_get_value (GdauiDataEntry *de)
  * Returns: TRUE if @de's contents is valid
  *
  * Since: 4.2
- *
- * Deprecated: 5.2
  */
 gboolean
 gdaui_data_entry_content_is_valid (GdauiDataEntry *de, GError **error)
@@ -270,29 +253,6 @@ gdaui_data_entry_content_is_valid (GdauiDataEntry *de, GError **error)
 	return is_valid;
 }
 
-/**
- * gdaui_data_entry_validate:
- * @de: a #GtkWidget object which implements the #GdauiDataEntry interface
- * @error: (allow-none): a place to store an erro, or %NULL
- *
- * Tests the validity of @de's contents. This function must be overrided by implementators.
- *
- * Default implementation returns TRUE.
- *
- * Returns: TRUE if @de's contents is valid
- *
- * Since: 5.2
- */
-gboolean
-gdaui_data_entry_validate (GdauiDataEntry *de, GError **error)
-{
-	g_return_val_if_fail (GDAUI_IS_DATA_ENTRY (de), FALSE);
-
-	if (GDAUI_DATA_ENTRY_GET_IFACE (de)->validate)
-		(GDAUI_DATA_ENTRY_GET_IFACE (de)->validate) (de, error);
-	else
-		return TRUE;
-}
 
 /**
  * gdaui_data_entry_set_reference_value:
@@ -455,8 +415,6 @@ gdaui_data_entry_get_handler (GdauiDataEntry *de)
  * Returns: %TRUE if the widget requires expansion
  *
  * Since: 4.2
- *
- * Deprecated: 5.2: use the GtkWidget::hexpand, GtkWidget::wexpand or GtkWidget::expand properties
  */
 gboolean
 gdaui_data_entry_can_expand (GdauiDataEntry *de, gboolean horiz)
@@ -464,12 +422,9 @@ gdaui_data_entry_can_expand (GdauiDataEntry *de, gboolean horiz)
 	g_return_val_if_fail (GDAUI_IS_DATA_ENTRY (de), FALSE);
 
 	if (GDAUI_DATA_ENTRY_GET_IFACE (de)->can_expand)
-		g_warning ("The GdauiDataEntry::can_expand virtual method is not used anymore, "
-			   "please clean your code");
-	if (horiz)
-		return gtk_widget_get_hexpand ((GtkWidget*) de);
+		return (GDAUI_DATA_ENTRY_GET_IFACE (de)->can_expand) (de, horiz);
 	else
-		return gtk_widget_get_vexpand ((GtkWidget*) de);
+		return FALSE;
 }
 
 /**
