@@ -1,6 +1,5 @@
 /*
- * Copyright (C) 2010 - 2012 Vivien Malerba <malerba@gnome-db.org>
- * Copyright (C) 2011 Murray Cumming <murrayc@murrayc.com>
+ * Copyright (C) 2010 - 2011 Vivien Malerba <malerba@gnome-db.org>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -70,6 +69,7 @@ typedef struct {
 struct _GdauiRtEditorPriv
 {
 	GtkTextView    *textview;
+	GtkAdjustment  *vadj;
 	gdouble         vadj_value;
 	GtkTextBuffer  *textbuffer;
 	GtkWidget      *toolbar;
@@ -89,6 +89,7 @@ struct _GdauiRtEditorPriv
 
 /* get a pointer to the parents to be able to call their destructor */
 static GObjectClass *parent_class = NULL;
+static GtkCssProvider *css_provider = NULL;
 static gchar *help_str=N_("\"\"\"= Title level 1 =\n"
 			  "== Title level 2 ==\n"
 			  "\"\"\"= Title level 1 =\n"
@@ -280,13 +281,12 @@ gdaui_rt_editor_class_init (GdauiRtEditorClass *klass)
 static void
 text_view_realized_cb (GtkWidget *tv, GdauiRtEditor *rte)
 {
+	GdkWindow *win;
+	GtkStyle *style;
 	if (rte->priv->no_background && ! gtk_text_view_get_editable (GTK_TEXT_VIEW (tv))) {
-		GdkWindow *win;
-		GtkStyleContext* style_context = gtk_widget_get_style_context (tv);
-                GdkRGBA color;
 		win = gtk_text_view_get_window (GTK_TEXT_VIEW (tv), GTK_TEXT_WINDOW_TEXT);
-                gtk_style_context_get_background_color (style_context, GTK_STATE_FLAG_NORMAL, &color);
-		gdk_window_set_background_rgba (win, &color);
+		style = gtk_widget_get_style (tv);
+		gdk_window_set_background (win, &(style->bg [GTK_STATE_NORMAL]));
 	}
 }
 
@@ -301,12 +301,14 @@ static void
 gdaui_rt_editor_init (GdauiRtEditor *rte)
 {
 	GtkWidget *sw, *textview, *toolbar;
+	GtkAdjustment *adj;
 
 	gtk_orientable_set_orientation (GTK_ORIENTABLE (rte), GTK_ORIENTATION_VERTICAL);
 
 	sw = gtk_scrolled_window_new (NULL, NULL);
 	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (sw),
 					GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
+	adj = gtk_scrolled_window_get_vadjustment (GTK_SCROLLED_WINDOW (sw));
 	gtk_box_pack_end (GTK_BOX (rte), sw, TRUE, TRUE, 0);
 
 	textview = gtk_text_view_new ();
@@ -319,6 +321,7 @@ gdaui_rt_editor_init (GdauiRtEditor *rte)
 
 	rte->priv = g_new0 (GdauiRtEditorPriv, 1);
 	rte->priv->sw = sw;
+	rte->priv->vadj = adj;
 	rte->priv->vadj_value = 0.;
 	rte->priv->saved_for_help = NULL;
 	rte->priv->enable_changed_signal = TRUE;
@@ -403,6 +406,18 @@ gdaui_rt_editor_init (GdauiRtEditor *rte)
 
 	/* toolbar */
 	toolbar = gtk_ui_manager_get_widget (rte->priv->uimanager, "/ToolBar");
+
+	if (!css_provider) {
+		css_provider = gtk_css_provider_new ();
+		gtk_css_provider_load_from_data (css_provider,
+						 "* {\n"
+						 "-GtkToolbar-shadow-type : none}",
+						 -1, NULL);
+	}
+	gtk_style_context_add_provider (gtk_widget_get_style_context ((GtkWidget*) toolbar),
+					GTK_STYLE_PROVIDER (css_provider),
+					GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
+
 	gtk_toolbar_set_icon_size (GTK_TOOLBAR (toolbar), GTK_ICON_SIZE_MENU);
 	rte->priv->toolbar = toolbar;
 	gtk_box_pack_end (GTK_BOX (rte), toolbar, FALSE, FALSE, 0);
@@ -1260,7 +1275,7 @@ spaces_since_start_of_line (GtkTextIter *iter)
 }
 
 /**
- * get_markup_token:
+ * get_markup_token
  * @iter: starting position
  * @out_nb_spaces_before: a place to set the value returned by spaces_since_start_of_line() if called
  * @out_end: (allow-none): place to put the last used position, or %NULL
@@ -1468,7 +1483,7 @@ get_markup_token (GtkTextIter *iter, gint *out_nb_spaces_before, GtkTextIter *ou
 }
 
 /**
- * get_char_at_iter:
+ * get_char_at_iter
  * @iter: an iter
  * @move_forward_first: %TRUE if @iter should be moved forward first
  *
@@ -1537,7 +1552,7 @@ static guint8 *serialize_as_txt2tag (GtkTextBuffer     *register_buffer,
 				     GdauiRtEditor     *editor);
 
 /**
- * gdaui_rt_editor_get_contents:
+ * gdaui_rt_editor_get_contents
  * @editor: a #GdauiRtEditor
  *
  * Get the contents of @editor, using the markup syntax
@@ -1893,7 +1908,7 @@ serialize_as_txt2tag (G_GNUC_UNUSED  GtkTextBuffer *register_buffer,
 
 
 /**
- * gdaui_rt_editor_set_contents:
+ * gdaui_rt_editor_set_contents
  * @editor: a #GdauiRtEditor
  * @markup: the text to set in @editor, using the markup syntax (must be valid UTF-8)
  * @length: length of text in bytes.
@@ -1913,7 +1928,7 @@ gdaui_rt_editor_set_contents (GdauiRtEditor *editor, const gchar *markup, gint l
 }
 
 /**
- * gdaui_rt_editor_set_editable:
+ * gdaui_rt_editor_set_editable
  * @editor: a #GdauiRtEditor
  * @editable: whether it's editable
  *
@@ -1976,20 +1991,14 @@ show_hide_toolbar (GdauiRtEditor *editor)
 
 	if (doshow) {
 		gtk_widget_show (editor->priv->toolbar);
-		if (editor->priv->sw && (editor->priv->vadj_value != 0.)) {
-			GtkAdjustment *adj;	
-			adj = gtk_scrolled_window_get_vadjustment (GTK_SCROLLED_WINDOW (editor->priv->sw));
+		if (editor->priv->vadj_value != 0.) {
 			while (gtk_events_pending ())
 				gtk_main_iteration ();
-			gtk_adjustment_set_value (adj, editor->priv->vadj_value);
+			gtk_adjustment_set_value (editor->priv->vadj, editor->priv->vadj_value);
 		}
 	}
 	else {
-		if (editor->priv->sw) {
-			GtkAdjustment *adj;
-			adj = gtk_scrolled_window_get_vadjustment (GTK_SCROLLED_WINDOW (editor->priv->sw));
-			editor->priv->vadj_value = gtk_adjustment_get_value (adj);
-		}
+		editor->priv->vadj_value = gtk_adjustment_get_value (editor->priv->vadj);
 		gtk_widget_hide (editor->priv->toolbar);
 	}
 
