@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2007 - 2011 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2007 - 2010 Vivien Malerba <malerba@gnome-db.org>
  * Copyright (C) 2010 David King <davidk@openismus.com>
  *
  * This library is free software; you can redistribute it and/or
@@ -46,7 +46,7 @@ static GObjectClass *parent_class = NULL;
  * Object init and finalize
  */
 GType
-_gda_dir_blob_op_get_type (void)
+gda_dir_blob_op_get_type (void)
 {
 	static GType type = 0;
 
@@ -112,10 +112,10 @@ gda_dir_blob_op_finalize (GObject * object)
 }
 
 /**
- * _gda_dir_blob_op_new
+ * gda_dir_blob_op_new
  */
 GdaBlobOp *
-_gda_dir_blob_op_new (const gchar *complete_filename)
+gda_dir_blob_op_new (const gchar *complete_filename)
 {
 	GdaDirBlobOp *pgop;
 
@@ -128,10 +128,10 @@ _gda_dir_blob_op_new (const gchar *complete_filename)
 }
 
 /**
- * _gda_dir_blob_set_filename
+ * gda_dir_blob_set_filename
  */
 void
-_gda_dir_blob_set_filename (GdaDirBlobOp *blob, const gchar *complete_filename)
+gda_dir_blob_set_filename (GdaDirBlobOp *blob, const gchar *complete_filename)
 {
 	g_return_if_fail (GDA_IS_DIR_BLOB_OP (blob));
 	g_return_if_fail (blob->priv);
@@ -142,10 +142,10 @@ _gda_dir_blob_set_filename (GdaDirBlobOp *blob, const gchar *complete_filename)
 }
 
 /**
- * _gda_dir_blob_get_filename
+ * gda_dir_blob_get_filename
  */
 const gchar *
-_gda_dir_blob_get_filename (GdaDirBlobOp *blob)
+gda_dir_blob_get_filename (GdaDirBlobOp *blob)
 {
 	g_return_val_if_fail (GDA_IS_DIR_BLOB_OP (blob), NULL);
 	g_return_val_if_fail (blob->priv, NULL);
@@ -188,7 +188,7 @@ gda_dir_blob_op_read (GdaBlobOp *op, GdaBlob *blob, glong offset, glong size)
 	g_return_val_if_fail (blob, -1);
 
 	/* open file */
-	file = fopen (dirop->priv->complete_filename, "rb"); /* Flawfinder: ignore */
+	file = fopen (dirop->priv->complete_filename, "r"); /* Flawfinder: ignore */
 	if (!file)
 		return -1;
 	
@@ -227,7 +227,7 @@ gda_dir_blob_op_write (GdaBlobOp *op, GdaBlob *blob, glong offset)
 	g_return_val_if_fail (blob, -1);
 
 	/* open file */
-	file = fopen (dirop->priv->complete_filename, "w+b"); /* Flawfinder: ignore */
+	file = fopen (dirop->priv->complete_filename, "w+"); /* Flawfinder: ignore */
 	if (!file)
 		return -1;
 	
@@ -256,7 +256,6 @@ gda_dir_blob_op_write (GdaBlobOp *op, GdaBlob *blob, glong offset)
 			tmp_written = fwrite ((char *) (bin->data), sizeof (guchar), bin->binary_length, file);
 			if (tmp_written < bin->binary_length) {
 				/* error writing stream */
-				fclose (file);
 				gda_blob_free ((gpointer) tmpblob);
 				return -1;
 			}
