@@ -140,9 +140,15 @@ static void lock_notify_changes (void);
 static void unlock_notify_changes (void);
 #endif
 
+#if GLIB_CHECK_VERSION(2,31,7)
+static GRecMutex gda_rmutex;
+#define GDA_CONFIG_LOCK() g_rec_mutex_lock(&gda_rmutex)
+#define GDA_CONFIG_UNLOCK() g_rec_mutex_unlock(&gda_rmutex)
+#else
 static GStaticRecMutex gda_mutex = G_STATIC_REC_MUTEX_INIT;
 #define GDA_CONFIG_LOCK() g_static_rec_mutex_lock(&gda_mutex)
 #define GDA_CONFIG_UNLOCK() g_static_rec_mutex_unlock(&gda_mutex)
+#endif
 
 /* GdaServerProvider for SQLite as a shortcut, available
  * even if the SQLite provider is not installed
@@ -1476,7 +1482,13 @@ gda_config_list_providers (void)
 	GDA_CONFIG_UNLOCK ();
 	return model;
 }
- 
+
+static gint
+internal_provider_sort_func (InternalProvider *a, InternalProvider *b)
+{
+	return strcmp (a->pinfo.id, b->pinfo.id);
+}
+
 static void load_providers_from_dir (const gchar *dirname, gboolean recurs);
 static void
 load_all_providers (void)
@@ -1504,6 +1516,10 @@ load_all_providers (void)
 		_gda_config_sqlite_provider = (GdaServerProvider*) 
 			g_object_new (GDA_TYPE_SQLITE_PROVIDER, NULL);
 	}
+
+	/* sort providers by name */
+	unique_instance->priv->prov_list = g_slist_sort (unique_instance->priv->prov_list,
+							 (GCompareFunc) internal_provider_sort_func);
 }
 
 static InternalProvider *
