@@ -1,6 +1,6 @@
 /*
- * Copyright (C) 2006 - 2011 Murray Cumming <murrayc@murrayc.com>
- * Copyright (C) 2006 - 2012 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2006 - 2008 Murray Cumming <murrayc@murrayc.com>
+ * Copyright (C) 2006 - 2011 Vivien Malerba <malerba@gnome-db.org>
  * Copyright (C) 2007 Brecht Sanders <brecht@edustria.be>
  * Copyright (C) 2009 Bas Driessen <bas.driessen@xobas.com>
  * Copyright (C) 2010 David King <davidk@openismus.com>
@@ -329,6 +329,7 @@ gda_data_model_import_data_model_init (GdaDataModelIface *iface)
 static void
 gda_data_model_import_init (GdaDataModelImport *model, G_GNUC_UNUSED GdaDataModelImportClass *klass)
 {
+	g_return_if_fail (GDA_IS_DATA_MODEL_IMPORT (model));
 	model->priv = g_new0 (GdaDataModelImportPrivate, 1);
 	model->priv->random_access = FALSE; /* cursor mode is the default */
 	model->priv->columns = NULL;
@@ -779,8 +780,8 @@ gda_data_model_import_get_property (GObject *object,
  *      <itemizedlist>
  *         <listitem><para>ENCODING (string): specifies the encoding of the data in the file</para></listitem>
  *         <listitem><para>SEPARATOR (string): specifies the CSV separator (comma as default)</para></listitem>
- *         <listitem><para>QUOTE (string): specifies the character used as quote (double quote as default)</para></listitem>
- *         <listitem><para>NAMES_ON_FIRST_LINE (boolean): consider that the first line of the file contains columns' titles (note that the TITLE_AS_FIRST_LINE option is also accepted as a synonym)</para></listitem>
+ *         <listitem><para>QUOTE (string): specifies the character used to as quote park (double quote as default)</para></listitem>
+ *         <listitem><para>TITLE_AS_FIRST_LINE (boolean): consider that the first line of the file contains columns' titles</para></listitem>
  *         <listitem><para>G_TYPE_&lt;column number&gt; (GType): specifies the type of value expected in column &lt;column number&gt;</para></listitem>
  *      </itemizedlist>
  *   </para></listitem>
@@ -869,8 +870,7 @@ init_csv_import (GdaDataModelImport *model)
 	gint nbcols;
 
 	if (model->priv->options)
-		title_first_line = find_option_as_boolean (model, "NAMES_ON_FIRST_LINE", FALSE) ||
-			find_option_as_boolean (model, "TITLE_AS_FIRST_LINE", FALSE);
+		title_first_line = find_option_as_boolean (model, "TITLE_AS_FIRST_LINE", FALSE);
 
 	g_assert (model->priv->format == FORMAT_CSV);
 
@@ -1971,10 +1971,9 @@ gda_data_model_import_iter_next (GdaDataModel *model, GdaDataModelIter *iter)
 		     plist && vlist;
 		     plist = plist->next, vlist = vlist->next) {
 			GError *lerror = NULL;
-			if (! gda_holder_take_value ((GdaHolder*) plist->data,
-						     (GValue *) vlist->data, &lerror))
+			if (! gda_holder_set_value (GDA_HOLDER (plist->data),
+						    (GValue *) vlist->data, &lerror))
 				gda_holder_force_invalid_e (GDA_HOLDER (plist->data), lerror);
-			vlist->data = NULL;
 		}
 		if (plist || vlist) {
 			if (plist) {
@@ -2042,7 +2041,7 @@ gda_data_model_import_iter_prev (GdaDataModel *model, GdaDataModelIter *iter)
 		     plist && vlist;
 		     plist = plist->next, vlist = vlist->next) {
 			GError *lerror = NULL;
-			if (! gda_holder_set_value ((GdaHolder*) plist->data,
+			if (! gda_holder_set_value (GDA_HOLDER (plist->data),
 						    (GValue *) vlist->data, &lerror))
 				gda_holder_force_invalid_e (GDA_HOLDER (plist->data), lerror);
 		}
