@@ -1,11 +1,10 @@
 /*
  * Copyright (C) 2008 Massimo Cora <maxcvs@email.it>
  * Copyright (C) 2008 - 2011 Murray Cumming <murrayc@murrayc.com>
- * Copyright (C) 2008 - 2012 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2008 - 2011 Vivien Malerba <malerba@gnome-db.org>
  * Copyright (C) 2009 Bas Driessen <bas.driessen@xobas.com>
  * Copyright (C) 2010 David King <davidk@openismus.com>
  * Copyright (C) 2010 Jonh Wendell <jwendell@gnome.org>
- * Copyright (C) 2011 Daniel Espinosa <despinosa@src.gnome.org>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -94,8 +93,7 @@ enum
 	PROP_SOURCE_MODEL,
 	PROP_SOURCE_COLUMN,
 	PROP_GDA_TYPE,
-	PROP_NOT_NULL,
-	PROP_VALIDATE_CHANGES
+	PROP_NOT_NULL
 };
 
 
@@ -122,8 +120,6 @@ struct _GdaHolderPrivate
 	gint             source_col;
 
 	GdaMutex        *mutex;
-
-	gboolean         validate_changes;
 };
 
 /* module error */
@@ -207,7 +203,7 @@ gda_holder_class_init (GdaHolderClass *class)
 	parent_class = g_type_class_peek_parent (class);
 
 	/**
-	 * GdaHolder::source-changed:
+	 * GdaHolder::source-changed
 	 * @holder: the #GdaHolder
 	 * 
 	 * Gets emitted when the data model in which @holder's values should be has changed
@@ -220,7 +216,7 @@ gda_holder_class_init (GdaHolderClass *class)
                               NULL, NULL,
                               _gda_marshal_VOID__VOID, G_TYPE_NONE, 0);
 	/**
-	 * GdaHolder::changed:
+	 * GdaHolder::changed
 	 * @holder: the #GdaHolder
 	 * 
 	 * Gets emitted when @holder's value has changed
@@ -233,7 +229,7 @@ gda_holder_class_init (GdaHolderClass *class)
                               NULL, NULL,
                               _gda_marshal_VOID__VOID, G_TYPE_NONE, 0);
 	/**
-	 * GdaHolder::attribute-changed:
+	 * GdaHolder::attribute-changed
 	 * @holder: the #GdaHolder
 	 * @att_name: attribute's name
 	 * @att_value: attribute's value
@@ -250,7 +246,7 @@ gda_holder_class_init (GdaHolderClass *class)
 			      G_TYPE_STRING, G_TYPE_VALUE);
 
 	/**
-	 * GdaHolder::validate-change:
+	 * GdaHolder::validate-change
 	 * @holder: the object which received the signal
 	 * @new_value: the proposed new value for @holder
 	 * 
@@ -316,18 +312,6 @@ gda_holder_class_init (GdaHolderClass *class)
 							   "with the source-model property",
 							   0, G_MAXINT, 0,
 							   (G_PARAM_READABLE | G_PARAM_WRITABLE)));
-
-	/**
-	 * GdaHolder:validate-changes:
-	 *
-	 * Defines if the "validate-change" signal gets emitted when
-	 * the holder's value changes.
-	 *
-	 * Since: 5.2.0
-	 */
-	g_object_class_install_property (object_class, PROP_VALIDATE_CHANGES,
-					 g_param_spec_boolean ("validate-changes", NULL, "Defines if the validate-change signal is emitted on value change", TRUE,
-							       (G_PARAM_READABLE | G_PARAM_WRITABLE)));
 	
 	/* extra */
 	gda_holder_attributes_manager = gda_attributes_manager_new (TRUE, holder_attribute_set_cb, NULL);
@@ -366,8 +350,6 @@ gda_holder_init (GdaHolder *holder)
 	holder->priv->source_col = 0;
 
 	holder->priv->mutex = gda_mutex_new ();
-
-	holder->priv->validate_changes = TRUE;
 }
 
 /**
@@ -682,9 +664,6 @@ gda_holder_set_property (GObject *object,
 		case PROP_SOURCE_COLUMN:
 			holder->priv->source_col = g_value_get_int (value);
 			break;
-		case PROP_VALIDATE_CHANGES:
-			holder->priv->validate_changes = g_value_get_boolean (value);
-			break;
 		default:
 			G_OBJECT_WARN_INVALID_PROPERTY_ID (object, param_id, pspec);
 			break;
@@ -738,10 +717,7 @@ gda_holder_get_property (GObject *object,
 			break;
 		case PROP_SOURCE_COLUMN:
 			g_value_set_int (value, holder->priv->source_col);
-			break;
-		case PROP_VALIDATE_CHANGES:
-			g_value_set_boolean (value, holder->priv->validate_changes);
-			break;
+			break;	
 		default:
 			G_OBJECT_WARN_INVALID_PROPERTY_ID (object, param_id, pspec);
 			break;
@@ -1062,21 +1038,19 @@ real_gda_holder_set_value (GdaHolder *holder, GValue *value, gboolean do_copy, G
 	}
 
 	/* check if we are allowed to change value */
-	if (holder->priv->validate_changes) {
-		GError *lerror = NULL;
-		g_signal_emit (holder, gda_holder_signals[VALIDATE_CHANGE], 0, value, &lerror);
-		if (lerror) {
-			/* change refused by signal callback */
+	GError *lerror = NULL;
+	g_signal_emit (holder, gda_holder_signals[VALIDATE_CHANGE], 0, value, &lerror);
+	if (lerror) {
+		/* change refused by signal callback */
 #ifdef DEBUG_HOLDER
-			g_print ("Holder change refused %p (ERROR %s)\n", holder,
-				 lerror->message);
+		g_print ("Holder change refused %p (ERROR %s)\n", holder,
+			 lerror->message);
 #endif
-			g_propagate_error (error, lerror);
-			if (!do_copy) 
-				gda_value_free (value);
-			gda_holder_unlock ((GdaLockable*) holder);
-			return FALSE;
-		}
+		g_propagate_error (error, lerror);
+		if (!do_copy) 
+			gda_value_free (value);
+		gda_holder_unlock ((GdaLockable*) holder);
+		return FALSE;
 	}
 
 	/* new valid status */
@@ -1098,10 +1072,10 @@ real_gda_holder_set_value (GdaHolder *holder, GValue *value, gboolean do_copy, G
 			 value && (G_VALUE_TYPE (value) == holder->priv->g_type))
 			holder->priv->default_forced = !gda_value_compare (holder->priv->default_value, value);
 	}
-	GValue att_value = {0};
-	g_value_init (&att_value, G_TYPE_BOOLEAN);
-	g_value_set_boolean (&att_value, holder->priv->default_forced);
-	gda_holder_set_attribute_static (holder, GDA_ATTRIBUTE_IS_DEFAULT, &att_value);
+	GValue *att_value;
+	g_value_set_boolean ((att_value = gda_value_new (G_TYPE_BOOLEAN)), holder->priv->default_forced);
+	gda_holder_set_attribute_static (holder, GDA_ATTRIBUTE_IS_DEFAULT, att_value);
+	gda_value_free (att_value);
 
 	/* real setting of the value */
 	if (holder->priv->full_bind) {
@@ -1212,14 +1186,12 @@ real_gda_holder_set_const_value (GdaHolder *holder, const GValue *value,
 	}
 
 	/* check if we are allowed to change value */
-	if (holder->priv->validate_changes) {
-		GError *lerror = NULL;
-		g_signal_emit (holder, gda_holder_signals[VALIDATE_CHANGE], 0, value, &lerror);
-		if (lerror) {
-			/* change refused by signal callback */
-			g_propagate_error (error, lerror);
-			return NULL;
-		}
+	GError *lerror = NULL;
+	g_signal_emit (holder, gda_holder_signals[VALIDATE_CHANGE], 0, value, &lerror);
+	if (lerror) {
+		/* change refused by signal callback */
+		g_propagate_error (error, lerror);
+		return NULL;
 	}
 
 	/* new valid status */
@@ -1986,7 +1958,7 @@ gda_holder_get_bind (GdaHolder *holder)
  *
  * This method is just a wrapper around the gda_text_to_alphanum() function.
  *
- * Returns: (transfer full): a new string
+ * Returns: a new string
  */
 gchar *
 gda_holder_get_alphanum_id (GdaHolder *holder)
@@ -2028,12 +2000,14 @@ gda_holder_get_attribute (GdaHolder *holder, const gchar *attribute)
  * then the string will not be freed at all).
  *
  * Attributes can have any name, but Libgda proposes some default names, 
- * see <link linkend="libgda-5.0-Attributes-manager.synopsis">this section</link>.
+ * see <link linkend="libgda-40-Attributes-manager.synopsis">this section</link>.
  *
  * For example one would use it as:
  *
- * <code>gda_holder_set_attribute (holder, g_strdup (my_attribute), my_value, g_free);</code>
- * <code>gda_holder_set_attribute (holder, GDA_ATTRIBUTE_NAME, my_value, NULL);</code>
+ * <code>
+ * gda_holder_set_attribute (holder, g_strdup (my_attribute), g_free, my_value);
+ * gda_holder_set_attribute (holder, GDA_ATTRIBUTE_NAME, NULL, my_value);
+ * </code>
  *
  * If there is already an attribute named @attribute set, then its value is replaced with the new value (@value is
  * copied), except if @value is %NULL, in which case the attribute is removed.
