@@ -40,7 +40,8 @@ extern GQuark gda_meta_struct_error_quark (void);
 typedef enum {
 	GDA_META_STRUCT_UNKNOWN_OBJECT_ERROR,
         GDA_META_STRUCT_DUPLICATE_OBJECT_ERROR,
-        GDA_META_STRUCT_INCOHERENCE_ERROR
+        GDA_META_STRUCT_INCOHERENCE_ERROR,
+	GDA_META_STRUCT_XML_ERROR
 } GdaMetaStructError;
 
 
@@ -113,15 +114,19 @@ typedef enum {
 
 /**
  * GdaMetaTable:
- * @columns: list of #GdaMetaTableColumn structures, one for each column in the table
+ * @columns: (element-type Gda.MetaTableColumn): list of #GdaMetaTableColumn structures, one for each column in the table
  * @pk_cols_array: index of the columns part of the primary key for the table (WARNING: columns numbering
  *                 here start at 0)
  * @pk_cols_nb: size of the @pk_cols_array array
- * @reverse_fk_list: list of #GdaMetaTableForeignKey where the referenced table is this table
- * @fk_list: list of #GdaMetaTableForeignKey for this table
+ * @reverse_fk_list: (element-type Gda.MetaTableForeignKey): list of #GdaMetaTableForeignKey where the referenced table is this table
+ * @fk_list: (element-type Gda.MetaTableForeignKey): list of #GdaMetaTableForeignKey for this table
  *
  * This structure specifies a #GdaMetaDbObject to represent a table's specific attributes,
  * its contents must not be modified.
+ *
+ * Note that in some cases, the columns cannot be determined for views, and in this case the
+ * @columns will be %NULL (this can be the case for example with SQLite where a view
+ * uses a function which is not natively provided by SQLite.
  */
 typedef struct {
 	/*< public >*/
@@ -177,7 +182,7 @@ typedef struct {
  * @obj_short_name: the shortest way to name the object
  * @obj_full_name: the full name of the object (in the &lt;schema&gt;.&lt;nameagt; notation
  * @obj_owner: object's owner
- * @depend_list: list of #GdaMetaDbObject pointers on which this object depends (through foreign keys
+ * @depend_list: (element-type Gda.MetaDbObject): list of #GdaMetaDbObject pointers on which this object depends (through foreign keys
  *               or tables used for views)
  *
  * Struture to hold information about each database object (tables, views, ...),
@@ -251,7 +256,7 @@ typedef struct {
  * @gtype: the detected column's #GType
  * @pkey: tells if the column is part of a primary key
  * @nullok: tells if the column can be %NULL
- * @default_value: the column's default value
+ * @default_value: (allow-none): the column's default value, represented as a valid SQL value (surrounded by simple quotes for strings, ...), or %NULL if column has no default value
  *
  * This structure represents a table of view's column, its contents must not be modified.
  */
@@ -289,7 +294,7 @@ void          gda_meta_table_column_set_attribute (GdaMetaTableColumn *tcol, con
  * gda_meta_table_column_set_attribute_static
  * @column: a #GdaMetaTableColumn
  * @attribute: attribute's name
- * @value: a #GValue, or %NULL
+ * @value: (allow-none): a #GValue, or %NULL
  *
  * This function is similar to gda_meta_table_column_set_attribute() but for static strings
  */
