@@ -63,7 +63,7 @@ enum {
 };
 
 static gint gda_tree_signals[LAST_SIGNAL] = { 0, 0, 0, 0 };
-extern GdaAttributesManager *_gda_tree_node_attributes_manager;
+extern GdaAttributesManager *gda_tree_node_attributes_manager;
 
 /* properties */
 enum {
@@ -86,7 +86,7 @@ gda_tree_class_init (GdaTreeClass *klass)
 
 	/* signals */
 	/**
-	 * GdaTree::node-changed:
+	 * GdaTree::node-changed
 	 * @tree: the #GdaTree
 	 * @node: the #GdaTreeNode which has changed
 	 *
@@ -103,7 +103,7 @@ gda_tree_class_init (GdaTreeClass *klass)
 			      g_cclosure_marshal_VOID__OBJECT,
 			      G_TYPE_NONE, 1, GDA_TYPE_TREE_NODE);
 	/**
-	 * GdaTree::node-inserted:
+	 * GdaTree::node-inserted
 	 * @tree: the #GdaTree
 	 * @node: the #GdaTreeNode which has inserted
 	 *
@@ -120,7 +120,7 @@ gda_tree_class_init (GdaTreeClass *klass)
 			      g_cclosure_marshal_VOID__OBJECT,
 			      G_TYPE_NONE, 1, GDA_TYPE_TREE_NODE);
 	/**
-	 * GdaTree::node-has-child-toggled:
+	 * GdaTree::node-has-child-toggled
 	 * @tree: the #GdaTree
 	 * @node: the #GdaTreeNode which changed from having children to being a
 	 *        leaf or the other way around
@@ -139,7 +139,7 @@ gda_tree_class_init (GdaTreeClass *klass)
 			      g_cclosure_marshal_VOID__OBJECT,
 			      G_TYPE_NONE, 1, GDA_TYPE_TREE_NODE);
 	/**
-	 * GdaTree::node-deleted:
+	 * GdaTree::node-deleted
 	 * @tree: the #GdaTree
 	 * @node_path: the position the node held in @tree as a tree path
 	 *
@@ -350,7 +350,7 @@ static void
 dump_root_attributes (GdaTreeNode *root)
 {
 	g_print ("DUMPING attributes for %p\n", root);
-	gda_attributes_manager_foreach (_gda_tree_node_attributes_manager, root,
+	gda_attributes_manager_foreach (gda_tree_node_attributes_manager, root,
 					(GdaAttributesManagerFunc) dump_attr_foreach_func, NULL);
 }
 #endif
@@ -373,8 +373,8 @@ gda_tree_clean (GdaTree *tree)
 
 	new_root = gda_tree_node_new (NULL);
 
-	gda_attributes_manager_copy (_gda_tree_node_attributes_manager, (gpointer) tree->priv->root,
-				     _gda_tree_node_attributes_manager, (gpointer) new_root);
+	gda_attributes_manager_copy (gda_tree_node_attributes_manager, (gpointer) tree->priv->root,
+				     gda_tree_node_attributes_manager, (gpointer) new_root);
 
 	take_root_node (tree, new_root);
 }
@@ -749,7 +749,7 @@ static GSList *split_absolute_path (const gchar *path, gboolean *out_error);
 static GSList *split_indexed_path (const gchar *path, gboolean *out_error);
 
 /**
- * decompose_path_as_segments:
+ * decompose_path_as_segments
  * @path: a path using '/'
  * @use_names: 
  *
