@@ -1,10 +1,6 @@
 /*
- * Copyright (C) 2001 - 2002 Gonzalo Paniagua Javier <gonzalo@gnome-db.org>
- * Copyright (C) 2001 - 2002 Rodrigo Moya <rodrigo@gnome-db.org>
- * Copyright (C) 2003 Danilo Schoeneberg <dj@starfire-programming.net>
- * Copyright (C) 2005 - 2011 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2009 Vivien Malerba <malerba@gnome-db.org>
  * Copyright (C) 2011 Murray Cumming <murrayc@murrayc.com>
- * Copyright (C) 2012 Daniel Espinosa <despinosa@src.gnome.org>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -40,4 +36,18 @@ _gda_slist_get_type (void)
 	return type;
 }
 
+GType
+_gda_meta_context_get_type (void)
+{
+	static GType type = 0;
 
+	if (G_UNLIKELY (type == 0)) {
+		static GStaticMutex registering = G_STATIC_MUTEX_INIT;
+		g_static_mutex_lock (&registering);
+                if (type == 0)
+			type = g_pointer_type_register_static ("GdaMetaContext");
+		g_static_mutex_unlock (&registering);
+	}
+
+	return type;
+}
