@@ -2,7 +2,7 @@
  * Copyright (C) 2001 - 2003 Rodrigo Moya <rodrigo@gnome-db.org>
  * Copyright (C) 2002 - 2003 Gonzalo Paniagua Javier <gonzalo@gnome-db.org>
  * Copyright (C) 2002 Holger Thon <holger.thon@gnome-db.org>
- * Copyright (C) 2002 - 2013 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2002 - 2011 Vivien Malerba <malerba@gnome-db.org>
  * Copyright (C) 2002 Zbigniew Chyla <cyba@gnome.pl>
  * Copyright (C) 2003 Akira TAGOH <tagoh@gnome-db.org>
  * Copyright (C) 2003 Danilo Schoeneberg <dschoene@src.gnome.org>
@@ -10,7 +10,7 @@
  * Copyright (C) 2003 Philippe CHARLIER <p.charlier@chello.be>
  * Copyright (C) 2004 Andrew Hill <andru@src.gnome.org>
  * Copyright (C) 2004 Dani Baeyens <daniel.baeyens@hispalinux.es>
- * Copyright (C) 2004 - 2011 Murray Cumming <murrayc@murrayc.com>
+ * Copyright (C) 2004 - 2008 Murray Cumming <murrayc@murrayc.com>
  * Copyright (C) 2004 Paisa  Seeluangsawat <paisa@users.sf.net>
  * Copyright (C) 2004 Szalai Ferenc <szferi@einstein.ki.iif.hu>
  * Copyright (C) 2007 Armin Burgmeier <armin@openismus.com>
@@ -19,7 +19,6 @@
  * Copyright (C) 2009 Bas Driessen <bas.driessen@xobas.com>
  * Copyright (C) 2010 David King <davidk@openismus.com>
  * Copyright (C) 2010 Jonh Wendell <jwendell@gnome.org>
- * Copyright (C) 2011 - 2012 Daniel Espinosa <despinosa@src.gnome.org>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -61,7 +60,7 @@ extern gchar *gda_numeric_locale;
  * GdaNumeric:
  * @number: a string representing a number
  * @precision: precision to use when @number is converted (not implemented jet)
- * @width: not implemented jet
+ * @width: (not implemented jet)
  *
  * Holds numbers represented as strings.
  *
@@ -172,7 +171,11 @@ set_from_string (GValue *value, const gchar *as_string)
 	else if (type == G_TYPE_CHAR) {
 		lvalue = strtol (as_string, endptr, 10);
 		if (*as_string!=0 && **endptr==0) {
+#if GLIB_CHECK_VERSION(2,31,7)
 			g_value_set_schar(value,(gint)lvalue);
+#else
+			g_value_set_char(value,(gchar)lvalue);
+#endif
 			retval = TRUE;
 		}
 	}
@@ -277,7 +280,9 @@ set_from_string (GValue *value, const gchar *as_string)
 			retval = TRUE;
 		}
 	}
-	else if (g_value_type_transformable (G_TYPE_STRING, type)) {
+
+
+	if (!retval && g_value_type_transformable (G_TYPE_STRING, type)) {
 		/* use the GLib type transformation function */
 		GValue *string;
 
@@ -409,6 +414,7 @@ gda_default_get_type (void)
 static void
 string_to_binary (const GValue *src, GValue *dest)
 {
+	/* FIXME: add more checks*/
 	GdaBinary *bin;
 	const gchar *as_string;
 
@@ -506,6 +512,7 @@ gda_binary_free (gpointer boxed)
 static void
 string_to_blob (const GValue *src, GValue *dest)
 {
+	/* FIXME: add more checks*/
 	GdaBlob *blob;
 	const gchar *as_string;
 
@@ -628,19 +635,20 @@ gda_blob_set_op (GdaBlob *blob, GdaBlobOp *op)
 static void
 geometric_point_to_string (const GValue *src, GValue *dest)
 {
-	GdaGeometricPoint *point;
 	gchar *str;
+	GdaGeometricPoint *point;
+
 	g_return_if_fail (G_VALUE_HOLDS_STRING (dest) &&
 			  GDA_VALUE_HOLDS_GEOMETRIC_POINT (src));
 
 	point = (GdaGeometricPoint *) gda_value_get_geometric_point ((GValue *) src);
-	if (point)
-		str = g_strdup_printf ("(%.*g,%.*g)", DBL_DIG, point->x,
-				       DBL_DIG, point->y);
-	else
-		str = g_strdup_printf ("(%.*g,%.*g)",
-				       DBL_DIG, 0.,
-				       DBL_DIG, 0.);
+
+	str = g_strdup_printf ("(%.*g,%.*g)",
+				  DBL_DIG,
+				  point->x,
+				  DBL_DIG,
+				  point->y);
+
 	g_value_take_string (dest, str);
 }
 
@@ -648,6 +656,7 @@ geometric_point_to_string (const GValue *src, GValue *dest)
 static void
 string_to_geometricpoint (const GValue *src, GValue *dest)
 {
+	/* FIXME: add more checks*/
 	GdaGeometricPoint *point;
 	const gchar *as_string;
 
@@ -731,7 +740,7 @@ numeric_to_string (const GValue *src, GValue *dest)
 	if (numeric)
 		g_value_set_string (dest, numeric->number);
 	else
-		g_value_set_string (dest, "0.0");
+		g_value_set_string (dest, "");
 }
 
 static void
@@ -858,19 +867,13 @@ GdaNumeric*
 gda_numeric_copy (GdaNumeric *src)
 {
 	GdaNumeric *copy;
-	gchar *str;
 
 	g_return_val_if_fail (src, NULL);
 
 	copy = gda_numeric_new ();
-
-	str = gda_numeric_get_string (src);
-	gda_numeric_set_from_string (copy, str);
-	g_free (str);
-
+	gda_numeric_set_from_string (copy, gda_numeric_get_string (src));
 	gda_numeric_set_width (copy, gda_numeric_get_width (src));
 	gda_numeric_set_precision (copy, gda_numeric_get_precision (src));
-
 	return copy;
 }
 
@@ -1054,30 +1057,26 @@ static void
 time_to_string (const GValue *src, GValue *dest)
 {
 	GdaTime *gdatime;
+	GString *string;
 
 	g_return_if_fail (G_VALUE_HOLDS_STRING (dest) &&
 			  GDA_VALUE_HOLDS_TIME (src));
 
 	gdatime = (GdaTime *) gda_value_get_time ((GValue *) src);
 
-	if (gdatime) {
-		GString *string;
-		string = g_string_new ("");
-		g_string_append_printf (string, "%02u:%02u:%02u",
-					gdatime->hour,
-					gdatime->minute,
-					gdatime->second);
-		if (gdatime->fraction != 0)
-			g_string_append_printf (string, ".%lu", gdatime->fraction);
+	string = g_string_new ("");
+	g_string_append_printf (string, "%02u:%02u:%02u",
+				gdatime->hour,
+				gdatime->minute,
+				gdatime->second);
+	if (gdatime->fraction != 0)
+		g_string_append_printf (string, ".%lu", gdatime->fraction);
 
-		if (gdatime->timezone != GDA_TIMEZONE_INVALID)
-			g_string_append_printf (string, "%+02d", (int) gdatime->timezone / 3600);
+	if (gdatime->timezone != GDA_TIMEZONE_INVALID)
+		g_string_append_printf (string, "%+02d", (int) gdatime->timezone / 3600);
 
-		g_value_take_string (dest, string->str);
-		g_string_free (string, FALSE);
-	}
-	else
-		g_value_set_string (dest, "00:00:00");
+	g_value_take_string (dest, string->str);
+	g_string_free (string, FALSE);
 }
 
 /* Transform a String GValue to a GdaTime from a string like "12:30:15+01" */
@@ -1235,65 +1234,14 @@ gda_time_valid (const GdaTime *time)
 {
 	g_return_val_if_fail (time, FALSE);
 
-	if ((time->hour > 23) ||
-	    (time->minute > 59) ||
-	    (time->second > 59))
+	if (time->hour > 24 ||
+	    time->minute > 59 ||
+	    time->second > 59)
 		return FALSE;
-	if ((time->fraction >= 1000000) ||
-	    (time->timezone <= -12 * 3600) ||
-	    (time->timezone >= 12 * 3600))
-		return FALSE;
-	return TRUE;
+	else
+		return TRUE;
 }
 
-/**
- * gda_time_change_timezone:
- * @time: a valid #GdaTime
- * @ntz: a new timezone to use, in seconds added to GMT
- *
- * Changes @time's timezone (for example to convert from GMT to another time zone).
- * If @time's current timezone is unset (i.e. equal to %GDA_TIMEZONE_INVALID), then this function simply sets
- * @time's timezone attribute; Otherwise, it adds or removes hours, minutes or seconds to reflect the time in the new timezone.
- *
- * Note: the resulting will always be a valid time.
- *
- * Since: 5.2
- */
-void
-gda_time_change_timezone (GdaTime *time, glong ntz)
-{
-	g_return_if_fail (time);
-	g_return_if_fail (gda_time_valid (time));
-	g_return_if_fail ((ntz > - 12 * 3600) && (ntz < 12 * 3600));
-
-	if (time->timezone == ntz)
-		return;
-
-	if (time->timezone != GDA_TIMEZONE_INVALID) {
-		glong nsec;
-		nsec = time->hour * 3600 + time->minute * 60 + time->second - time->timezone + ntz;
-		if (nsec < 0)
-			nsec += 86400;
-		else if (nsec >= 86400)
-			nsec -= 86400;
-
-		/* hours */
-		gint n;
-		n = nsec / 3600;
-		time->hour = (gushort) n;
-
-		/* minutes */
-		nsec -= n * 3600;
-		n = nsec / 60;
-		time->minute = (gushort) n;
-
-		/* seconds */
-		nsec -= n * 60;
-		time->second = (gushort) nsec;
-	}
-
-	time->timezone = ntz;
-}
 
 /*
  * Register the GdaTimestamp type in the GType system
@@ -1302,12 +1250,14 @@ gda_time_change_timezone (GdaTime *time, glong ntz)
 static void
 string_to_timestamp (const GValue *src, GValue *dest)
 {
+	/* FIXME: add more checks*/
 	GdaTimestamp timestamp;
 
 	g_return_if_fail (G_VALUE_HOLDS_STRING (src) &&
 			  GDA_VALUE_HOLDS_TIMESTAMP (dest));
 
-	gda_parse_iso8601_timestamp (&timestamp, g_value_get_string (src));
+	if (! gda_parse_iso8601_timestamp (&timestamp, g_value_get_string (src)))
+		g_warning ("Can't convert '%s' to a timestamp", g_value_get_string (src));
 	gda_value_set_timestamp (dest, &timestamp);
 }
 
@@ -1315,31 +1265,28 @@ static void
 timestamp_to_string (const GValue *src, GValue *dest)
 {
 	GdaTimestamp *timestamp;
+	GString *string;
 
 	g_return_if_fail (G_VALUE_HOLDS_STRING (dest) &&
 			  GDA_VALUE_HOLDS_TIMESTAMP (src));
 
 	timestamp = (GdaTimestamp *) gda_value_get_timestamp ((GValue *) src);
-	if (timestamp) {
-		GString *string;
-		string = g_string_new ("");
-		g_string_append_printf (string, "%04u-%02u-%02u %02u:%02u:%02u",
-					timestamp->year,
-					timestamp->month,
-					timestamp->day,
-					timestamp->hour,
-					timestamp->minute,
-					timestamp->second);
-		if (timestamp->fraction > 0)
-			g_string_append_printf (string, ".%lu", timestamp->fraction);
-		if (timestamp->timezone != GDA_TIMEZONE_INVALID)
-			g_string_append_printf (string, "%+02d",
-						(int) timestamp->timezone/3600);
-		g_value_take_string (dest, string->str);
-		g_string_free (string, FALSE);
-	}
-	else
-		g_value_set_string (dest, "0000-00-00 00:00:00");
+
+	string = g_string_new ("");
+	g_string_append_printf (string, "%04u-%02u-%02u %02u:%02u:%02u",
+				timestamp->year,
+				timestamp->month,
+				timestamp->day,
+				timestamp->hour,
+				timestamp->minute,
+				timestamp->second);
+	if (timestamp->fraction > 0)
+		g_string_append_printf (string, ".%lu", timestamp->fraction);
+	if (timestamp->timezone != GDA_TIMEZONE_INVALID)
+		g_string_append_printf (string, "%+02d",
+					(int) timestamp->timezone/3600);
+	g_value_take_string (dest, string->str);
+	g_string_free (string, FALSE);
 }
 
 GType
@@ -1404,89 +1351,30 @@ gda_timestamp_valid (const GdaTimestamp *timestamp)
 {
 	g_return_val_if_fail (timestamp, FALSE);
 
+	GDate *gdate;
+
 	/* check the date part */
-	if (! g_date_valid_dmy ((GDateDay) timestamp->day, (GDateMonth) timestamp->month,
-				(GDateYear) timestamp->year))
+	gdate = g_date_new_dmy ((GDateDay) timestamp->day, (GDateMonth) timestamp->month,
+				(GDateYear) timestamp->year);
+	if (!gdate)
 		return FALSE;
+	if (! g_date_valid (gdate)) {
+		g_date_free (gdate);
+		return FALSE;
+	}
+	g_date_free (gdate);
 
 	/* check the time part */
-	if ((timestamp->hour > 23) ||
-	    (timestamp->minute > 59) ||
-	    (timestamp->second > 59))
+	if (timestamp->hour > 24 ||
+	    timestamp->minute > 59 ||
+	    timestamp->second > 59)
 		return FALSE;
-	if ((timestamp->fraction >= 1000000) ||
-	    (timestamp->timezone <= -12 * 3600) ||
-	    (timestamp->timezone >= 12 * 3600))
-		return FALSE;
-
-	return TRUE;
+	else
+		return TRUE;
 }
 
 /**
- * gda_timestamp_change_timezone:
- * @ts: a valid #GdaTimestamp
- * @ntz: a new timezone to use, in seconds added to GMT
- *
- * This function is similar to gda_time_change_timezone() but operates on time stamps.
- *
- * Note: the resulting will always be a valid time.
- *
- * Since: 5.2
- */
-void
-gda_timestamp_change_timezone (GdaTimestamp *ts, glong ntz)
-{
-	g_return_if_fail (ts);
-	g_return_if_fail (gda_timestamp_valid (ts));
-	g_return_if_fail ((ntz > - 12 * 3600) && (ntz < 12 * 3600));
-
-	if (ts->timezone == ntz)
-		return;
-
-	if (ts->timezone != GDA_TIMEZONE_INVALID) {
-		glong nsec;
-		nsec = ts->hour * 3600 + ts->minute * 60 + ts->second - ts->timezone + ntz;
-		if (nsec < 0) {
-			GDate *date;
-			date = g_date_new_dmy ((GDateDay) ts->day, (GDateMonth) ts->month, (GDateYear) ts->year);
-			g_date_subtract_days (date, 1);
-			ts->year = g_date_get_year (date);
-			ts->month = g_date_get_month (date);
-			ts->day = g_date_get_day (date);
-			g_date_free (date);
-			nsec += 86400;
-		}
-		else if (nsec >= 86400) {
-			GDate *date;
-			date = g_date_new_dmy ((GDateDay) ts->day, (GDateMonth) ts->month, (GDateYear) ts->year);
-			g_date_add_days (date, 1);
-			ts->year = g_date_get_year (date);
-			ts->month = g_date_get_month (date);
-			ts->day = g_date_get_day (date);
-			g_date_free (date);
-			nsec -= 86400;
-		}
-
-		/* hours */
-		gint n;
-		n = nsec / 3600;
-		ts->hour = (gushort) n;
-
-		/* minutes */
-		nsec -= n * 3600;
-		n = nsec / 60;
-		ts->minute = (gushort) n;
-
-		/* seconds */
-		nsec -= n * 60;
-		ts->second = (gushort) nsec;
-	}
-
-	ts->timezone = ntz;
-}
-
-/**
- * gda_value_new: (skip)
+ * gda_value_new:
  * @type: the new value type.
  *
  * Makes a new #GValue of type @type.
@@ -1507,7 +1395,7 @@ gda_value_new (GType type)
 }
 
 /**
- * gda_value_new_null: (skip)
+ * gda_value_new_null:
  *
  * Creates a new #GValue initiated to a #GdaNull structure with a #GDA_TYPE_NULL, to
  * represent a NULL in the database.
@@ -1521,7 +1409,7 @@ gda_value_new_null (void)
 }
 
 /**
- * gda_value_new_default: (skip)
+ * gda_value_new_default:
  * @default_val: (allow-none): the default value as a string, or %NULL
  *
  * Creates a new default value.
@@ -1540,7 +1428,7 @@ gda_value_new_default (const gchar *default_val)
 }
 
 /**
- * gda_value_new_binary: (skip)
+ * gda_value_new_binary:
  * @val: value to set for the new #GValue.
  * @size: the size of the memory pool pointer to by @val.
  *
@@ -1569,7 +1457,7 @@ gda_value_new_binary (const guchar *val, glong size)
 }
 
 /**
- * gda_value_new_blob: (skip)
+ * gda_value_new_blob:
  * @val: value to set for the new #GValue.
  * @size: the size of the memory pool pointer to by @val.
  *
@@ -1601,7 +1489,7 @@ gda_value_new_blob (const guchar *val, glong size)
 }
 
 /**
- * gda_value_new_blob_from_file: (skip)
+ * gda_value_new_blob_from_file:
  * @filename: name of the file to manipulate
  *
  * Makes a new #GValue of type #GDA_TYPE_BLOB interfacing with the contents of the file
@@ -1618,7 +1506,7 @@ gda_value_new_blob_from_file (const gchar *filename)
 	GdaBlob *blob;
 
 	blob = g_new0 (GdaBlob, 1);
-	blob->op = _gda_dir_blob_op_new (filename);
+	blob->op = gda_dir_blob_op_new (filename);
 
         value = g_new0 (GValue, 1);
 	g_value_init (value, GDA_TYPE_BLOB);
@@ -1627,90 +1515,36 @@ gda_value_new_blob_from_file (const gchar *filename)
         return value;
 }
 
-/*
- * Warning: modifies @gmttm and loctm
- *
- * Returns: the offset, or G_MAXLONG in case of error
- */
-static glong
-compute_tz_offset (struct tm *gmttm, struct tm *loctm)
-{
-	time_t lt, gt;
-	if (! gmttm || !loctm)
-		return G_MAXLONG;
-
-	gmttm->tm_isdst = 0;
-	loctm->tm_isdst = 0;
-
-	lt = mktime (loctm);
-	if (lt == -1)
-		return G_MAXLONG;
-	gt = mktime (gmttm);
-	if (gt == -1)
-		return G_MAXLONG;
-
-	glong off;
-	off = lt - gt;
-	if ((off >= 24 * 3600) || (off <= - 24 * 3600))
-		return G_MAXLONG;
-	else
-		return off;
-}
-
 /**
- * gda_value_new_timestamp_from_timet: (skip)
+ * gda_value_new_timestamp_from_timet:
  * @val: value to set for the new #GValue.
  *
  * Makes a new #GValue of type #GDA_TYPE_TIMESTAMP with value @val
- * (of type time_t). The returned timestamp's value is relative to the current
- * timezone (i.e. is localtime).
+ * (of type time_t).
  *
- * For example, to get a time stamp representing the current date and time, use:
- *
- * <code>
- * ts = gda_value_new_timestamp_from_timet (time (NULL));
- * </code>
- *
- * Returns: (transfer full): the newly created #GValue, or %NULL in case of error
+ * Returns: (transfer full): the newly created #GValue.
  *
  * Free-function: gda_value_free
  */
 GValue *
 gda_value_new_timestamp_from_timet (time_t val)
 {
-	GValue *value = NULL;
-	struct tm *ltm = NULL;
-	glong tz = 0;
+	GValue *value;
 
+	struct tm *ltm;
+
+        value = g_new0 (GValue, 1);
 #ifdef HAVE_LOCALTIME_R
-	struct tm gmttm, loctm;
-	tzset ();
-	ltm = localtime_r ((const time_t *) &val, &loctm);
-	tz = compute_tz_offset (gmtime_r ((const time_t *) &val, &gmttm), &loctm);
-	if (tz == G_MAXLONG)
-		ltm = NULL;
+	struct tm tmpstm;
+	ltm = localtime_r ((const time_t *) &val, &tmpstm);
 #elif HAVE_LOCALTIME_S
-	struct tm gmttm, loctm;
-	if ((localtime_s (&loctm, (const time_t *) &val) == 0) &&
-	    (gmtime_s (&gmttm, (const time_t *) &val) == 0)) {
-		tz = compute_tz_offset (&gmttm, &loctm);
-		if (tz != G_MAXLONG)
-			ltm = &loctm;
-	}
+	struct tm tmpstm;
+	if (localtime_s (&tmpstm, (const time_t *) &val) == 0)
+		ltm = &tmpstm;
+	else
+		ltm = NULL;
 #else
-	struct tm gmttm, loctm;
-	ltm = gmtime ((const time_t *) &val);
-	if (ltm) {
-		gmttm = *ltm;
-		ltm = localtime ((const time_t *) &val);
-		if (ltm) {
-			loctm = *ltm;
-			tz = compute_tz_offset (&gmttm, &loctm);
-			if (tz == G_MAXLONG)
-				ltm = NULL;
-		}
-	}
-	
+	ltm = localtime ((const time_t *) &val);
 #endif
 
         if (ltm) {
@@ -1722,9 +1556,7 @@ gda_value_new_timestamp_from_timet (time_t val)
                 tstamp.minute = ltm->tm_min;
                 tstamp.second = ltm->tm_sec;
                 tstamp.fraction = 0;
-                tstamp.timezone = tz;
-
-		value = g_new0 (GValue, 1);
+                tstamp.timezone = GDA_TIMEZONE_INVALID;
                 gda_value_set_timestamp (value, (const GdaTimestamp *) &tstamp);
         }
 
@@ -1732,7 +1564,7 @@ gda_value_new_timestamp_from_timet (time_t val)
 }
 
 /**
- * gda_value_new_from_string: (skip)
+ * gda_value_new_from_string:
  * @as_string: stringified representation of the value.
  * @type: the new value type.
  *
@@ -1764,7 +1596,7 @@ gda_value_new_from_string (const gchar *as_string, GType type)
 }
 
 /**
- * gda_value_new_from_xml: (skip)
+ * gda_value_new_from_xml:
  * @node: an XML node representing the value.
  *
  * Creates a GValue from an XML representation of it. That XML
@@ -1807,7 +1639,7 @@ gda_value_new_from_xml (const xmlNodePtr node)
 }
 
 /**
- * gda_value_free: (skip)
+ * gda_value_free:
  * @value: (transfer full) (allow-none): the resource to free (or %NULL)
  *
  * Deallocates all memory associated to a #GValue.
@@ -1822,7 +1654,7 @@ gda_value_free (GValue *value)
 }
 
 /**
- * gda_value_reset_with_type: (skip)
+ * gda_value_reset_with_type:
  * @value: the #GValue to be reseted
  * @type:  the #GType to set to
  *
@@ -1847,7 +1679,7 @@ gda_value_reset_with_type (GValue *value, GType type)
 
 
 /**
- * gda_value_is_null: (skip)
+ * gda_value_is_null:
  * @value: value to test.
  *
  * Tests if a given @value is of type #GDA_TYPE_NULL.
@@ -1862,7 +1694,7 @@ gda_value_is_null (const GValue *value)
 }
 
 /**
- * gda_value_is_number: (skip)
+ * gda_value_is_number:
  * @value: a #GValue.
  *
  * Gets whether the value stored in the given #GValue is of numeric type or not.
@@ -1885,7 +1717,7 @@ gda_value_is_number (const GValue *value)
 }
 
 /**
- * gda_value_copy: (skip)
+ * gda_value_copy:
  * @value: value to get a copy from.
  *
  * Creates a new #GValue from an existing one.
@@ -1912,7 +1744,7 @@ gda_value_copy (const GValue *value)
 }
 
 /**
- * gda_value_get_binary: (skip)
+ * gda_value_get_binary:
  * @value: a #GValue whose value we want to get.
  *
  * Returns: (transfer none): the value stored in @value.
@@ -1932,7 +1764,7 @@ gda_value_get_binary (const GValue *value)
 
 
 /**
- * gda_value_set_binary: (skip)
+ * gda_value_set_binary:
  * @value: a #GValue that will store @val.
  * @binary: a #GdaBinary structure with the data and its size to be stored in @value.
  *
@@ -1954,7 +1786,7 @@ gda_value_set_binary (GValue *value, const GdaBinary *binary)
 }
 
 /**
- * gda_value_take_binary: (skip)
+ * gda_value_take_binary:
  * @value: a #GValue that will store @val.
  * @binary: (transfer full): a #GdaBinary structure with the data and its size to be stored in @value.
  *
@@ -1973,7 +1805,7 @@ gda_value_take_binary (GValue *value, GdaBinary *binary)
 }
 
 /**
- * gda_value_set_blob: (skip)
+ * gda_value_set_blob:
  * @value: a #GValue that will store @val.
  * @blob: a #GdaBlob structure with the data and its size to be stored in @value.
  *
@@ -1991,7 +1823,7 @@ gda_value_set_blob (GValue *value, const GdaBlob *blob)
 }
 
 /**
- * gda_value_get_blob: (skip)
+ * gda_value_get_blob:
  * @value: a #GValue whose value we want to get.
  *
  * Returns: (transfer none): the value stored in @value.
@@ -2010,7 +1842,7 @@ gda_value_get_blob (const GValue *value)
 }
 
 /**
- * gda_value_take_blob: (skip)
+ * gda_value_take_blob:
  * @value: a #GValue that will store @val.
  * @blob: (transfer full): a #GdaBlob structure with the data and its size to be stored in @value.
  *
@@ -2029,7 +1861,7 @@ gda_value_take_blob (GValue *value, GdaBlob *blob)
 }
 
 /**
- * gda_value_get_geometric_point: (skip)
+ * gda_value_get_geometric_point:
  * @value: a #GValue whose value we want to get.
  *
  * Returns: (transfer none): the value stored in @value.
@@ -2043,7 +1875,7 @@ gda_value_get_geometric_point (const GValue *value)
 }
 
 /**
- * gda_value_set_geometric_point: (skip)
+ * gda_value_set_geometric_point:
  * @value: a #GValue that will store @val.
  * @val: value to be stored in @value.
  *
@@ -2061,7 +1893,7 @@ gda_value_set_geometric_point (GValue *value, const GdaGeometricPoint *val)
 }
 
 /**
- * gda_value_set_null: (skip)
+ * gda_value_set_null
  * @value: a #GValue that will store a value of type #GDA_TYPE_NULL.
  *
  * Sets the type of @value to #GDA_TYPE_NULL.
@@ -2074,7 +1906,7 @@ gda_value_set_null (GValue *value)
 }
 
 /**
- * gda_value_get_numeric: (skip)
+ * gda_value_get_numeric
  * @value: a #GValue whose value we want to get.
  *
  * Returns: (transfer none): the value stored in @value.
@@ -2088,7 +1920,7 @@ gda_value_get_numeric (const GValue *value)
 }
 
 /**
- * gda_value_set_numeric: (skip)
+ * gda_value_set_numeric:
  * @value: a #GValue that will store @val.
  * @val: value to be stored in @value.
  *
@@ -2106,7 +1938,7 @@ gda_value_set_numeric (GValue *value, const GdaNumeric *val)
 }
 
 /**
- * gda_value_get_short: (skip)
+ * gda_value_get_short:
  * @value: a #GValue whose value we want to get.
  *
  * Returns: the value stored in @value.
@@ -2120,7 +1952,7 @@ gda_value_get_short (const GValue *value)
 }
 
 /**
- * gda_value_set_short: (skip)
+ * gda_value_set_short:
  * @value: a #GValue that will store @val.
  * @val: value to be stored in @value.
  *
@@ -2137,7 +1969,7 @@ gda_value_set_short (GValue *value, gshort val)
 }
 
 /**
- * gda_value_get_ushort: (skip)
+ * gda_value_get_ushort:
  * @value: a #GValue whose value we want to get.
  *
  * Returns: the value stored in @value.
@@ -2151,7 +1983,7 @@ gda_value_get_ushort (const GValue *value)
 }
 
 /**
- * gda_value_set_ushort: (skip)
+ * gda_value_set_ushort:
  * @value: a #GValue that will store @val.
  * @val: value to be stored in @value.
  *
@@ -2169,7 +2001,7 @@ gda_value_set_ushort (GValue *value, gushort val)
 
 
 /**
- * gda_value_get_time: (skip)
+ * gda_value_get_time:
  * @value: a #GValue whose value we want to get.
  *
  * Returns: (transfer none): the value stored in @value.
@@ -2183,7 +2015,7 @@ gda_value_get_time (const GValue *value)
 }
 
 /**
- * gda_value_set_time: (skip)
+ * gda_value_set_time:
  * @value: a #GValue that will store @val.
  * @val: value to be stored in @value.
  *
@@ -2201,7 +2033,7 @@ gda_value_set_time (GValue *value, const GdaTime *val)
 }
 
 /**
- * gda_value_get_timestamp: (skip)
+ * gda_value_get_timestamp:
  * @value: a #GValue whose value we want to get.
  *
  * Returns: (transfer none): the value stored in @value.
@@ -2215,7 +2047,7 @@ gda_value_get_timestamp (const GValue *value)
 }
 
 /**
- * gda_value_set_timestamp: (skip)
+ * gda_value_set_timestamp:
  * @value: a #GValue that will store @val.
  * @val: value to be stored in @value.
  *
@@ -2233,7 +2065,7 @@ gda_value_set_timestamp (GValue *value, const GdaTimestamp *val)
 }
 
 /**
- * gda_value_set_from_string: (skip)
+ * gda_value_set_from_string:
  * @value: a #GValue that will store @val.
  * @as_string: the stringified representation of the value.
  * @type: the type of the value
@@ -2271,7 +2103,7 @@ gda_value_set_from_string (GValue *value,
 }
 
 /**
- * gda_value_set_from_value: (skip)
+ * gda_value_set_from_value:
  * @value: a #GValue.
  * @from: the value to copy from.
  *
@@ -2330,10 +2162,8 @@ gda_value_stringify (const GValue *value)
 		GValue *string;
 		gchar *str;
 
-		setlocale (LC_NUMERIC, "C");
 		string = g_value_init (g_new0 (GValue, 1), G_TYPE_STRING);
 		g_value_transform (value, string);
-		setlocale (LC_NUMERIC, gda_numeric_locale);
 		str = g_value_dup_string (string);
 		gda_value_free (string);
 		return str;
@@ -2356,11 +2186,6 @@ gda_value_stringify (const GValue *value)
 			else
 				return g_strdup ("0000-00-00");
 		}
-		else if (G_TYPE_IS_OBJECT (type)) {
-			GObject *obj;
-			obj = g_value_get_object (value);
-			return g_strdup_printf ("%p (%s)", obj, G_OBJECT_TYPE_NAME (obj));
-		}
 		else
 			return g_strdup ("");
 	}
@@ -2758,8 +2583,13 @@ gda_value_compare (const GValue *value1, const GValue *value2)
 	}
 
 	else if (type == G_TYPE_CHAR) {
+#if GLIB_CHECK_VERSION(2,31,7)
 		gint8 c1 = g_value_get_schar (value1);
 		gint8 c2 = g_value_get_schar (value2);
+#else
+		gchar c1 = g_value_get_char (value1);
+		gchar c2 = g_value_get_char (value2);
+#endif
 		return (c1 > c2) ? 1 : ((c1 == c2) ? 0 : -1);
 	}
 
@@ -3074,7 +2904,7 @@ gda_string_to_binary (const gchar *str)
 	}
 
 	total = strlen (str);
-	retval = g_new0 (guchar, total + 1);
+	retval = g_new0 (gchar, total + 1);
 	sptr = (guchar*) str;
 	rptr = retval;
 
