@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2006 - 2013 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2006 - 2010 Vivien Malerba <malerba@gnome-db.org>
  * Copyright (C) 2007 Armin Burgmeier <armin@openismus.com>
  * Copyright (C) 2007 Murray Cumming <murrayc@murrayc.com>
  * Copyright (C) 2009 Bas Driessen <bas.driessen@xobas.com>
@@ -47,6 +47,7 @@ static gboolean     gda_handler_bin_accepts_g_type       (GdaDataHandler * dh, G
 static const gchar *gda_handler_bin_get_descr              (GdaDataHandler *dh);
 
 struct  _GdaHandlerBinPriv {
+	gchar             *detailed_descr;
 	guint              nb_g_types;
 	GType             *valid_g_types;
 };
@@ -71,7 +72,7 @@ gda_handler_bin_get_type (void)
 			sizeof (GdaHandlerBin),
 			0,
 			(GInstanceInitFunc) gda_handler_bin_init,
-			NULL
+			0
 		};		
 
 		static const GInterfaceInfo data_entry_info = {
@@ -118,6 +119,7 @@ gda_handler_bin_init (GdaHandlerBin * hdl)
 {
 	/* Private structure */
 	hdl->priv = g_new0 (GdaHandlerBinPriv, 1);
+	hdl->priv->detailed_descr = _("Binary handler");
 	hdl->priv->nb_g_types = 2;
 	hdl->priv->valid_g_types = g_new0 (GType, hdl->priv->nb_g_types);
 	hdl->priv->valid_g_types[0] = GDA_TYPE_BINARY;
@@ -168,45 +170,57 @@ gda_handler_bin_new (void)
 
 
 static gchar *
-gda_handler_bin_get_sql_from_value (G_GNUC_UNUSED GdaDataHandler *iface, const GValue *value)
+gda_handler_bin_get_sql_from_value (GdaDataHandler *iface, const GValue *value)
 {
-	g_assert (value);
-
 	gchar *retval;
-	if (gda_value_isa ((GValue *) value, GDA_TYPE_BINARY)) {
-		gchar *str, *str2;
-		str = gda_binary_to_string (gda_value_get_binary ((GValue *) value), 0);
-		str2 = gda_default_escape_string (str);
-		g_free (str);
-		retval = g_strdup_printf ("'%s'", str2);
-		g_free (str2);
-	}
-	else {
-		GdaBlob *blob;
-		GdaBinary *bin;
-		blob = (GdaBlob*) gda_value_get_blob ((GValue *) value);
-		bin = (GdaBinary *) blob;
-		if (blob->op &&
-		    (bin->binary_length != gda_blob_op_get_length (blob->op)))
-			gda_blob_op_read_all (blob->op, blob);
+	GdaHandlerBin *hdl;
 
-		gchar *str, *str2;
-		str = gda_binary_to_string (bin, 0);
-		str2 = gda_default_escape_string (str);
-		g_free (str);
-		retval = g_strdup_printf ("'%s'", str2);
-		g_free (str2);
+	g_return_val_if_fail (iface && GDA_IS_HANDLER_BIN (iface), NULL);
+	hdl = GDA_HANDLER_BIN (iface);
+	g_return_val_if_fail (hdl->priv, NULL);
+
+	if (value) {
+		if (gda_value_isa ((GValue *) value, GDA_TYPE_BINARY)) {
+			gchar *str, *str2;
+			str = gda_binary_to_string (gda_value_get_binary ((GValue *) value), 0);
+			str2 = gda_default_escape_string (str);
+			g_free (str);
+			retval = g_strdup_printf ("'%s'", str2);
+			g_free (str2);
+		}
+		else {
+			GdaBlob *blob;
+			GdaBinary *bin;
+			blob = (GdaBlob*) gda_value_get_blob ((GValue *) value);
+			bin = (GdaBinary *) blob;
+			if (blob->op &&
+			    (bin->binary_length != gda_blob_op_get_length (blob->op)))
+				gda_blob_op_read_all (blob->op, blob);
+
+			gchar *str, *str2;
+			str = gda_binary_to_string (bin, 0);
+			str2 = gda_default_escape_string (str);
+			g_free (str);
+			retval = g_strdup_printf ("'%s'", str2);
+			g_free (str2);
+		}
 	}
+	else
+		retval = g_strdup ("NULL");
 
 	return retval;
 }
 
 static gchar *
-gda_handler_bin_get_str_from_value (G_GNUC_UNUSED GdaDataHandler *iface, const GValue *value)
+gda_handler_bin_get_str_from_value (GdaDataHandler *iface, const GValue *value)
 {
-	g_assert (value);
+	gchar *retval;
+	GdaHandlerBin *hdl;
+
+	g_return_val_if_fail (iface && GDA_IS_HANDLER_BIN (iface), NULL);
+	hdl = GDA_HANDLER_BIN (iface);
+	g_return_val_if_fail (hdl->priv, NULL);
 
-	gchar *retval = NULL;
 	if (value) {
 		if (gda_value_isa ((GValue *) value, GDA_TYPE_BINARY)) 
 			retval = gda_binary_to_string (gda_value_get_binary ((GValue *) value), 0);
@@ -218,29 +232,38 @@ gda_handler_bin_get_str_from_value (G_GNUC_UNUSED GdaDataHandler *iface, const G
 			retval = gda_binary_to_string ((GdaBinary *) blob, 0);
 		}
 	}
+	else
+		retval = g_strdup (NULL);
 
 	return retval;
 }
 
 static GValue *
-gda_handler_bin_get_value_from_sql (G_GNUC_UNUSED GdaDataHandler *iface, const gchar *sql, GType type)
+gda_handler_bin_get_value_from_sql (GdaDataHandler *iface, const gchar *sql, GType type)
 {
-	g_assert (sql);
-
+	GdaHandlerBin *hdl;
 	GValue *value = NULL;
-	if (*sql) {
-		gint i = strlen (sql);
-		if ((i>=2) && (*sql=='\'') && (sql[i-1]=='\'')) {
-			gchar *str = g_strdup (sql);
-			gchar *unstr;
 
-			str[i-1] = 0;
-			unstr = gda_default_unescape_string (str+1);
-			if (unstr) {
-				value = gda_handler_bin_get_value_from_str (iface, unstr, type);
-				g_free (unstr);
+	g_return_val_if_fail (iface && GDA_IS_HANDLER_BIN (iface), NULL);
+	hdl = GDA_HANDLER_BIN (iface);
+	g_return_val_if_fail (hdl->priv, NULL);
+
+	if ((type == GDA_TYPE_BINARY) ||
+	    (type == GDA_TYPE_BLOB)) {
+		if (sql && *sql) {
+			gint i = strlen (sql);
+			if ((i>=2) && (*sql=='\'') && (sql[i-1]=='\'')) {
+				gchar *str = g_strdup (sql);
+				gchar *unstr;
+				
+				str[i-1] = 0;
+				unstr = gda_default_unescape_string (str+1);
+				if (unstr) {
+					value = gda_handler_bin_get_value_from_str (iface, unstr, type);
+					g_free (unstr);
+				}
+				g_free (str);
 			}
-			g_free (str);
 		}
 	}
 
@@ -248,11 +271,15 @@ gda_handler_bin_get_value_from_sql (G_GNUC_UNUSED GdaDataHandler *iface, const g
 }
 
 static GValue *
-gda_handler_bin_get_value_from_str (G_GNUC_UNUSED GdaDataHandler *iface, const gchar *str, GType type)
+gda_handler_bin_get_value_from_str (GdaDataHandler *iface, const gchar *str, GType type)
 {
-	g_assert (str);
-
+	GdaHandlerBin *hdl;
 	GValue *value = NULL;
+
+	g_return_val_if_fail (iface && GDA_IS_HANDLER_BIN (iface), NULL);
+	hdl = GDA_HANDLER_BIN (iface);
+	g_return_val_if_fail (hdl->priv, NULL);
+
 	if (type == GDA_TYPE_BINARY) {
 		GdaBinary *bin;
 		bin = gda_string_to_binary (str);
@@ -261,7 +288,7 @@ gda_handler_bin_get_value_from_str (G_GNUC_UNUSED GdaDataHandler *iface, const g
 			gda_value_take_binary (value, bin);
 		}
 	}
-	else {
+	else if (type == GDA_TYPE_BLOB) {
 		GdaBlob *blob;
 		blob = gda_string_to_blob (str);
 		if (blob) {
@@ -277,22 +304,30 @@ static gboolean
 gda_handler_bin_accepts_g_type (GdaDataHandler *iface, GType type)
 {
 	GdaHandlerBin *hdl;
-	guint i;
+	guint i = 0;
+	gboolean found = FALSE;
 
-	g_assert (iface);
-	hdl = (GdaHandlerBin*) (iface);
+	g_return_val_if_fail (iface && GDA_IS_HANDLER_BIN (iface), FALSE);
+	hdl = GDA_HANDLER_BIN (iface);
+	g_return_val_if_fail (hdl->priv, 0);
 
-	for (i = 0; i < hdl->priv->nb_g_types; i++) {
+	while (!found && (i < hdl->priv->nb_g_types)) {
 		if (hdl->priv->valid_g_types [i] == type)
-			return TRUE;
+			found = TRUE;
+		i++;
 	}
 
-	return FALSE;
+	return found;
 }
 
 static const gchar *
 gda_handler_bin_get_descr (GdaDataHandler *iface)
 {
-	g_return_val_if_fail (GDA_IS_HANDLER_BIN (iface), NULL);
-	return g_object_get_data (G_OBJECT (iface), "descr");
+	GdaHandlerBin *hdl;
+
+	g_return_val_if_fail (iface && GDA_IS_HANDLER_BIN (iface), NULL);
+	hdl = GDA_HANDLER_BIN (iface);
+	g_return_val_if_fail (hdl->priv, NULL);
+
+	return g_object_get_data (G_OBJECT (hdl), "descr");
 }
