@@ -93,7 +93,6 @@ gda_sql_expr_free (GdaSqlExpr *expr)
 	}
 	gda_sql_case_free (expr->case_s);
 	g_free (expr->cast_as);
-	expr->value_is_ident = TRUE;
 	g_free (expr);
 }
 
@@ -152,10 +151,10 @@ gda_sql_expr_copy (GdaSqlExpr *expr)
  * gda_sql_expr_serialize
  * @expr: a #GdaSqlExpr structure
  *
- * Creates a new string representing a field. You need to free the returned string
+ * Creates a new string representation of the SQL expression. You need to free the returned string
  * using g_free();
  *
- * Returns: a new string with the name of the field or "null" in case @expr is invalid.
+ * Returns: a new string with the SQL expression or "null" in case @expr is invalid.
  */
 gchar *
 gda_sql_expr_serialize (GdaSqlExpr *expr)
@@ -729,6 +728,11 @@ gda_sql_operation_operator_to_string (GdaSqlOperatorType op)
 		return "NOT IN";
 	case GDA_SQL_OPERATOR_TYPE_LIKE:
 		return "LIKE";
+        /* ILIKE is a PostgreSQL extension for case-insensitive comparison.
+         * See http://developer.postgresql.org/pgdocs/postgres/functions-matching.html
+         */ 
+	case GDA_SQL_OPERATOR_TYPE_ILIKE:
+		return "ILIKE";
 	case GDA_SQL_OPERATOR_TYPE_BETWEEN:
 		return "BETWEEN";
 	case GDA_SQL_OPERATOR_TYPE_GT:
@@ -800,6 +804,8 @@ gda_sql_operation_operator_from_string (const gchar *op)
 			return GDA_SQL_OPERATOR_TYPE_IS;
 		else if (op[1] == 'N')
 			return GDA_SQL_OPERATOR_TYPE_IN;
+		else if (op[1] == 'L')
+			return GDA_SQL_OPERATOR_TYPE_ILIKE;
 		break;
 	case 'L':
 		return GDA_SQL_OPERATOR_TYPE_LIKE;
@@ -1124,10 +1130,15 @@ void
 gda_sql_select_field_take_expr (GdaSqlSelectField *field, GdaSqlExpr *expr)
 {
 	field->expr = expr;
+	g_assert (GDA_SQL_ANY_PART (expr)->type == GDA_SQL_ANY_EXPR);
 	gda_sql_any_part_set_parent (field->expr, field);
 
-	if (expr && expr->value)
-		_split_identifier_string (g_value_dup_string (expr->value), &(field->table_name), &(field->field_name));
+	if (expr && expr->value) {
+		const gchar *dup;
+		dup = g_value_get_string (expr->value);
+		if (dup && *dup)
+			_split_identifier_string (g_strdup (dup), &(field->table_name), &(field->field_name));
+	}
 }
 
 /**
