@@ -1,23 +1,22 @@
 /*
- * Copyright (C) 2007 - 2011 The GNOME Foundation.
+ * Copyright (C) 2008 Bas Driessen <bas.driessen@xobas.com>
+ * Copyright (C) 2008 - 2011 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2009 - 2010 Murray Cumming <murrayc@murrayc.com>
  *
- * AUTHORS:
- *      Vivien Malerba <malerba@gnome-db.org>
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) any later version.
  *
- * This Library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public License as
- * published by the Free Software Foundation; either version 2 of the
- * License, or (at your option) any later version.
- *
- * This Library is distributed in the hope that it will be useful,
+ * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
+ * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Library General Public
- * License along with this Library; see the file COPYING.LIB.  If not,
- * write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the
+ * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
+ * Boston, MA  02110-1301, USA.
  */
 
 #ifndef _GDA_STATEMENT_STRUCT_PARTS_H
@@ -31,32 +30,75 @@
 #include <libgda/gda-meta-struct.h>
 
 G_BEGIN_DECLS
-
+/*
+ * GdaSqlExpr: (skip)
+ *
+ **/
 typedef struct _GdaSqlExpr      GdaSqlExpr;
+/*
+ * GdaSqlField: (skip)
+ *
+ **/
 typedef struct _GdaSqlField     GdaSqlField;
+/*
+ * GdaSqlTable: (skip)
+ *
+ **/
 typedef struct _GdaSqlTable     GdaSqlTable;
+/*
+ * GdaSqlFunction: (skip)
+ *
+ **/
 typedef struct _GdaSqlFunction  GdaSqlFunction;
+/*
+ * GdaSqlOperation: (skip)
+ *
+ **/
 typedef struct _GdaSqlOperation GdaSqlOperation;
+/*
+ * GdaSqlCase: (skip)
+ *
+ **/
 typedef struct _GdaSqlCase GdaSqlCase;
+/*
+ * GdaSqlSelectField: (skip)
+ *
+ **/
 typedef struct _GdaSqlSelectField GdaSqlSelectField;
+/*
+ * GdaSqlSelectTarget: (skip)
+ *
+ **/
 typedef struct _GdaSqlSelectTarget GdaSqlSelectTarget;
+/*
+ * GdaSqlSelectJoin: (skip)
+ *
+ **/
 typedef struct _GdaSqlSelectJoin GdaSqlSelectJoin;
+/*
+ * GdaSqlSelectFrom: (skip)
+ *
+ **/
 typedef struct _GdaSqlSelectFrom GdaSqlSelectFrom;
+/*
+ * GdaSqlSelectOrder: (skip)
+ *
+ **/
 typedef struct _GdaSqlSelectOrder GdaSqlSelectOrder;
 
 /*
  * Any Expression
  */
 /**
- * GdaSqlExpr:
+ * GdaSqlExpr: (skip)
  * @any: inheritance structure
- * @value: a #GValue, or %NULL. Please see specific note about this field. 
- * @param_spec: a #GdaSqlParamSpec, or %NULL if this is not a variable
- * @func: not %NULL if expression is a function or aggregate
- * @cond: not %NULL if expression is a condition or an operation
- * @select: not %NULL if expression is a sub select statement (#GdaSqlStatementSelect or #GdaSqlStatementCompound)
- * @case_s: not %NULL if expression is a CASE WHEN ... expression
- * @cast_as: not %NULL if expression must be cast to another data type
+ * @value: (allow-none): a #GValue, or %NULL. Please see specific note about this field. 
+ * @param_spec: (allow-none): a #GdaSqlParamSpec, or %NULL if this is not a variable
+ * @func: (allow-none): not %NULL if expression is a function or aggregate
+ * @cond: (allow-none): not %NULL if expression is a condition or an operation
+ * @select: (allow-none): not %NULL if expression is a sub select statement (#GdaSqlStatementSelect or #GdaSqlStatementCompound)
+ * @case_s: (allow-none): not %NULL if expression is a CASE WHEN ... expression
+ * @cast_as: (allow-none): not %NULL if expression must be cast to another data type
  * @value_is_ident: Please see specific note about the @value field
  *
  * This structure contains any expression, either as a value (the @value part is set),
@@ -95,21 +137,19 @@ struct _GdaSqlExpr {
 };
 
 #define GDA_TYPE_SQL_EXPR (gda_sql_expr_get_type())
-
 GType            gda_sql_expr_get_type       (void) G_GNUC_CONST;
 GdaSqlExpr      *gda_sql_expr_new            (GdaSqlAnyPart *parent);
 void             gda_sql_expr_free           (GdaSqlExpr *expr);
 GdaSqlExpr      *gda_sql_expr_copy           (GdaSqlExpr *expr);
 gchar           *gda_sql_expr_serialize      (GdaSqlExpr *expr);
 void             _gda_sql_expr_check_clean   (GdaSqlExpr *expr);
-
 void             gda_sql_expr_take_select    (GdaSqlExpr *expr, GdaSqlStatement *stmt);
 
 /*
  * Any Table's field
  */
 /**
- * GdaSqlField:
+ * GdaSqlField: (skip)
  * any: 
  * @field_name: 
  * @validity_meta_table_column: 
@@ -141,7 +181,7 @@ void             gda_sql_field_take_name      (GdaSqlField *field, GValue *value
  * Any table
  */
 /**
- * GdaSqlTable:
+ * GdaSqlTable: (skip)
  * @any: 
  * @table_name: 
  * @validity_meta_object: 
@@ -174,7 +214,7 @@ void             gda_sql_table_take_name      (GdaSqlTable *table, GValue *value
  * A function with any number of arguments
  */
 /**
- * GdaSqlFunction:
+ * GdaSqlFunction: (skip)
  * @any: inheritance structure
  * @function_name: name of the function , in the form [[catalog.]schema.]function_name
  * @args_list: list of #GdaSqlExpr expressions, one for each argument
@@ -210,7 +250,8 @@ void             gda_sql_function_take_args_list (GdaSqlFunction *function, GSLi
  * @GDA_SQL_OPERATOR_TYPE_OR: 
  * @GDA_SQL_OPERATOR_TYPE_EQ: 
  * @GDA_SQL_OPERATOR_TYPE_IS: 
- * @GDA_SQL_OPERATOR_TYPE_LIKE: 
+ * @GDA_SQL_OPERATOR_TYPE_LIKE:
+ * @GDA_SQL_OPERATOR_TYPE_ILIKE:  
  * @GDA_SQL_OPERATOR_TYPE_BETWEEN: 
  * @GDA_SQL_OPERATOR_TYPE_GT: 
  * @GDA_SQL_OPERATOR_TYPE_LT: 
@@ -269,11 +310,12 @@ typedef enum {
 	GDA_SQL_OPERATOR_TYPE_REM,
 	GDA_SQL_OPERATOR_TYPE_BITAND,
 	GDA_SQL_OPERATOR_TYPE_BITOR,
-	GDA_SQL_OPERATOR_TYPE_BITNOT
+	GDA_SQL_OPERATOR_TYPE_BITNOT,
+	GDA_SQL_OPERATOR_TYPE_ILIKE
 } GdaSqlOperatorType;
 
 /**
- * GdaSqlOperation:
+ * GdaSqlOperation: (skip)
  * @any: inheritance structure
  * @operator_type: 
  * @operands: list of #GdaSqlExpr operands
@@ -302,7 +344,7 @@ GdaSqlOperatorType    gda_sql_operation_operator_from_string (const gchar *op);
  * A CASE expression
  */
 /**
- * GdaSqlCase:
+ * GdaSqlCase: (skip)
  * @any: inheritance structure
  * @base_expr: expression to test
  * @when_expr_list: list of #GdaSqlExpr, one for each WHEN clause
@@ -334,7 +376,7 @@ gchar             *gda_sql_case_serialize      (GdaSqlCase *sc);
  * Any expression in a SELECT ... before the FROM clause
  */
 /**
- * GdaSqlSelectField:
+ * GdaSqlSelectField: (skip)
  * @any: inheritance structure
  * @expr: expression
  * @field_name: field name part of @expr if @expr represents a field
@@ -380,7 +422,7 @@ void               gda_sql_select_field_take_alias     (GdaSqlSelectField *field
  * Any TARGET ... in a SELECT statement
  */
 /**
- * GdaSqlSelectTarget:
+ * GdaSqlSelectTarget: (skip)
  * @any: inheritance structure
  * @expr: expression
  * @table_name: table name part of @expr if @expr represents a table
@@ -440,12 +482,12 @@ typedef enum {
 } GdaSqlSelectJoinType;
 
 /**
- * GdaSqlSelectJoin:
+ * GdaSqlSelectJoin: (skip)
  * @any: inheritance structure
  * @type: type of join
  * @position: represents a join between a target at (pos &lt; @position) and the one at @position
- * @expr: joining expression, or %NULL
- * @use: list of #GdaSqlField pointers to use when joining, or %NULL
+ * @expr: (allow-none): joining expression, or %NULL
+ * @use: (allow-none): list of #GdaSqlField pointers to use when joining, or %NULL
  *
  * This structure represents a join between two targets in a SELECT statement.
  */
@@ -475,10 +517,10 @@ const gchar       *gda_sql_select_join_type_to_string (GdaSqlSelectJoinType type
  * Any FROM ... in a SELECT statement
  */
 /**
- * GdaSqlSelectFrom:
+ * GdaSqlSelectFrom: (skip)
  * @any: inheritance structure
- * @targets: list of #GdaSqlSelectTarget
- * @joins: list of #GdaSqlSelectJoin
+ * @targets: (element-type Gda.SqlSelectTarget): list of #GdaSqlSelectTarget
+ * @joins: (element-type Gda.SqlSelectJoin): list of #GdaSqlSelectJoin
  *
  * This structure represents the FROM clause of a SELECT statement, it lists targets and joins
  */
@@ -506,7 +548,7 @@ void               gda_sql_select_from_take_new_join  (GdaSqlSelectFrom *from, G
  * Any expression in a SELECT ... after the ORDER BY
  */
 /**
- * GdaSqlSelectOrder:
+ * GdaSqlSelectOrder: (skip)
  * @any: inheritance structure
  * @expr: expression to order on
  * @asc: TRUE is ordering is ascending
