@@ -1,7 +1,7 @@
 /*
  * Copyright (C) 2008 - 2009 Bas Driessen <bas.driessen@xobas.com>
- * Copyright (C) 2008 - 2011 Murray Cumming <murrayc@murrayc.com>
- * Copyright (C) 2008 - 2011 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2008 - 2010 Murray Cumming <murrayc@murrayc.com>
+ * Copyright (C) 2008 - 2010 Vivien Malerba <malerba@gnome-db.org>
  * Copyright (C) 2010 David King <davidk@openismus.com>
  * Copyright (C) 2010 Jonh Wendell <jwendell@gnome.org>
  *
@@ -198,8 +198,10 @@ gda_sql_statement_type_to_string (GdaSqlStatementType type)
 {
 	GdaSqlStatementContentsInfo *infos;
 	infos = gda_sql_statement_get_contents_infos (type);
-	if (!infos)
+	if (!infos) {
 		return "NONE";
+		TO_IMPLEMENT;
+	}
 	else
 		return infos->name;
 }
@@ -1050,9 +1052,7 @@ gda_sql_any_part_check_structure (GdaSqlAnyPart *node, GError **error)
 		case GDA_SQL_OPERATOR_TYPE_EQ:
 		case GDA_SQL_OPERATOR_TYPE_IS:
 		case GDA_SQL_OPERATOR_TYPE_LIKE:
-		case GDA_SQL_OPERATOR_TYPE_NOTLIKE:
 		case GDA_SQL_OPERATOR_TYPE_ILIKE:
-		case GDA_SQL_OPERATOR_TYPE_NOTILIKE:
 		case GDA_SQL_OPERATOR_TYPE_GT:
 		case GDA_SQL_OPERATOR_TYPE_LT:
 		case GDA_SQL_OPERATOR_TYPE_GEQ:
