@@ -1,7 +1,6 @@
 /*
  * Copyright (C) 2008 - 2011 Vivien Malerba <malerba@gnome-db.org>
  * Copyright (C) 2010 David King <davidk@openismus.com>
- * Copyright (C) 2012 Daniel Espinosa <despinosa@src.gnome.org>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -83,24 +82,23 @@ static gchar *internal_sql[] = {
 /*
  * predefined statements' GdaStatement
  */
-static GStaticMutex init_mutex = G_STATIC_MUTEX_INIT;
-static GdaStatement **internal_stmt = NULL;
-static GdaSet        *internal_params = NULL;
+static GdaStatement **internal_stmt;
+static GdaSet        *internal_params;
 
 /* 
  * global static values
  */
 static GdaSqlParser *internal_parser = NULL;
-static GValue       *catalog_value = NULL;
-static GValue       *table_type_value = NULL;
-static GValue       *view_type_value = NULL;
-static GValue       *view_check_option = NULL;
-static GValue       *false_value = NULL;
-static GValue       *true_value = NULL;
-static GValue       *zero_value = NULL;
-static GValue       *rule_value_none = NULL;
-static GValue       *rule_value_action = NULL;
-static GdaSet       *pragma_set = NULL;
+static GValue       *catalog_value;
+static GValue       *table_type_value;
+static GValue       *view_type_value;
+static GValue       *view_check_option;
+static GValue       *false_value;
+static GValue       *true_value;
+static GValue       *zero_value;
+static GValue       *rule_value_none;
+static GValue       *rule_value_action;
+static GdaSet       *pragma_set;
 
 static GValue *
 new_caseless_value (const GValue *cvalue)
@@ -153,39 +151,39 @@ to_caseless_string (gchar *string)
 void
 _gda_sqlite_provider_meta_init (GdaServerProvider *provider)
 {
+	static GStaticMutex init_mutex = G_STATIC_MUTEX_INIT;
+	InternalStatementItem i;
+
 	g_static_mutex_lock (&init_mutex);
 
-	if (!internal_stmt) {
-		InternalStatementItem i;
-		internal_parser = gda_server_provider_internal_get_parser (provider);
-		internal_params = gda_set_new (NULL);
+        internal_parser = gda_server_provider_internal_get_parser (provider);
+	internal_params = gda_set_new (NULL);
 
-		internal_stmt = g_new0 (GdaStatement *, sizeof (internal_sql) / sizeof (gchar*));
-		for (i = I_PRAGMA_DATABASE_LIST; i < sizeof (internal_sql) / sizeof (gchar*); i++) {
-			GdaSet *set;
-			internal_stmt[i] = gda_sql_parser_parse_string (internal_parser, internal_sql[i], NULL, NULL);
-			if (!internal_stmt[i])
-				g_error ("Could not parse internal statement: %s\n", internal_sql[i]);
-			g_assert (gda_statement_get_parameters (internal_stmt[i], &set, NULL));
-			if (set) {
-				gda_set_merge_with_set (internal_params, set);
-				g_object_unref (set);
-			}
+        internal_stmt = g_new0 (GdaStatement *, sizeof (internal_sql) / sizeof (gchar*));
+        for (i = I_PRAGMA_DATABASE_LIST; i < sizeof (internal_sql) / sizeof (gchar*); i++) {
+		GdaSet *set;
+                internal_stmt[i] = gda_sql_parser_parse_string (internal_parser, internal_sql[i], NULL, NULL);
+                if (!internal_stmt[i])
+                        g_error ("Could not parse internal statement: %s\n", internal_sql[i]);
+		g_assert (gda_statement_get_parameters (internal_stmt[i], &set, NULL));
+		if (set) {
+			gda_set_merge_with_set (internal_params, set);
+			g_object_unref (set);
 		}
+        }
 
-		g_value_set_string ((catalog_value = gda_value_new (G_TYPE_STRING)), "main");
-		g_value_set_string ((table_type_value = gda_value_new (G_TYPE_STRING)), "BASE TABLE");
-		g_value_set_string ((view_type_value = gda_value_new (G_TYPE_STRING)), "VIEW");
-		g_value_set_string ((view_check_option = gda_value_new (G_TYPE_STRING)), "NONE");
-		g_value_set_boolean ((false_value = gda_value_new (G_TYPE_BOOLEAN)), FALSE);
-		g_value_set_boolean ((true_value = gda_value_new (G_TYPE_BOOLEAN)), TRUE);
-		g_value_set_int ((zero_value = gda_value_new (G_TYPE_INT)), 0);
-		rule_value_none = view_check_option;
-		g_value_set_string ((rule_value_action = gda_value_new (G_TYPE_STRING)), "NO ACTION");
+	g_value_set_string ((catalog_value = gda_value_new (G_TYPE_STRING)), "main");
+	g_value_set_string ((table_type_value = gda_value_new (G_TYPE_STRING)), "BASE TABLE");
+	g_value_set_string ((view_type_value = gda_value_new (G_TYPE_STRING)), "VIEW");
+	g_value_set_string ((view_check_option = gda_value_new (G_TYPE_STRING)), "NONE");
+	g_value_set_boolean ((false_value = gda_value_new (G_TYPE_BOOLEAN)), FALSE);
+	g_value_set_boolean ((true_value = gda_value_new (G_TYPE_BOOLEAN)), TRUE);
+	g_value_set_int ((zero_value = gda_value_new (G_TYPE_INT)), 0);
+	rule_value_none = view_check_option;
+	g_value_set_string ((rule_value_action = gda_value_new (G_TYPE_STRING)), "NO ACTION");
 
-		pragma_set = gda_set_new_inline (2, "tblname", G_TYPE_STRING, "",
-						 "idxname", G_TYPE_STRING, "");
-	}
+	pragma_set = gda_set_new_inline (2, "tblname", G_TYPE_STRING, "",
+					 "idxname", G_TYPE_STRING, "");
 
 	g_static_mutex_unlock (&init_mutex);
 }
@@ -723,20 +721,18 @@ _gda_sqlite_meta_schemata (G_GNUC_UNUSED GdaServerProvider *prov, GdaConnection
 		if (!schema_name_n || 
 		    !gda_value_compare (schema_name_n, cvalue)) {
 			const gchar *cstr;
-			GValue *v1, *v2;
+			GValue *v1;
 
 			cstr = g_value_get_string (cvalue); /* VMA */
 			if (!cstr || !strncmp (cstr, TMP_DATABASE_NAME, 4))
 				continue;
 
 			g_value_set_boolean ((v1 = gda_value_new (G_TYPE_BOOLEAN)), FALSE);
-			g_value_set_boolean ((v2 = gda_value_new (G_TYPE_BOOLEAN)), TRUE);
-			retval = append_a_row (model, error, 5, 
+			retval = append_a_row (model, error, 4, 
 					       FALSE, catalog_value,
 					       TRUE, new_caseless_value (cvalue), 
 					       FALSE, NULL,
-					       TRUE, v1,
-					       TRUE, v2);
+					       TRUE, v1);
 		}
 	}
 	g_object_unref (tmpmodel);
@@ -1611,7 +1607,7 @@ fill_constraints_ref_model (GdaConnection *cnc, G_GNUC_UNUSED SqliteConnectionDa
 		}
 		if ((fkid  == -1) || (fkid != g_value_get_int (cvalue))) {
 			gchar *constname;
-			GValue *v2, *v3, *v4, *v5 = NULL;
+			GValue *v2, *v3, *v4, *v5;
 
 			fkid = g_value_get_int (cvalue);
 
@@ -1897,7 +1893,7 @@ fill_key_columns_model (GdaConnection *cnc, SqliteConnectionData *cdata, GdaData
 		 */
 		GType fk_col_types[] = {G_TYPE_INT, G_TYPE_INT, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_NONE};
 		gint fkid = -1;
-		gint ord_pos = 1;
+		gint ord_pos;
 		stmt = get_statement (I_PRAGMA_FK_LIST, schema_name, g_value_get_string (p_table_name), error);
 		tmpmodel = gda_connection_statement_execute_select_full (cnc, stmt, pragma_set, 
 									 GDA_STATEMENT_MODEL_RANDOM_ACCESS, 
@@ -2382,8 +2378,7 @@ _gda_sqlite_meta_index_cols (G_GNUC_UNUSED GdaServerProvider *prov, G_GNUC_UNUSE
 }
 
 /*
- * @...: a list of TRUE/FALSE, GValue*  -- if TRUE then the following GValue will be freed by
- * this function
+ * @...: a list of TRUE/FALSE, GValue*  -- if TRUE then the following GValue must be freed
  */
 static gboolean 
 append_a_row (GdaDataModel *to_model, GError **error, gint nb, ...)
