@@ -1,6 +1,6 @@
 /*
- * Copyright (C) 2007 - 2012 Vivien Malerba <malerba@gnome-db.org>
- * Copyright (C) 2008 - 2011 Murray Cumming <murrayc@murrayc.com>
+ * Copyright (C) 2007 - 2011 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2008 Murray Cumming <murrayc@murrayc.com>
  * Copyright (C) 2009 Bas Driessen <bas.driessen@xobas.com>
  * Copyright (C) 2010 David King <davidk@openismus.com>
  *
@@ -31,13 +31,6 @@
 
 struct _GdaVconnectionDataModelPrivate {
 	GSList *table_data_list; /* list of GdaVConnectionTableData structures */
-
-#if GLIB_CHECK_VERSION(2,32,0)
-	GMutex        lock_context;
-#else
-	GMutex       *lock_context;
-#endif
-	GdaStatement *executed_stmt;
 };
 
 static void gda_vconnection_data_model_class_init (GdaVconnectionDataModelClass *klass);
@@ -82,7 +75,7 @@ static void
 vtable_dropped (GdaVconnectionDataModel *cnc, const gchar *table_name)
 {
 	GdaVConnectionTableData *td;
-	td = _gda_vconnection_get_table_data_by_name (cnc, table_name);
+	td = gda_vconnection_get_table_data_by_name (cnc, table_name);
 	if (td)
 		cnc->priv->table_data_list = g_slist_remove (cnc->priv->table_data_list, td);
 	_gda_connection_signal_meta_table_update ((GdaConnection *)cnc, table_name);
@@ -143,11 +136,6 @@ gda_vconnection_data_model_init (GdaVconnectionDataModel *cnc, G_GNUC_UNUSED Gda
 {
 	cnc->priv = g_new (GdaVconnectionDataModelPrivate, 1);
 	cnc->priv->table_data_list = NULL;
-#if GLIB_CHECK_VERSION(2,32,0)
-	g_mutex_init (& (cnc->priv->lock_context));
-#else
-	cnc->priv->lock_context = g_mutex_new ();
-#endif
 
 	g_object_set (G_OBJECT (cnc), "cnc-string", "_IS_VIRTUAL=TRUE", NULL);
 }
@@ -168,11 +156,6 @@ gda_vconnection_data_model_dispose (GObject *object)
 		}
 		gda_connection_close_no_warning ((GdaConnection *) cnc);
 
-#if GLIB_CHECK_VERSION(2,32,0)
-		g_mutex_clear (& (cnc->priv->lock_context));
-#else
-		g_mutex_free (cnc->priv->lock_context);
-#endif
 		g_free (cnc->priv);
 		cnc->priv = NULL;
 	}
@@ -347,7 +330,7 @@ gda_vconnection_data_model_add (GdaVconnectionDataModel *cnc, GdaVconnectionData
 			     GDA_SERVER_PROVIDER_INTERNAL_ERROR,
 			     "%s", zErrMsg);
 		SQLITE3_CALL (sqlite3_free) (zErrMsg);
-		_gda_vconnection_data_model_table_data_free (td);
+		gda_vconnection_data_model_table_data_free (td);
 		cnc->priv->table_data_list = g_slist_remove (cnc->priv->table_data_list, td);
 		retval = FALSE;
 	}
@@ -394,7 +377,7 @@ get_rid_of_vtable (GdaVconnectionDataModel *cnc, GdaVConnectionTableData *td, gb
 	g_signal_emit (G_OBJECT (cnc), gda_vconnection_data_model_signals[VTABLE_DROPPED], 0,
 		       td->table_name);
 	/*g_print ("Virtual connection: removed table %s (%p)\n", td->table_name, td->spec->data_model);*/
-	_gda_vconnection_data_model_table_data_free (td);
+	gda_vconnection_data_model_table_data_free (td);
 
 	return allok;
 }
@@ -418,7 +401,7 @@ gda_vconnection_data_model_remove (GdaVconnectionDataModel *cnc, const gchar *ta
 	g_return_val_if_fail (GDA_IS_VCONNECTION_DATA_MODEL (cnc), FALSE);
 	g_return_val_if_fail (table_name && *table_name, FALSE);
 
-	td = _gda_vconnection_get_table_data_by_name (cnc, table_name);
+	td = gda_vconnection_get_table_data_by_name (cnc, table_name);
 	if (!td) {
 		g_set_error (error, GDA_SERVER_PROVIDER_ERROR,
 			     GDA_SERVER_PROVIDER_MISUSE_ERROR,
@@ -448,7 +431,7 @@ gda_vconnection_data_model_get (GdaVconnectionDataModel *cnc, const gchar *table
 	g_return_val_if_fail (GDA_IS_VCONNECTION_DATA_MODEL (cnc), NULL);
 	if (!table_name || !(*table_name))
 		return NULL;
-	td = _gda_vconnection_get_table_data_by_name (cnc, table_name);
+	td = gda_vconnection_get_table_data_by_name (cnc, table_name);
 	if (td)
 		return td->spec;
 	else
@@ -475,7 +458,7 @@ gda_vconnection_data_model_get_model (GdaVconnectionDataModel *cnc, const gchar
 	if (!table_name || !(*table_name))
 		return NULL;
 
-	td = _gda_vconnection_get_table_data_by_name (cnc, table_name);
+	td = gda_vconnection_get_table_data_by_name (cnc, table_name);
 	if (td)
 		return td->spec->data_model;
 	else
@@ -501,7 +484,7 @@ gda_vconnection_data_model_get_table_name (GdaVconnectionDataModel *cnc, GdaData
 		return NULL;
 	g_return_val_if_fail (GDA_IS_DATA_MODEL (model), NULL);
 
-	td = _gda_vconnection_get_table_data_by_model (cnc, model);
+	td = gda_vconnection_get_table_data_by_model (cnc, model);
 	if (td)
 		return td->table_name;
 	else
@@ -543,7 +526,7 @@ gda_vconnection_data_model_foreach (GdaVconnectionDataModel *cnc,
  * private 
  */
 GdaVConnectionTableData *
-_gda_vconnection_get_table_data_by_name (GdaVconnectionDataModel *cnc, const gchar *table_name)
+gda_vconnection_get_table_data_by_name (GdaVconnectionDataModel *cnc, const gchar *table_name)
 {
 	GSList *list;
 	gchar *quoted;
@@ -561,7 +544,7 @@ _gda_vconnection_get_table_data_by_name (GdaVconnectionDataModel *cnc, const gch
 }
 
 GdaVConnectionTableData *
-_gda_vconnection_get_table_data_by_unique_name (GdaVconnectionDataModel *cnc, const gchar *unique_name)
+gda_vconnection_get_table_data_by_unique_name (GdaVconnectionDataModel *cnc, const gchar *unique_name)
 {
 	GSList *list;
 	for (list = cnc->priv->table_data_list; list; list = list->next) {
@@ -572,7 +555,7 @@ _gda_vconnection_get_table_data_by_unique_name (GdaVconnectionDataModel *cnc, co
 }
 
 GdaVConnectionTableData *
-_gda_vconnection_get_table_data_by_model (GdaVconnectionDataModel *cnc, GdaDataModel *model)
+gda_vconnection_get_table_data_by_model (GdaVconnectionDataModel *cnc, GdaDataModel *model)
 {
 	GSList *list;
 	for (list = cnc->priv->table_data_list; list; list = list->next) {
@@ -583,7 +566,7 @@ _gda_vconnection_get_table_data_by_model (GdaVconnectionDataModel *cnc, GdaDataM
 }
 
 void
-_gda_vconnection_data_model_table_data_free (GdaVConnectionTableData *td)
+gda_vconnection_data_model_table_data_free (GdaVConnectionTableData *td)
 {
 	ParamType i;
 
@@ -603,123 +586,5 @@ _gda_vconnection_data_model_table_data_free (GdaVConnectionTableData *td)
 		if (td->modif_stmt[i])
 			g_object_unref (td->modif_stmt[i]);
 	}
-
-	if (td->context.hash)
-		g_hash_table_destroy (td->context.hash);
 	g_free (td);
 }
-
-static void
-vcontext_object_weak_notify_cb (VContext *context, GObject *old_context_object)
-{
-	g_assert (context);
-	g_mutex_lock (context->vtable->context.mutex);
-	context->context_object = NULL;
-	g_hash_table_remove (context->vtable->context.hash, old_context_object);
-	g_mutex_unlock (context->vtable->context.mutex);
-}
-
-static void
-vcontext_free (VContext *context)
-{
-	if (context->context_object)
-		g_object_weak_unref (context->context_object,
-				     (GWeakNotify) vcontext_object_weak_notify_cb, context);
-	if (context->context_data) {
-		guint i;
-		for (i = 0; i < context->context_data->len; i++) {
-			VirtualFilteredData *data;
-			data = g_array_index (context->context_data, VirtualFilteredData*, i);
-			_gda_vconnection_virtual_filtered_data_unref (data);
-		}
-		g_array_free (context->context_data, TRUE);
-	}
-	g_free (context);
-#ifdef DEBUG_VCONTEXT
-	g_print ("VCFree %p\n", context);
-#endif
-}
-
-void
-_gda_vconnection_set_working_obj (GdaVconnectionDataModel *cnc, GObject *obj)
-{
-	GSList *list;
-	if (obj) {
-#if GLIB_CHECK_VERSION(2,32,0)
-		g_mutex_lock (& (cnc->priv->lock_context));
-#else
-		g_mutex_lock (cnc->priv->lock_context);
-#endif
-		for (list = cnc->priv->table_data_list; list; list = list->next) {
-			GdaVConnectionTableData *td = (GdaVConnectionTableData*) list->data;
-			VContext *vc = NULL;
-			
-			g_assert (!td->context.current_vcontext);
-#if GLIB_CHECK_VERSION(2,32,0)
-			td->context.mutex = &(cnc->priv->lock_context);
-#else
-			td->context.mutex = cnc->priv->lock_context;
-#endif
-			if (! td->context.hash)
-				td->context.hash = g_hash_table_new_full (g_direct_hash, g_direct_equal,
-									  NULL, (GDestroyNotify) vcontext_free);
-			else
-				vc = g_hash_table_lookup (td->context.hash, obj);
-
-			if (! vc) {
-				vc = g_new0 (VContext, 1);
-				vc->context_object = obj;
-				vc->context_data = g_array_new (FALSE, FALSE,
-								sizeof (VirtualFilteredData*));
-				vc->vtable = td;
-				g_object_weak_ref (obj, (GWeakNotify) vcontext_object_weak_notify_cb, vc);
-				g_hash_table_insert (td->context.hash, obj, vc);
-#ifdef DEBUG_VCONTEXT
-				g_print ("VCNew %p\n", vc);
-#endif
-			}
-			td->context.current_vcontext = vc;
-		}
-	}
-	else {
-		for (list = cnc->priv->table_data_list; list; list = list->next) {
-			GdaVConnectionTableData *td = (GdaVConnectionTableData*) list->data;
-			/* REM: td->context.current_vcontext may already be NULL in case
-			 * an exception already occurred */
-			td->context.current_vcontext = NULL;
-		}
-#if GLIB_CHECK_VERSION(2,32,0)
-		g_mutex_unlock (& (cnc->priv->lock_context));
-#else
-		g_mutex_unlock (cnc->priv->lock_context);
-#endif
-	}
-}
-
-void
-_gda_vconnection_change_working_obj (GdaVconnectionDataModel *cnc, GObject *obj)
-{
-	GSList *list;
-
-	for (list = cnc->priv->table_data_list; list; list = list->next) {
-		GdaVConnectionTableData *td = (GdaVConnectionTableData*) list->data;
-		if (!td->context.hash)
-			continue;
-
-		g_assert (td->context.current_vcontext);
-
-		VContext *ovc, *nvc;
-		ovc = td->context.current_vcontext;
-		nvc = g_new0 (VContext, 1);
-		nvc->context_object = obj;
-		nvc->vtable = ovc->vtable;
-		nvc->context_data = ovc->context_data;
-		ovc->context_data = NULL;
-		g_object_weak_ref (obj, (GWeakNotify) vcontext_object_weak_notify_cb, nvc);
-		g_hash_table_insert (td->context.hash, obj, nvc);
-#ifdef DEBUG_VCONTEXT
-		g_print ("VCNew %p\n", nvc);
-#endif
-		g_hash_table_remove (td->context.hash, ovc->context_object);
-	}
-}
