@@ -97,23 +97,25 @@ gda_virtual_connection_get_type (void)
 	static GType type = 0;
 
 	if (G_UNLIKELY (type == 0)) {
-		static GMutex registering;
-		static GTypeInfo info = {
-			sizeof (GdaVirtualConnectionClass),
-			(GBaseInitFunc) NULL,
-			(GBaseFinalizeFunc) NULL,
-			(GClassInitFunc) gda_virtual_connection_class_init,
-			NULL, NULL,
-			sizeof (GdaVirtualConnection),
-			0,
-			(GInstanceInitFunc) gda_virtual_connection_init,
-			0
-		};
+		static GStaticMutex registering = G_STATIC_MUTEX_INIT;
+		if (type == 0) {
+			static GTypeInfo info = {
+				sizeof (GdaVirtualConnectionClass),
+				(GBaseInitFunc) NULL,
+				(GBaseFinalizeFunc) NULL,
+				(GClassInitFunc) gda_virtual_connection_class_init,
+				NULL, NULL,
+				sizeof (GdaVirtualConnection),
+				0,
+				(GInstanceInitFunc) gda_virtual_connection_init,
+				0
+			};
 			
-		g_mutex_lock (&registering);
+		g_static_mutex_lock (&registering);
 		if (type == 0)
 			type = g_type_register_static (PARENT_TYPE, "GdaVirtualConnection", &info, G_TYPE_FLAG_ABSTRACT);
-		g_mutex_unlock (&registering);
+		g_static_mutex_unlock (&registering);
+		}
 	}
 
 	return type;
