@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2009 Bas Driessen <bas.driessen@xobas.com>
- * Copyright (C) 2009 - 2012 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2009 - 2010 Vivien Malerba <malerba@gnome-db.org>
  * Copyright (C) 2010 David King <davidk@openismus.com>
  *
  * This library is free software; you can redistribute it and/or
@@ -327,8 +327,7 @@ gda_thread_provider_create_connection (GdaServerProvider *provider)
 	GdaConnection *cnc;
         g_return_val_if_fail (GDA_IS_THREAD_PROVIDER (provider), NULL);
 
-        cnc = g_object_new (GDA_TYPE_CONNECTION, "provider", provider, NULL);
-	_gda_connection_define_as_thread_wrapper (cnc);
+        cnc = g_object_new (GDA_TYPE_CONNECTION, "provider", provider, "is-wrapper", TRUE, NULL);
 
         return cnc;
 }
@@ -341,7 +340,7 @@ gda_thread_provider_create_connection (GdaServerProvider *provider)
 typedef struct {
 	const gchar *dsn;
 
-	gchar *prov_name;
+	const gchar *prov_name;
 	const gchar *cnc_string;
 
 	const gchar *auth_string;
@@ -399,16 +398,17 @@ create_connection_data (GdaServerProvider *provider, GdaConnection *cnc, GdaQuar
 						  dsninfo->provider);
 	}
 	else if (cnc_string) {
-		const gchar *tmp;
 		data = g_new0 (NewConnectionData, 1);
 		if (params) {
-			tmp = gda_quark_list_find (params, "PROVIDER_NAME");
-			data->prov_name = tmp ? g_strdup (tmp) : NULL;
+			data->prov_name = gda_quark_list_find (params, "PROVIDER_NAME");
+			if (data->prov_name)
+				data->prov_name = g_strdup (data->prov_name);
 		}
 		else {
 			params = gda_quark_list_new_from_string (cnc_string);
-			tmp = gda_quark_list_find (params, "PROVIDER_NAME");
-			data->prov_name = tmp ? g_strdup (tmp) : NULL;
+			data->prov_name = gda_quark_list_find (params, "PROVIDER_NAME");
+			if (data->prov_name)
+				data->prov_name = g_strdup (data->prov_name);
 			gda_quark_list_free (params);
 			params = NULL;
 		}
@@ -1640,7 +1640,6 @@ gda_thread_provider_statement_prepare (GdaServerProvider *provider, GdaConnectio
 typedef struct {
 	GdaServerProvider *prov;
 	GdaConnection *cnc;
-	guint exec_slowdown;
 	GdaStatement *stmt;
 	GdaSet *params;
 	GdaStatementModelUsage model_usage;
@@ -1658,11 +1657,12 @@ sub_thread_execute_statement (ExecuteStatementData *data, GError **error)
 	/* WARNING: function executed in sub thread! */
 	GObject *retval;
 	
-	if (data->exec_slowdown) {
-		g_print ("Starting sleeping in thread %p...\n", g_thread_self ());
-		g_usleep (data->exec_slowdown);
-		g_print ("End sleeping in thread %p\n", g_thread_self ());
-	}
+#ifdef GDA_DEBUG_NO
+	g_print ("%p Starting sleep in %s()...\n", g_thread_self (), __FUNCTION__);
+	sleep (10);
+	g_print ("%p finished sleeping in %s().\n", g_thread_self (), __FUNCTION__);
+#endif
+
 	retval = PROV_CLASS (data->prov)->statement_execute (data->prov,
 							     data->cnc,
 							     data->stmt,
@@ -1677,19 +1677,11 @@ sub_thread_execute_statement (ExecuteStatementData *data, GError **error)
 #endif
 
 	if (GDA_IS_DATA_MODEL (retval)) {
-		if (GDA_IS_DATA_SELECT (retval) && (data->model_usage & GDA_STATEMENT_MODEL_OFFLINE) &&
-		    ! gda_data_select_prepare_for_offline ((GdaDataSelect*) retval, error)) {
-			g_object_unref (retval);
-			retval = NULL;
-		}
-
-		if (retval) {
-			/* substitute the GdaDataSelect with a GdaThreadRecordset */
-			GdaDataModel *model;
-			model = _gda_thread_recordset_new (data->real_cnc, data->wrapper, GDA_DATA_MODEL (retval));
-			g_object_unref (retval);
-			retval = (GObject*) model;
-		}
+		/* substitute the GdaDataSelect with a GdaThreadRecordset */
+		GdaDataModel *model;
+		model = _gda_thread_recordset_new (data->real_cnc, data->wrapper, GDA_DATA_MODEL (retval));
+		g_object_unref (retval);
+		retval = (GObject*) model;
 	}
 
 	return retval;
@@ -1718,13 +1710,12 @@ gda_thread_provider_statement_execute (GdaServerProvider *provider, GdaConnectio
 			     "%s", _("Connection is closed"));
 		return NULL;
 	}
-
+	
 	if (async_cb) {
 		ExecuteStatementData *wdata;
 		wdata = g_new0 (ExecuteStatementData, 1);
 		wdata->prov = cdata->cnc_provider;
 		wdata->cnc = cdata->sub_connection;
-		g_object_get (cnc, "execution-slowdown", &(wdata->exec_slowdown), NULL);
 		wdata->stmt = stmt;
 		wdata->params = params;
 		wdata->model_usage = model_usage;
@@ -1754,7 +1745,6 @@ gda_thread_provider_statement_execute (GdaServerProvider *provider, GdaConnectio
 
 		wdata.prov = cdata->cnc_provider;
 		wdata.cnc = cdata->sub_connection;
-		g_object_get (cnc, "execution-slowdown", &(wdata.exec_slowdown), NULL);
 		wdata.stmt = stmt;
 		wdata.params = params;
 		wdata.model_usage = model_usage;
