@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2008 - 2011 Murray Cumming <murrayc@murrayc.com>
+ * Copyright (C) 2008 Murray Cumming <murrayc@murrayc.com>
  * Copyright (C) 2008 - 2011 Vivien Malerba <malerba@gnome-db.org>
  * Copyright (C) 2009 Bas Driessen <bas.driessen@xobas.com>
  * Copyright (C) 2010 David King <davidk@openismus.com>
@@ -145,8 +145,7 @@ static void gda_jdbc_free_cnc_data (JdbcConnectionData *cdata);
  * TO_ADD: any prepared statement to be used internally by the provider should be
  *         declared here, as constants and as SQL statements
  */
-static GStaticMutex init_mutex = G_STATIC_MUTEX_INIT;
-static GdaStatement **internal_stmt = NULL;
+static GdaStatement **internal_stmt;
 
 typedef enum {
 	INTERNAL_STMT1
@@ -267,27 +266,21 @@ extern JavaVM *_jdbc_provider_java_vm;
 static void
 gda_jdbc_provider_init (GdaJdbcProvider *jdbc_prv, G_GNUC_UNUSED GdaJdbcProviderClass *klass)
 {
-	g_static_mutex_lock (&init_mutex);
+	InternalStatementItem i;
+	GdaSqlParser *parser;
 
-	if (!internal_stmt) {
-		InternalStatementItem i;
-		GdaSqlParser *parser;
-
-		parser = gda_server_provider_internal_get_parser ((GdaServerProvider*) jdbc_prv);
-		internal_stmt = g_new0 (GdaStatement *, sizeof (internal_sql) / sizeof (gchar*));
-		for (i = INTERNAL_STMT1; i < sizeof (internal_sql) / sizeof (gchar*); i++) {
-			internal_stmt[i] = gda_sql_parser_parse_string (parser, internal_sql[i], NULL, NULL);
-			if (!internal_stmt[i])
-				g_error ("Could not parse internal statement: %s\n", internal_sql[i]);
-		}
+	parser = gda_server_provider_internal_get_parser ((GdaServerProvider*) jdbc_prv);
+	internal_stmt = g_new0 (GdaStatement *, sizeof (internal_sql) / sizeof (gchar*));
+	for (i = INTERNAL_STMT1; i < sizeof (internal_sql) / sizeof (gchar*); i++) {
+		internal_stmt[i] = gda_sql_parser_parse_string (parser, internal_sql[i], NULL, NULL);
+		if (!internal_stmt[i]) 
+			g_error ("Could not parse internal statement: %s\n", internal_sql[i]);
 	}
 
 	/* meta data init */
 	_gda_jdbc_provider_meta_init ((GdaServerProvider*) jdbc_prv);
 
 	/* TO_ADD: any other provider's init should be added here */
-
-	g_static_mutex_unlock (&init_mutex);
 }
 
 GType
@@ -482,7 +475,7 @@ gda_jdbc_provider_get_server_version (GdaServerProvider *provider, GdaConnection
 		return FALSE;
 
 	if (! cdata->server_version && cdata->jcnc_obj) {
-		JNIEnv *jenv = NULL;
+		JNIEnv *jenv;
 		gboolean jni_detach;
 		GError *error = NULL;
 
@@ -955,7 +948,7 @@ gda_jdbc_provider_get_data_handler (GdaServerProvider *provider, GdaConnection *
                 }
 	}
 	else
-		dh = gda_server_provider_handler_use_default (provider, type);
+		dh = gda_server_provider_get_data_handler_default (provider, cnc, type, dbms_type);
 
 	return dh;
 }
@@ -1084,14 +1077,13 @@ gda_jdbc_provider_statement_prepare (GdaServerProvider *provider, GdaConnection
                 return FALSE;
         sql = gda_jdbc_provider_statement_to_sql (provider, cnc, stmt, params, GDA_STATEMENT_SQL_PARAMS_AS_UQMARK,
 						  &used_params, error);
-
-	JNIEnv *jenv = NULL;
         if (!sql)
 		goto out;
 
 	/* prepare @stmt using the C API, creates @ps */
 	GValue *pstmt_obj;
-	gboolean jni_detach = FALSE;
+	JNIEnv *jenv = NULL;
+	gboolean jni_detach;
 	jstring jsql;
 	
 	jenv = _gda_jdbc_get_jenv (&jni_detach, error);
@@ -1791,7 +1783,7 @@ gda_jdbc_free_cnc_data (JdbcConnectionData *cdata)
 
 	if (cdata->jcnc_obj) {
 		/* force the connection to be closed */
-		JNIEnv *jenv = NULL;
+		JNIEnv *jenv;
 		gboolean jni_detach;
 		GError *error = NULL;
 
