@@ -6,7 +6,7 @@
  * Copyright (C) 2004 Julio M. Merino Vidal <jmmv@menta.net>
  * Copyright (C) 2004 Jrg Billeter <j@bitron.ch>
  * Copyright (C) 2004 Szalai Ferenc <szferi@einstein.ki.iif.hu>
- * Copyright (C) 2005 - 2012 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2005 - 2011 Vivien Malerba <malerba@gnome-db.org>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -223,109 +223,6 @@ compute_data_file_name (GdaQuarkList *params, gboolean is_cache, const gchar *da
 	return fname;
 }
 
-typedef struct {
-	gchar *filter_format;
-	gchar *attribute;
-} LdapAuthMapping;
-
-LdapAuthMapping mappings[] = {
-	{"(&(uid=%s)(objectclass=inetOrgPerson))", "uid"},
-	{"(sAMAccountName=%s)", "sAMAccountName"}, /* Active Directory */
-};
-
-/*
- * Using @url and @username, performs the following tasks:
- * - bind to the LDAP server anonymously
- * - search the directory to identify the entry for the provided user name,
- *   filter: (&(uid=##uid)(objectclass=inetOrgPerson))
- * - if one and only one entry is returned, get the DN of the entry and check that the UID is correct
- *
- * If all the steps are right, it returns the DN of the identified entry as a new string.
- */
-static gchar *
-fetch_user_dn (const gchar *url, const gchar *base, const gchar *username, LdapAuthMapping *mapping)
-{
-	LDAP *ld;
-	int res;
-	int version = LDAP_VERSION3;
-	gchar *dn = NULL;
-	LDAPMessage *msg = NULL;
-
-	if (! username)
-		return NULL;
-
-	res = ldap_initialize (&ld, url);
-	if (res != LDAP_SUCCESS)
-		return NULL;
-
-	res = ldap_set_option (ld, LDAP_OPT_PROTOCOL_VERSION, &version);
-        if (res != LDAP_SUCCESS) {
-		if (res == LDAP_PROTOCOL_ERROR) {
-			version = LDAP_VERSION2;
-			res = ldap_set_option (ld, LDAP_OPT_PROTOCOL_VERSION, &version);
-		}
-		if (res != LDAP_SUCCESS)
-			goto out;
-        }
-
-	struct berval cred;
-        memset (&cred, 0, sizeof (cred));
-	res = ldap_sasl_bind_s (ld, NULL, NULL, &cred, NULL, NULL, NULL);
-	if (res != LDAP_SUCCESS)
-		goto out;
-
-	gchar *filter;
-	gchar *attributes[] = {NULL, NULL};
-	attributes[0] = mapping->attribute;
-	filter = g_strdup_printf (mapping->filter_format, username);
-	res = ldap_search_ext_s (ld, base, LDAP_SCOPE_SUBTREE,
-				 filter, attributes, 0,
-				 NULL, NULL, NULL, 2, &msg);
-	g_free (filter);
-	if (res != LDAP_SUCCESS)
-		goto out;
-
-	LDAPMessage *ldap_row;
-	for (ldap_row = ldap_first_entry (ld, msg);
-	     ldap_row;
-	     ldap_row = ldap_next_entry (ld, ldap_row)) {
-		char *attr, *uid;
-		attr = ldap_get_dn (ld, ldap_row);
-		if (attr) {
-			BerElement* ber;
-			for (uid = ldap_first_attribute (ld, ldap_row, &ber);
-			     uid;
-			     uid = ldap_next_attribute (ld, ldap_row, ber)) {
-				BerValue **bvals;
-				bvals = ldap_get_values_len (ld, ldap_row, uid);
-				if (!bvals || !bvals[0] || bvals[1] || strcmp (bvals[0]->bv_val, username)) {
-					g_free (dn);
-					dn = NULL;
-				}
-				ldap_value_free_len (bvals);
-				ldap_memfree (uid);
-			}
-
-			if (dn) {
-				/* more than 1 entry => unique DN could not be identified */
-				g_free (dn);
-				dn = NULL;
-				goto out;
-			}
-
-			dn = g_strdup (attr);
-			ldap_memfree (attr);
-		}
-	}
-
- out:
-	if (msg)
-		ldap_msgfree (msg);
-	ldap_unbind_ext (ld, NULL, NULL);
-	/*g_print ("Identified DN: [%s]\n", dn);*/
-	return dn;
-}
-
 /* 
  * Open connection request
  *
@@ -360,19 +257,13 @@ gda_ldap_provider_open_connection (GdaServerProvider *provider, GdaConnection *c
 	const gchar *tmp;
 	const gchar *port;
 	const gchar *user = NULL;
-	gchar *dnuser = NULL;
         const gchar *pwd = NULL;
-        const gchar *time_limit = NULL;
-        const gchar *size_limit = NULL;
-        const gchar *tls_method = NULL;
-        const gchar *tls_cacert = NULL;
-	int rtls_method = -1;
 	gint rport;
 	gboolean use_ssl, use_cache;
 
         base_dn = gda_quark_list_find (params, "DB_NAME");
         if (!base_dn) {
-                gda_connection_add_event_string (cnc, "%s",
+                gda_connection_add_event_string (cnc,
                                                  _("The connection string must contain the DB_NAME value"));
                 return FALSE;
         }
@@ -399,111 +290,26 @@ gda_ldap_provider_open_connection (GdaServerProvider *provider, GdaConnection *c
         if (!pwd)
                 pwd = gda_quark_list_find (params, "PASSWORD");
 
-	tls_cacert = gda_quark_list_find (params, "TLS_CACERT");
-	tls_method = gda_quark_list_find (params, "TLS_REQCERT");
-	if (tls_method && *tls_method) {
-		if (! g_ascii_strcasecmp (tls_method, "never"))
-			rtls_method = LDAP_OPT_X_TLS_NEVER;
-		else if (! g_ascii_strcasecmp (tls_method, "hard"))
-			rtls_method = LDAP_OPT_X_TLS_HARD;
-		else if (! g_ascii_strcasecmp (tls_method, "demand"))
-			rtls_method = LDAP_OPT_X_TLS_DEMAND;
-		else if (! g_ascii_strcasecmp (tls_method, "allow"))
-			rtls_method = LDAP_OPT_X_TLS_ALLOW;
-		else if (! g_ascii_strcasecmp (tls_method, "try"))
-			rtls_method = LDAP_OPT_X_TLS_TRY;
-		else {
-			gda_connection_add_event_string (cnc, "%s",
-							 _("Invalid value for 'TLS_REQCERT'"));
-			return FALSE;
-		}
-	}
-	time_limit = gda_quark_list_find (params, "TIME_LIMIT");
-	size_limit = gda_quark_list_find (params, "SIZE_LIMIT");
-
 	/* open LDAP connection */
 	LdapConnectionData *cdata;
 	LDAP *ld;
         int res;
 	gchar *url;
-
-	if (use_ssl) {
-		/* Configuring SSL/TLS options:
-		 * this is for texting purpose only, and should actually be done through LDAP's conf.
-		 * files, see: man 5 ldap.conf
-		 *
-		 * For example ~/.ldaprc can contain:
-		 * TLS_REQCERT demand
-		 * TLS_CACERT /usr/share/ca-certificates/mozilla/Thawte_Premium_Server_CA.crt
-		 *
-		 * Note: if server certificate verification fails,
-		 * the error message is: "Can't contact LDAP server"
-		 */
-		if (rtls_method >= 0) {
-			res = ldap_set_option (NULL, LDAP_OPT_X_TLS_REQUIRE_CERT, &rtls_method);
-			if (res != LDAP_SUCCESS) {
-				gda_connection_add_event_string (cnc, ldap_err2string (res));
-				return FALSE;
-			}
-		}
-
-		if (tls_cacert && *tls_cacert) {
-			res = ldap_set_option (NULL, LDAP_OPT_X_TLS_CACERTFILE, tls_cacert);
-			if (res != LDAP_SUCCESS) {
-				gda_connection_add_event_string (cnc, ldap_err2string (res));
-				return FALSE;
-			}
-		}
-
+	if (use_ssl)
 		url = g_strdup_printf ("ldaps://%s:%d", host, rport);
-	}
 	else
 		url = g_strdup_printf ("ldap://%s:%d", host, rport);
-
-	if (user && *user && ! gda_ldap_parse_dn (user, NULL)) {
-		/* analysing the @user parameter */
-		/* the user name is not a DN => we need to fetch the DN of the entry
-		 * using filters defined in the "mappings" array @user */
-		guint i;
-		const gchar *ptr;
-		GString *rname;
-		rname = g_string_new ("");
-		for (ptr = user; *ptr; ptr++) {
-			if ((*ptr == ',') || (*ptr == '\\') || (*ptr == '#') ||
-			    (*ptr == '+') || (*ptr == '<') ||
-			    (*ptr == '>') || (*ptr == ';') || (*ptr == '"') ||
-			    (*ptr == '=') || (*ptr == '*'))
-				g_string_append_c (rname, '\\');
-			g_string_append_c (rname, *ptr);
-		}
-		for (i = 0; i < sizeof (mappings) / sizeof (LdapAuthMapping); i++) {
-			gchar *tmp;
-			tmp = fetch_user_dn (url, base_dn, rname->str, &(mappings[i]));
-			if (tmp) {
-				dnuser = tmp;
-				break;
-			}
-		}
-		g_string_free (rname, TRUE);
-
-		/* if no DN user has been found, then still use the provided name AS IS
-		 * => dnuser can be %NULL here */
-	}
-
 	res = ldap_initialize (&ld, url);
+
         if (res != LDAP_SUCCESS) {
 		gda_connection_add_event_string (cnc, ldap_err2string (res));
 		g_free (url);
-		g_free (dnuser);
                 return FALSE;
         }
 
 	cdata = g_new0 (LdapConnectionData, 1);
-	cdata->keep_bound_count = 0;
 	cdata->handle = ld;
 	cdata->url = url;
-	cdata->time_limit = 0;
-	cdata->size_limit = 0;
 	cdata->base_dn = g_strdup (base_dn);
 	if (use_cache)
 		cdata->attributes_cache_file = compute_data_file_name (params, TRUE, "attrs");
@@ -519,74 +325,49 @@ gda_ldap_provider_open_connection (GdaServerProvider *provider, GdaConnection *c
 		if (res != LDAP_SUCCESS) {
 			gda_connection_add_event_string (cnc, ldap_err2string (res));
 			gda_ldap_free_cnc_data (cdata);
-			g_free (dnuser);
 			return FALSE;
 		}
         }
+	res = ldap_set_option (cdata->handle, LDAP_OPT_RESTART, LDAP_OPT_ON);
 
-	/* time limit */
-	if (time_limit && *time_limit) {
-		int limit = atoi (time_limit);
-		res = ldap_set_option (cdata->handle, LDAP_OPT_TIMELIMIT, &limit);
+#ifdef NO
+	if (use_ssl) {
+		/* Configuring SSL/TLS options:
+		 * this is for texting purpose only, and should actually be done through LDAP's conf.
+		 * files, see: man 5 ldap.conf
+		 *
+		 * For example ~/.ldaprc can contain:
+		 * TLS_REQCERT demand
+		 * TLS_CACERT /usr/share/ca-certificates/mozilla/Thawte_Premium_Server_CA.crt
+		 *
+		 * Note: if server certificate verification fails,
+		 * the error message is: "Can't contact LDAP server"
+		 */
+		int opt = LDAP_OPT_X_TLS_DEMAND;
+		res = ldap_set_option (cdata->handle, LDAP_OPT_X_TLS_REQUIRE_CERT, &opt);
 		if (res != LDAP_SUCCESS) {
 			gda_connection_add_event_string (cnc, ldap_err2string (res));
 			gda_ldap_free_cnc_data (cdata);
-			g_free (dnuser);
 			return FALSE;
 		}
-		cdata->time_limit = limit;
-	}
-
-	/* size limit */
-	if (size_limit && *size_limit) {
-		int limit = atoi (size_limit);
-		res = ldap_set_option (cdata->handle, LDAP_OPT_SIZELIMIT, &limit);
-		if (res != LDAP_SUCCESS) {
-			gda_connection_add_event_string (cnc, ldap_err2string (res));
-			gda_ldap_free_cnc_data (cdata);
-			g_free (dnuser);
-			return FALSE;
-		}
-		cdata->size_limit = limit;
 	}
+#endif
 
 	/* authentication */
 	struct berval cred;
         memset (&cred, 0, sizeof (cred));
         cred.bv_len = pwd && *pwd ? strlen (pwd) : 0;
         cred.bv_val = pwd && *pwd ? (char *) pwd : NULL;
-        res = ldap_sasl_bind_s (ld, dnuser ? dnuser : user, NULL, &cred, NULL, NULL, NULL);
+        res = ldap_sasl_bind_s (ld, user, NULL, &cred, NULL, NULL, NULL);
 	if (res != LDAP_SUCCESS) {
 		gda_connection_add_event_string (cnc, ldap_err2string (res));
 		gda_ldap_free_cnc_data (cdata);
-		g_free (dnuser);
                 return FALSE;
 	}
-	if (pwd) {
-		gchar *tmp;
-		tmp = g_strdup_printf ("PASSWORD=%s", pwd);
-		cdata->auth = gda_quark_list_new_from_string (tmp);
-		g_free (tmp);
-	}
-	if (dnuser) {
-		gchar *tmp;
-		tmp = g_strdup_printf ("USERNAME=%s", dnuser);
-		if (cdata->auth)
-			gda_quark_list_add_from_string (cdata->auth, tmp, FALSE);
-		else
-			cdata->auth = gda_quark_list_new_from_string (tmp);
-		g_free (tmp);
-		dnuser = NULL;
-	}
-	else if (user) {
-		gchar *tmp;
-		tmp = g_strdup_printf ("USERNAME=%s", user);
-		if (cdata->auth)
-			gda_quark_list_add_from_string (cdata->auth, tmp, FALSE);
-		else
-			cdata->auth = gda_quark_list_new_from_string (tmp);
-		g_free (tmp);
-	}
+	if (pwd)
+		cdata->pass = g_strdup (pwd);
+	if (user)
+		cdata->user = g_strdup (user);
 
 	/* set startup file name */
 	gchar *fname;
@@ -606,46 +387,16 @@ gda_ldap_provider_open_connection (GdaServerProvider *provider, GdaConnection *c
                 return FALSE;
         }
 
-	gda_ldap_may_unbind (cdata);
 	return TRUE;
 }
 
-/*
- * Unbinds the connection if possible (i.e. if cdata->keep_bound_count is 0)
- * This allows to avoid keeping the connection to the LDAP server if unused
- */
-void
-gda_ldap_may_unbind (LdapConnectionData *cdata)
-{
-	if (!cdata || (cdata->keep_bound_count > 0))
-		return;
-	if (cdata->handle) {
-                ldap_unbind_ext (cdata->handle, NULL, NULL);
-		cdata->handle = NULL;
-	}
-}
-
-/*
- * Makes sure the connection is opened
- */
-gboolean
-gda_ldap_ensure_bound (LdapConnectionData *cdata, GError **error)
-{
-	if (!cdata)
-		return FALSE;
-	else if (cdata->handle)
-		return TRUE;
-
-	return gda_ldap_rebind (cdata, error);
-}
-
 /*
  * Reopens a connection after the server has closed it (possibly because of a timeout)
  *
  * If it fails, then @cdata is left unchanged, otherwise it is modified to be useable again.
  */
 gboolean
-gda_ldap_rebind (LdapConnectionData *cdata, GError **error)
+gda_ldap_silently_rebind (LdapConnectionData *cdata)
 {
 	if (!cdata)
 		return FALSE;
@@ -654,11 +405,8 @@ gda_ldap_rebind (LdapConnectionData *cdata, GError **error)
 	LDAP *ld;
 	int res;
 	res = ldap_initialize (&ld, cdata->url);
-	if (res != LDAP_SUCCESS) {
-		g_set_error (error, GDA_CONNECTION_ERROR, GDA_CONNECTION_OPEN_ERROR,
-			     "%s", ldap_err2string (res));
+	if (res != LDAP_SUCCESS)
 		return FALSE;
-	}
 
 	/* set protocol version to 3 by default */
 	int version = LDAP_VERSION3;
@@ -669,8 +417,6 @@ gda_ldap_rebind (LdapConnectionData *cdata, GError **error)
 			res = ldap_set_option (ld, LDAP_OPT_PROTOCOL_VERSION, &version);
 		}
 		if (res != LDAP_SUCCESS) {
-			g_set_error (error, GDA_CONNECTION_ERROR, GDA_CONNECTION_OPEN_ERROR,
-				     "%s", ldap_err2string (res));
 			ldap_unbind_ext (ld, NULL, NULL);
 			return FALSE;
 		}
@@ -678,43 +424,13 @@ gda_ldap_rebind (LdapConnectionData *cdata, GError **error)
 
 	/* authentication */
 	struct berval cred;
-	const gchar *pwd = "";
-	const gchar *user = "";
-	if (cdata->auth)
-		pwd = gda_quark_list_find (cdata->auth, "PASSWORD");
+	const gchar *pwd;
+	pwd = cdata->pass;
         memset (&cred, 0, sizeof (cred));
         cred.bv_len = pwd && *pwd ? strlen (pwd) : 0;
         cred.bv_val = pwd && *pwd ? (char *) pwd : NULL;
-
-	if (cdata->auth)
-		user = gda_quark_list_find (cdata->auth, "USERNAME");
-	res = ldap_sasl_bind_s (ld, user, NULL, &cred, NULL, NULL, NULL);
-	if (cdata->auth)
-		gda_quark_list_protect_values (cdata->auth);
-
+	res = ldap_sasl_bind_s (ld, cdata->user, NULL, &cred, NULL, NULL, NULL);
 	if (res != LDAP_SUCCESS) {
-		g_set_error (error, GDA_CONNECTION_ERROR, GDA_CONNECTION_OPEN_ERROR,
-			     "%s", ldap_err2string (res));
-		ldap_unbind_ext (ld, NULL, NULL);
-                return FALSE;
-	}
-
-	/* time limit */
-	int limit = cdata->time_limit;
-	res = ldap_set_option (cdata->handle, LDAP_OPT_TIMELIMIT, &limit);
-	if (res != LDAP_SUCCESS) {
-		g_set_error (error, GDA_CONNECTION_ERROR, GDA_CONNECTION_OPEN_ERROR,
-			     "%s", ldap_err2string (res));
-		ldap_unbind_ext (ld, NULL, NULL);
-                return FALSE;
-	}
-
-	/* size limit */
-	limit = cdata->size_limit;
-	res = ldap_set_option (cdata->handle, LDAP_OPT_SIZELIMIT, &limit);
-	if (res != LDAP_SUCCESS) {
-		g_set_error (error, GDA_CONNECTION_ERROR, GDA_CONNECTION_OPEN_ERROR,
-			     "%s", ldap_err2string (res));
 		ldap_unbind_ext (ld, NULL, NULL);
                 return FALSE;
 	}
@@ -765,7 +481,8 @@ gda_ldap_provider_get_database (GdaServerProvider *provider, GdaConnection *cnc)
         cdata = (LdapConnectionData*) gda_virtual_connection_internal_get_provider_data (GDA_VIRTUAL_CONNECTION (cnc));
         if (!cdata)
                 return NULL;
-        return cdata->base_dn;
+        TO_IMPLEMENT;
+        return NULL;
 }
 
 /*
@@ -856,44 +573,22 @@ gda_ldap_provider_statement_execute (GdaServerProvider *provider, GdaConnection
 			GError *lerror = NULL;
 			GObject *retval = NULL;
 			cmde = parse_extra_sql_command (ssql, "DROP", &lerror);
-			if (cmde != NOT_AN_EXTRA_SQL_COMMAND) {
+			if ((cmde != NOT_AN_EXTRA_SQL_COMMAND) && !cmde->other_args) {
 				GdaConnectionEvent *event = NULL;
 				if (cmde) {
-					if (cmde->other_args) {
-						g_set_error (&lerror, GDA_SQL_PARSER_ERROR,
-							     GDA_SQL_PARSER_SYNTAX_ERROR,
-							     "%s",
-							     _("Too many arguments"));
+					if (gda_ldap_connection_undeclare_table (GDA_LDAP_CONNECTION (cnc),
+										 cmde->table_name, &lerror))
+						retval = (GObject*) gda_set_new (NULL);
+					else {
 						event = gda_connection_point_available_event (cnc,
 											      GDA_CONNECTION_EVENT_ERROR);
-						gda_connection_event_set_description (event,
-										      lerror->message);
+						gda_connection_event_set_description (event, lerror && lerror->message ? 
+										      lerror->message : _("No detail"));
 						gda_connection_add_event (cnc, event);
 						g_propagate_error (error, lerror);
 					}
-					else {
-						if (gda_ldap_connection_undeclare_table (GDA_LDAP_CONNECTION (cnc),
-											 cmde->table_name, &lerror))
-							retval = (GObject*) gda_set_new (NULL);
-						else {
-							event = gda_connection_point_available_event (cnc,
-												      GDA_CONNECTION_EVENT_ERROR);
-							gda_connection_event_set_description (event, lerror && lerror->message ? 
-											      lerror->message : _("No detail"));
-							gda_connection_add_event (cnc, event);
-							g_propagate_error (error, lerror);
-						}
-					}
 					extra_sql_command_free (cmde);
 				}
-				else {
-					event = gda_connection_point_available_event (cnc,
-										      GDA_CONNECTION_EVENT_ERROR);
-					gda_connection_event_set_description (event, lerror && lerror->message ? 
-									      lerror->message : _("No detail"));
-					gda_connection_add_event (cnc, event);
-					g_propagate_error (error, lerror);
-				}
 				gda_connection_internal_statement_executed (cnc, stmt, params, event);
 				g_free (sql);
 				return retval;
@@ -984,8 +679,8 @@ gda_ldap_free_cnc_data (LdapConnectionData *cdata)
 	g_free (cdata->base_dn);
 	g_free (cdata->server_version);
 	g_free (cdata->url);
-	if (cdata->auth)
-		gda_quark_list_free (cdata->auth);
+	g_free (cdata->user);
+	g_free (cdata->pass);
 	g_free (cdata);
 }
 
