@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2011 - 2012 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2011 Vivien Malerba <malerba@gnome-db.org>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -64,7 +64,7 @@ struct _LdapPart {
 #define LDAP_PART(x) ((LdapPart*)(x))
 
 static LdapPart *ldap_part_new (LdapPart *parent, const gchar *base_dn, GdaLdapSearchScope scope);
-static void ldap_part_free (LdapPart *part, LdapConnectionData *cdata);
+static void ldap_part_free (LdapPart *part);
 static gboolean ldap_part_split (LdapPart *part, GdaDataModelLdap *model, gboolean *out_error);
 static LdapPart *ldap_part_next (LdapPart *part, gboolean executed);
 #ifdef GDA_DEBUG_SUBSEARCHES
@@ -92,7 +92,6 @@ static void row_multiplier_set_holders (RowMultiplier *rm);
 struct _GdaDataModelLdapPrivate {
 	GdaConnection      *cnc;
 	gchar              *base_dn;
-	gboolean            use_rdn;
 	gchar              *filter;
 	GArray             *attributes;
 	GdaLdapSearchScope  scope;
@@ -119,8 +118,7 @@ enum {
 	PROP_BASE,
 	PROP_FILTER,
 	PROP_ATTRIBUTES,
-	PROP_SCOPE,
-	PROP_USE_RDN
+	PROP_SCOPE
 };
 
 static void gda_data_model_ldap_class_init (GdaDataModelLdapClass *klass);
@@ -197,8 +195,6 @@ gda_data_model_ldap_init (GdaDataModelLdap *model,
 
 	model->priv = g_new0 (GdaDataModelLdapPrivate, 1);
 	model->priv->cnc = NULL;
-	model->priv->base_dn = NULL;
-	model->priv->use_rdn = FALSE;
 	model->priv->filter = g_strdup ("(objectClass=*)");
 	model->priv->iter_row = -1;
 	model->priv->default_mv_action = MULTIPLE_VALUE_ACTION_SET_INVALID;
@@ -257,17 +253,12 @@ gda_data_model_ldap_class_init (GdaDataModelLdapClass *klass)
 							   G_PARAM_WRITABLE | G_PARAM_READABLE |
 							   G_PARAM_CONSTRUCT_ONLY));
 
-	g_object_class_install_property (object_class, PROP_USE_RDN,
-                                         g_param_spec_boolean ("use-rdn", NULL, "Return Relative DN instead of complete DN",
-							       FALSE, G_PARAM_WRITABLE | G_PARAM_READABLE));
-
-
 	/* virtual functions */
 	object_class->dispose = gda_data_model_ldap_dispose;
 }
 
 static void
-gda_data_model_ldap_dispose (GObject *object)
+gda_data_model_ldap_dispose (GObject * object)
 {
 	GdaDataModelLdap *model = (GdaDataModelLdap *) object;
 
@@ -295,17 +286,14 @@ gda_data_model_ldap_dispose (GObject *object)
 		if (model->priv->column_mv_actions)
 			g_array_free (model->priv->column_mv_actions, TRUE);
 
-		if (model->priv->top_exec) {
-			LdapConnectionData *cdata;
-			cdata = (LdapConnectionData*) gda_virtual_connection_internal_get_provider_data (GDA_VIRTUAL_CONNECTION (model->priv->cnc));
-			ldap_part_free (model->priv->top_exec, cdata);
-		}
+		if (model->priv->top_exec)
+			ldap_part_free (model->priv->top_exec);
 
 		g_free (model->priv->base_dn);
 		g_free (model->priv->filter);
 
 		if (model->priv->exceptions) {
-			gint i;
+			gint i; 
 			for (i = 0; i < model->priv->exceptions->len; i++) {
 				GError *e;
 				e = g_array_index (model->priv->exceptions, GError*, i);
@@ -410,12 +398,6 @@ gda_data_model_ldap_set_property (GObject *object,
 									      &model->priv->attributes,
 									      model->priv->default_mv_action,
 									      &model->priv->column_mv_actions);
-				if (model->priv->use_rdn)
-					gda_column_set_description (GDA_COLUMN (model->priv->columns->data),
-								    _("Relative distinguished name"));
-				else
-					gda_column_set_description (GDA_COLUMN (model->priv->columns->data),
-								    _("Distinguished name"));
 				model->priv->n_columns = g_list_length (model->priv->columns);
 			}
 			break;
@@ -423,15 +405,6 @@ gda_data_model_ldap_set_property (GObject *object,
 		case PROP_SCOPE:
 			model->priv->scope = g_value_get_int (value);
 			break;
-		case PROP_USE_RDN:
-			model->priv->use_rdn = g_value_get_boolean (value);
-			if (model->priv->columns && model->priv->use_rdn)
-				gda_column_set_description (GDA_COLUMN (model->priv->columns->data),
-							    _("Relative distinguished name"));
-			else
-				gda_column_set_description (GDA_COLUMN (model->priv->columns->data),
-							    _("Distinguished name"));
-			break;
 		default:
 			G_OBJECT_WARN_INVALID_PROPERTY_ID (object, param_id, pspec);
 			break;
@@ -462,9 +435,6 @@ gda_data_model_ldap_get_property (GObject *object,
 		case PROP_SCOPE:
 			g_value_set_int (value, model->priv->scope);
 			break;
-		case PROP_USE_RDN:
-		        g_value_set_boolean (value, model->priv->use_rdn);
-			break;
 		default:
 			G_OBJECT_WARN_INVALID_PROPERTY_ID (object, param_id, pspec);
 			break;
@@ -517,6 +487,7 @@ _ldap_compute_columns (GdaConnection *cnc, const gchar *attributes,
 	gda_column_set_name (col, "dn");
 	gda_column_set_g_type (col, G_TYPE_STRING);
 	gda_column_set_allow_null (col, FALSE);
+	gda_column_set_description (col, _("Distinguished name"));
 	columns = g_list_prepend (NULL, col);
 	g_hash_table_insert (colnames, g_strdup ("dn"), (gpointer) 0x01);
 
@@ -557,7 +528,6 @@ _ldap_compute_columns (GdaConnection *cnc, const gchar *attributes,
 		}
 		col = gda_column_new ();
 		gda_column_set_name (col, sub [0]);
-		gda_column_set_description (col, sub [0]);
 		g_hash_table_insert (colnames, g_strdup (sub [0]), (gpointer) 0x01);
 		gda_column_set_g_type (col, coltype);
 		gda_column_set_allow_null (col, TRUE);
@@ -704,9 +674,6 @@ update_iter_from_ldap_row (GdaDataModelLdap *imodel, GdaDataModelIter *iter)
 	cdata = (LdapConnectionData*) gda_virtual_connection_internal_get_provider_data (GDA_VIRTUAL_CONNECTION (imodel->priv->cnc));
 	g_return_if_fail (cdata);
 
-	/* LDAP connection must have been kept opened */
-	g_assert (cdata->handle);
-
 	g_object_get (G_OBJECT (iter), "update-model", &update_model, NULL);
 	g_object_set (G_OBJECT (iter), "update-model", FALSE, NULL);
 		
@@ -716,18 +683,6 @@ update_iter_from_ldap_row (GdaDataModelLdap *imodel, GdaDataModelIter *iter)
 	if (attr) {
 		gchar *userdn;
 		if (gda_ldap_parse_dn (attr, &userdn)) {
-			if (imodel->priv->base_dn && *imodel->priv->base_dn &&
-			    imodel->priv->use_rdn &&
-			    g_str_has_suffix (userdn, imodel->priv->base_dn)) {
-				gint i;
-				i = strlen (userdn) - strlen (imodel->priv->base_dn);
-				if (i > 0) {
-					userdn [i] = 0;
-					for (i--; (i >= 0) && (userdn [i] != ','); i--);
-					if ((i >= 0) && userdn [i] == ',')
-						userdn [i] = 0;
-				}
-			}
 			gda_holder_set_value_str (holder, NULL, userdn, NULL);
 			g_free (userdn);
 		}
@@ -895,7 +850,7 @@ update_iter_from_ldap_row (GdaDataModelLdap *imodel, GdaDataModelIter *iter)
 	if (gda_data_model_iter_is_valid (iter)) {
 		imodel->priv->iter_row ++;
 		if ((imodel->priv->iter_row == imodel->priv->n_rows - 1) && imodel->priv->truncated) {
-			GError *e = NULL;
+			GError *e;
 			g_set_error (&e, GDA_DATA_MODEL_ERROR,
 				     GDA_DATA_MODEL_TRUNCATED_ERROR,
 				     "%s", _("Truncated result because LDAP server limit encountered"));
@@ -939,12 +894,6 @@ execute_ldap_search (GdaDataModelLdap *model)
 	cdata = (LdapConnectionData*) gda_virtual_connection_internal_get_provider_data (GDA_VIRTUAL_CONNECTION (model->priv->cnc));
 	g_return_if_fail (cdata);
 
-	GError *e = NULL;
-	if (! gda_ldap_ensure_bound (cdata, &e)) {
-		add_exception (model, e);
-		return;
-	}
-
 	g_assert (model->priv->current_exec);
 	g_assert (! model->priv->current_exec->executed);
 
@@ -967,11 +916,10 @@ execute_ldap_search (GdaDataModelLdap *model)
 		ldap_part_dump (model->priv->top_exec);
 	}
 #endif
-
+	retry:
 #ifdef GDA_DEBUG_SUBSEARCHES_FORCE
 	/* force sub searches for 2 levels */
 	static gint sims = 10;
- retry:
 	if ((sims > 0) &&
 	    (model->priv->scope == GDA_LDAP_SEARCH_SUBTREE) &&
 	    (! model->priv->current_exec->parent || ! model->priv->current_exec->parent->parent)) {
@@ -980,9 +928,8 @@ execute_ldap_search (GdaDataModelLdap *model)
 		sims --;
 	}
 	if (res == 0)
-#else
-	retry:
 #endif
+
 	res = ldap_search_ext_s (cdata->handle, model->priv->current_exec->base_dn, lscope,
 				 model->priv->filter,
 				 (char**) model->priv->attributes->data, 0,
@@ -990,34 +937,18 @@ execute_ldap_search (GdaDataModelLdap *model)
 				 &msg);
 	model->priv->current_exec->executed = TRUE;
 
-#define GDA_DEBUG_FORCE_ERROR
-#undef GDA_DEBUG_FORCE_ERROR
-#ifdef GDA_DEBUG_FORCE_ERROR
-	/* error */
-	GError *e = NULL;
-	int ldap_errno;
-	g_print ("SIMULATING error\n");
-	ldap_get_option (cdata->handle, LDAP_OPT_ERROR_NUMBER, &ldap_errno);
-	g_set_error (&e, GDA_DATA_MODEL_ERROR, GDA_DATA_MODEL_OTHER_ERROR,
-		     "%s", "Simulated error");
-	add_exception (model, e);
-	return;
-#else
 	switch (res) {
 	case LDAP_SUCCESS:
 	case LDAP_NO_SUCH_OBJECT:
 		/* all Ok */
 		model->priv->current_exec->ldap_msg = msg;
 		model->priv->current_exec->nb_entries = ldap_count_entries (cdata->handle, msg);
-
-		/* keep the connection opened for this LdapPart */
-		cdata->keep_bound_count ++;
-
 #ifdef GDA_DEBUG_SUBSEARCHES
 		g_print ("model->priv->current_exec->nb_entries = %d\n",
 			 model->priv->current_exec->nb_entries);
 #endif
 		break;
+
 	case LDAP_ADMINLIMIT_EXCEEDED:
 	case LDAP_SIZELIMIT_EXCEEDED:
 	case LDAP_TIMELIMIT_EXCEEDED: {
@@ -1025,8 +956,7 @@ execute_ldap_search (GdaDataModelLdap *model)
 		g_print ("LIMIT_EXCEEDED!\n");
 #endif
 		gboolean handled = FALSE;
-		if ((cdata->time_limit == 0) && (cdata->size_limit == 0) &&
-		    (model->priv->scope == GDA_LDAP_SEARCH_SUBTREE)) {
+		if (model->priv->scope == GDA_LDAP_SEARCH_SUBTREE) {
 			gboolean split_error;
 			if (ldap_part_split (model->priv->current_exec, model, &split_error)) {
 				/* create some children to re-run the search */
@@ -1054,16 +984,13 @@ execute_ldap_search (GdaDataModelLdap *model)
 			model->priv->truncated = TRUE;
 			model->priv->current_exec->ldap_msg = msg;
 			model->priv->current_exec->nb_entries = ldap_count_entries (cdata->handle, msg);
-
-			/* keep the connection opened for this LdapPart */
-			cdata->keep_bound_count ++;
 		}
 		break;
 	}
 	case LDAP_SERVER_DOWN: {
 		gint i;
 		for (i = 0; i < 5; i++) {
-			if (gda_ldap_rebind (cdata, NULL))
+			if (gda_ldap_silently_rebind (cdata))
 				goto retry;
 			g_usleep (G_USEC_PER_SEC * 2);
 		}
@@ -1074,13 +1001,11 @@ execute_ldap_search (GdaDataModelLdap *model)
 		int ldap_errno;
 		ldap_get_option (cdata->handle, LDAP_OPT_ERROR_NUMBER, &ldap_errno);
 		g_set_error (&e, GDA_DATA_MODEL_ERROR, GDA_DATA_MODEL_OTHER_ERROR,
-			     "%s", ldap_err2string (ldap_errno));
+			     "%s", ldap_err2string(ldap_errno));
 		add_exception (model, e);
-		gda_ldap_may_unbind (cdata);
 		return;
 	}
 	}
-#endif /*GDA_DEBUG_FORCE_ERROR*/
 
 	if (model->priv->truncated) {
 		/* compute totel number of rows now that we know it */
@@ -1093,7 +1018,6 @@ execute_ldap_search (GdaDataModelLdap *model)
 				model->priv->n_rows += iter->nb_entries;
 		}
 	}
-
 #ifdef GDA_DEBUG_NO
 	gint tmpnb = 0;
 	if (model->priv->top_exec->ldap_msg)
@@ -1126,7 +1050,7 @@ gda_data_model_ldap_iter_next (GdaDataModel *model, GdaDataModelIter *iter)
 	}
 
 	cdata = (LdapConnectionData*) gda_virtual_connection_internal_get_provider_data (GDA_VIRTUAL_CONNECTION (imodel->priv->cnc));
-	if (!cdata || ! gda_ldap_ensure_bound (cdata, NULL)) {
+	if (!cdata) {
 		/* error */
 		gda_data_model_iter_invalidate_contents (iter);
 		return FALSE;
@@ -1150,7 +1074,6 @@ gda_data_model_ldap_iter_next (GdaDataModel *model, GdaDataModelIter *iter)
 		if (! cpart->ldap_msg) {
 			/* error somewhere */
 			gda_data_model_iter_invalidate_contents (iter);
-			gda_ldap_may_unbind (cdata);
 			return FALSE;
 		}
 
@@ -1174,17 +1097,9 @@ gda_data_model_ldap_iter_next (GdaDataModel *model, GdaDataModelIter *iter)
 			update_iter_from_ldap_row (imodel, iter);
 			break;
 		}
-		else {
+		else
 			/* nothing more for this part, switch to the next one */
-			ldap_msgfree (imodel->priv->current_exec->ldap_msg);
-			imodel->priv->current_exec->ldap_msg = NULL;
-
-			g_assert (cdata->keep_bound_count > 0);
-			cdata->keep_bound_count --;
-			gda_ldap_may_unbind (cdata);
-
 			imodel->priv->current_exec = ldap_part_next (cpart, FALSE);
-		}
 	}
 
 	if (!imodel->priv->current_exec) {
@@ -1192,18 +1107,16 @@ gda_data_model_ldap_iter_next (GdaDataModel *model, GdaDataModelIter *iter)
 		gda_data_model_iter_invalidate_contents (iter);
                 g_object_set (G_OBJECT (iter), "current-row", -1, NULL);
 		if (imodel->priv->truncated) {
-			GError *e = NULL;
+			GError *e;
 			g_set_error (&e, GDA_DATA_MODEL_ERROR,
 				     GDA_DATA_MODEL_TRUNCATED_ERROR,
 				     "%s", _("Truncated result because LDAP server limit encountered"));
 			add_exception (imodel, e);
 		}
 		g_signal_emit_by_name (iter, "end-of-data");
-		gda_ldap_may_unbind (cdata);
                 return FALSE;
 	}
 
-	gda_ldap_may_unbind (cdata);
 	return TRUE;
 }
 
@@ -1267,23 +1180,16 @@ ldap_part_new (LdapPart *parent, const gchar *base_dn, GdaLdapSearchScope scope)
 }
 
 static void
-ldap_part_free (LdapPart *part, LdapConnectionData *cdata)
+ldap_part_free (LdapPart *part)
 {
 	g_assert (part);
 	g_free (part->base_dn);
 	if (part->children) {
-		g_slist_foreach (part->children, (GFunc) ldap_part_free, cdata);
+		g_slist_foreach (part->children, (GFunc) ldap_part_free, NULL);
 		g_slist_free (part->children);
 	}
-	if (part->ldap_msg) {
+	if (part->ldap_msg)
 		ldap_msgfree (part->ldap_msg);
-
-		/* Release the connection being opened for this LdapPart */
-		g_assert (cdata);
-		g_assert (cdata->keep_bound_count > 0);
-		cdata->keep_bound_count --;
-		gda_ldap_may_unbind (cdata);
-	}
 	g_free (part);
 }
 
@@ -1373,9 +1279,7 @@ ldap_part_split (LdapPart *part, GdaDataModelLdap *model, gboolean *out_error)
 		}
 		if (!sub) {
 			/* error */
-			LdapConnectionData *cdata;
-			cdata = (LdapConnectionData*) gda_virtual_connection_internal_get_provider_data (GDA_VIRTUAL_CONNECTION (model->priv->cnc));
-			g_slist_foreach (part->children, (GFunc) ldap_part_free, cdata);
+			g_slist_foreach (part->children, (GFunc) ldap_part_free, NULL);
 			g_slist_free (part->children);
 			part->children = NULL;
 			break;
@@ -1542,256 +1446,3 @@ row_multiplier_index_next (RowMultiplier *rm)
 		}
 	}
 }
-
-/*
- * Writing support
- */
-
-typedef struct {
-	LdapConnectionData *cdata;
-	GArray *mods_array;
-} FHData;
-static void removed_attrs_func (const gchar *attr_name, GdaLdapAttribute *attr, FHData *data);
-
-gboolean
-gdaprov_ldap_modify (GdaLdapConnection *cnc, GdaLdapModificationType modtype,
-		     GdaLdapEntry *entry, GdaLdapEntry *ref_entry, GError **error)
-{
-	LdapConnectionData *cdata;
-	int res;
-
-	g_return_val_if_fail (GDA_IS_LDAP_CONNECTION (cnc), FALSE);
-	g_return_val_if_fail (entry, FALSE);
-	if (entry)
-		g_return_val_if_fail (gdaprov_ldap_is_dn (entry->dn), FALSE);
-	if (ref_entry)
-		g_return_val_if_fail (gdaprov_ldap_is_dn (ref_entry->dn), FALSE);
-
-	cdata = (LdapConnectionData*) gda_virtual_connection_internal_get_provider_data (GDA_VIRTUAL_CONNECTION (cnc));
-	g_return_val_if_fail (cdata, FALSE);
-
-	if (! gda_ldap_ensure_bound (cdata, error))
-		return FALSE;
-
-	/* checks */
-	if ((modtype != GDA_LDAP_MODIFICATION_INSERT) &&
-	    (modtype != GDA_LDAP_MODIFICATION_ATTR_ADD) &&
-	    (modtype != GDA_LDAP_MODIFICATION_ATTR_DEL) &&
-	    (modtype != GDA_LDAP_MODIFICATION_ATTR_REPL) &&
-	    (modtype != GDA_LDAP_MODIFICATION_ATTR_DIFF)) {
-		g_warning (_("Unknown GdaLdapModificationType %d"), modtype);
-		gda_ldap_may_unbind (cdata);
-		return FALSE;
-	}
-
-	if (((modtype == GDA_LDAP_MODIFICATION_DELETE) || (modtype == GDA_LDAP_MODIFICATION_INSERT)) &&
-	    !entry) {
-		g_warning ("%s", _("No GdaLdapEntry specified"));
-		gda_ldap_may_unbind (cdata);
-		return FALSE;
-	}
-
-	if ((modtype == GDA_LDAP_MODIFICATION_ATTR_ADD) && !entry) {
-		g_warning ("%s", _("No GdaLdapEntry specified to define attributes to add"));
-		gda_ldap_may_unbind (cdata);
-		return FALSE;
-	}
-
-	if ((modtype == GDA_LDAP_MODIFICATION_ATTR_DEL) && !entry) {
-		g_warning ("%s", _("No GdaLdapEntry specified to define attributes to remove"));
-		gda_ldap_may_unbind (cdata);
-		return FALSE;
-	}
-
-	if ((modtype == GDA_LDAP_MODIFICATION_ATTR_REPL) && !entry) {
-		g_warning ("%s", _("No GdaLdapEntry specified to define attributes to replace"));
-		gda_ldap_may_unbind (cdata);
-		return FALSE;
-	}
-
-	if ((modtype == GDA_LDAP_MODIFICATION_ATTR_DIFF) && (!entry || !ref_entry)) {
-		g_warning ("%s", _("No GdaLdapEntry specified to compare attributes"));
-		gda_ldap_may_unbind (cdata);
-		return FALSE;
-	}
-	if ((modtype == GDA_LDAP_MODIFICATION_ATTR_DIFF) && strcmp (entry->dn, ref_entry->dn)) {
-		g_warning ("%s", _("GdaLdapEntry specified to compare have different DN"));
-		gda_ldap_may_unbind (cdata);
-		return FALSE;
-	}
-
-	/* handle DELETE operation */
-	if (modtype == GDA_LDAP_MODIFICATION_DELETE) {
-		res = ldap_delete_ext_s (cdata->handle, entry->dn, NULL, NULL);
-		if (res != LDAP_SUCCESS) {
-			g_set_error (error, GDA_DATA_MODEL_ERROR, GDA_DATA_MODEL_OTHER_ERROR,
-				     "%s", ldap_err2string (res));
-			gda_ldap_may_unbind (cdata);
-			return FALSE;
-		}
-		else {
-			gda_ldap_may_unbind (cdata);
-			return TRUE;
-		}
-	}
-
-	/* build array of modifications to perform */
-	GArray *mods_array;
-	mods_array = g_array_new (TRUE, FALSE, sizeof (LDAPMod*));
-	if (modtype == GDA_LDAP_MODIFICATION_ATTR_DIFF) {
-		/* index ref_entry's attributes */
-		GHashTable *hash;
-		guint i;
-		hash = g_hash_table_new (g_str_hash, g_str_equal);
-		for (i = 0; i < ref_entry->nb_attributes; i++) {
-			GdaLdapAttribute *attr;
-			attr = ref_entry->attributes [i];
-			g_hash_table_insert (hash, attr->attr_name, attr);
-		}
-		
-		for (i = 0; i < entry->nb_attributes; i++) {
-			LDAPMod *mod;
-			GdaLdapAttribute *attr, *ref_attr;
-			guint j;
-
-			attr = entry->attributes [i];
-			ref_attr = g_hash_table_lookup (hash, attr->attr_name);
-
-			mod = g_new0 (LDAPMod, 1);
-			mod->mod_type = attr->attr_name; /* no duplication */
-			if (ref_attr) {
-				mod->mod_op = LDAP_MOD_BVALUES | LDAP_MOD_REPLACE;
-				g_hash_table_remove (hash, attr->attr_name);
-			}
-			else
-				mod->mod_op = LDAP_MOD_BVALUES | LDAP_MOD_ADD;
-
-			mod->mod_bvalues = g_new0 (struct berval *, attr->nb_values + 1); /* last is NULL */
-			for (j = 0; j < attr->nb_values; j++)
-				mod->mod_bvalues[j] = gda_ldap_attr_g_value_to_value (cdata, attr->values [j]);
-			g_array_append_val (mods_array, mod);
-		}
-
-		FHData fhdata;
-		fhdata.cdata = cdata;
-		fhdata.mods_array = mods_array;
-		g_hash_table_foreach (hash, (GHFunc) removed_attrs_func, &fhdata);
-		g_hash_table_destroy (hash);
-	}
-	else {
-		guint i;
-		for (i = 0; i < entry->nb_attributes; i++) {
-			LDAPMod *mod;
-			GdaLdapAttribute *attr;
-			guint j;
-
-			attr = entry->attributes [i];
-			mod = g_new0 (LDAPMod, 1);
-			mod->mod_op = LDAP_MOD_BVALUES;
-			if ((modtype == GDA_LDAP_MODIFICATION_INSERT) ||
-			    (modtype == GDA_LDAP_MODIFICATION_ATTR_ADD))
-				mod->mod_op |= LDAP_MOD_ADD;
-			else if (modtype == GDA_LDAP_MODIFICATION_ATTR_DEL)
-				mod->mod_op |= LDAP_MOD_DELETE;
-			else
-				mod->mod_op |= LDAP_MOD_REPLACE;
-			mod->mod_type = attr->attr_name; /* no duplication */
-			mod->mod_bvalues = g_new0 (struct berval *, attr->nb_values + 1); /* last is NULL */
-			for (j = 0; j < attr->nb_values; j++)
-				mod->mod_bvalues[j] = gda_ldap_attr_g_value_to_value (cdata, attr->values [j]);
-			g_array_append_val (mods_array, mod);
-		}
-	}
-	
-	gboolean retval = TRUE;
-	if (mods_array->len > 0) {
-		/* apply modifications */
-		if (modtype == GDA_LDAP_MODIFICATION_INSERT)
-			res = ldap_add_ext_s (cdata->handle, entry->dn, (LDAPMod **) mods_array->data, NULL, NULL);
-		else
-			res = ldap_modify_ext_s (cdata->handle, entry->dn, (LDAPMod **) mods_array->data, NULL, NULL);
-
-		if (res != LDAP_SUCCESS) {
-			g_set_error (error, GDA_DATA_MODEL_ERROR, GDA_DATA_MODEL_OTHER_ERROR,
-				     "%s", ldap_err2string (res));
-			retval = FALSE;
-		}
-	}
-
-	/* clear tmp data */
-	guint i;
-	for (i = 0; i < mods_array->len; i++) {
-		LDAPMod *mod;
-		mod = g_array_index (mods_array, LDAPMod*, i);
-		if (mod->mod_values) {
-			guint j;
-			for (j = 0; mod->mod_values [j]; j++)
-				gda_ldap_attr_value_free (cdata, mod->mod_bvalues [j]);
-			g_free (mod->mod_values);
-		}
-		g_free (mod);
-	}
-	g_array_free (mods_array, TRUE);
-
-	gda_ldap_may_unbind (cdata);
-	return retval;
-}
-
-static void
-removed_attrs_func (const gchar *attr_name, GdaLdapAttribute *attr, FHData *data)
-{
-	LDAPMod *mod;
-	guint j;
-
-	mod = g_new0 (LDAPMod, 1);
-	mod->mod_op = LDAP_MOD_BVALUES | LDAP_MOD_DELETE;
-	mod->mod_type = attr->attr_name; /* no duplication */
-	mod->mod_bvalues = g_new0 (struct berval *, attr->nb_values + 1); /* last is NULL */
-	for (j = 0; j < attr->nb_values; j++)
-		mod->mod_bvalues[j] = gda_ldap_attr_g_value_to_value (data->cdata, attr->values [j]);
-	g_array_append_val (data->mods_array, mod);
-}
-
-gboolean
-gdaprov_ldap_rename_entry (GdaLdapConnection *cnc, const gchar *current_dn, const gchar *new_dn,
-			   GError **error)
-{
-	g_return_val_if_fail (GDA_IS_LDAP_CONNECTION (cnc), FALSE);
-	g_return_val_if_fail (current_dn && *current_dn, FALSE);
-	g_return_val_if_fail (gdaprov_ldap_is_dn (current_dn), FALSE);
-	g_return_val_if_fail (new_dn && *new_dn, FALSE);
-	g_return_val_if_fail (gdaprov_ldap_is_dn (new_dn), FALSE);
-
-	LdapConnectionData *cdata;
-	cdata = (LdapConnectionData*) gda_virtual_connection_internal_get_provider_data (GDA_VIRTUAL_CONNECTION (cnc));
-	g_return_val_if_fail (cdata, FALSE);
-
-	if (! gda_ldap_ensure_bound (cdata, error))
-		return FALSE;
-
-	gchar **carray, **narray;
-	int res;
-	gboolean retval = TRUE;
-	gchar *parent = NULL;
-
-	carray = gda_ldap_dn_split (current_dn, FALSE);
-	narray = gda_ldap_dn_split (new_dn, FALSE);
-
-	if (carray[1] && narray[1] && strcmp (carray[1], narray[1]))
-		parent = narray [1];
-	else if (! carray[1] && narray[1])
-		parent = narray [1];
-
-	res = ldap_rename_s (cdata->handle, current_dn, narray[0], parent, 1, NULL, NULL);
-	g_strfreev (carray);
-	g_strfreev (narray);
-
-	if (res != LDAP_SUCCESS) {
-		g_set_error (error, GDA_DATA_MODEL_ERROR, GDA_DATA_MODEL_OTHER_ERROR,
-			     "%s", ldap_err2string (res));
-		retval = FALSE;
-	}
-
-	gda_ldap_may_unbind (cdata);
-	return retval;
-}
