@@ -271,7 +271,10 @@ gda_postgres_render_CREATE_TABLE (GdaServerProvider *provider, GdaConnection *cn
 				node = gda_server_operation_get_node_info (op, "/FKEY_S/%d/FKEY_FIELDS_A", i);
 				if (!node || ((nbfields = gda_data_model_get_n_rows (node->model)) == 0)) {
 					allok = FALSE;
-					g_set_error (error, 0, 0, "%s", _("No field specified in foreign key constraint"));
+					g_set_error (error, GDA_SERVER_OPERATION_ERROR,
+						     GDA_SERVER_OPERATION_INCORRECT_VALUE_ERROR,
+						     "%s",
+						     _("No field specified in foreign key constraint"));
 				}
 				else {
 					for (j = 0; j < nbfields; j++) {
@@ -285,7 +288,9 @@ gda_postgres_render_CREATE_TABLE (GdaServerProvider *provider, GdaConnection *cn
 						}
 						else {
 							allok = FALSE;
-							g_set_error (error, 0, 0, "%s",  
+							g_set_error (error, GDA_SERVER_OPERATION_ERROR,
+								     GDA_SERVER_OPERATION_INCORRECT_VALUE_ERROR,
+								     "%s",  
 								     _("Empty field specified in foreign key constraint"));
 						}
 					}
@@ -300,7 +305,10 @@ gda_postgres_render_CREATE_TABLE (GdaServerProvider *provider, GdaConnection *cn
 				}
 				else {
 					allok = FALSE;
-					g_set_error (error, 0, 0, "%s", _("No referenced table specified in foreign key constraint"));
+					g_set_error (error, GDA_SERVER_OPERATION_ERROR,
+						     GDA_SERVER_OPERATION_INCORRECT_VALUE_ERROR,
+						     "%s",
+						     _("No referenced table specified in foreign key constraint"));
 				}
 
 				g_string_append (string, " (");
@@ -315,7 +323,9 @@ gda_postgres_render_CREATE_TABLE (GdaServerProvider *provider, GdaConnection *cn
 					}
 					else {
 						allok = FALSE;
-						g_set_error (error, 0, 0, "%s",  
+						g_set_error (error, GDA_SERVER_OPERATION_ERROR,
+							     GDA_SERVER_OPERATION_INCORRECT_VALUE_ERROR,
+							     "%s",  
 							     _("Empty referenced field specified in foreign key constraint"));
 					}
 				}
@@ -362,7 +372,9 @@ gda_postgres_render_CREATE_TABLE (GdaServerProvider *provider, GdaConnection *cn
 
 	if (!hasfields) {
 		allok = FALSE;
-		g_set_error (error, 0, 0, "%s", _("Table to create must have at least one row"));
+		g_set_error (error, GDA_SERVER_OPERATION_ERROR,
+                             GDA_SERVER_OPERATION_INCORRECT_VALUE_ERROR,
+			     "%s", _("Table to create must have at least one row"));
 	}
 
 	if (allok) {
@@ -766,7 +778,7 @@ gda_postgres_render_CREATE_USER (GdaServerProvider *provider, GdaConnection *cnc
 	if (cnc) {
 		g_return_val_if_fail (GDA_IS_CONNECTION (cnc), FALSE);
 		g_return_val_if_fail (gda_connection_get_provider (cnc) == provider, FALSE);
-		cdata = (PostgresConnectionData*) gda_connection_internal_get_provider_data (cnc);
+		cdata = (PostgresConnectionData*) gda_connection_internal_get_provider_data_error (cnc, error);
 	}
 	if (cdata && (cdata->reuseable->version_float < 8.1))
 		use_role = FALSE;
@@ -971,7 +983,7 @@ gda_postgres_render_DROP_USER (GdaServerProvider *provider, GdaConnection *cnc,
 	if (cnc) {
 		g_return_val_if_fail (GDA_IS_CONNECTION (cnc), FALSE);
 		g_return_val_if_fail (gda_connection_get_provider (cnc) == provider, FALSE);
-		cdata = (PostgresConnectionData*) gda_connection_internal_get_provider_data (cnc);
+		cdata = (PostgresConnectionData*) gda_connection_internal_get_provider_data_error (cnc, error);
 	}
 	if (cdata && (cdata->reuseable->version_float < 8.1))
 		use_role = FALSE;
