@@ -1,7 +1,7 @@
 /*
  * Copyright (C) 2001 - 2003 Gonzalo Paniagua Javier <gonzalo@gnome-db.org>
  * Copyright (C) 2001 - 2004 Rodrigo Moya <rodrigo@gnome-db.org>
- * Copyright (C) 2002 - 2012 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2002 - 2011 Vivien Malerba <malerba@gnome-db.org>
  * Copyright (C) 2002 Zbigniew Chyla <cyba@gnome.pl>
  * Copyright (C) 2003 Akira TAGOH <tagoh@gnome-db.org>
  * Copyright (C) 2004 - 2005 Alan Knowles <alank@src.gnome.org>
@@ -165,8 +165,7 @@ static void gda_postgres_free_cnc_data (PostgresConnectionData *cdata);
  * TO_ADD: any prepared statement to be used internally by the provider should be
  *         declared here, as constants and as SQL statements
  */
-static GStaticMutex init_mutex = G_STATIC_MUTEX_INIT;
-static GdaStatement **internal_stmt = NULL;
+static GdaStatement **internal_stmt;
 
 typedef enum {
 	I_STMT_BEGIN,
@@ -302,25 +301,19 @@ gda_postgres_provider_class_init (GdaPostgresProviderClass *klass)
 static void
 gda_postgres_provider_init (GdaPostgresProvider *postgres_prv, G_GNUC_UNUSED GdaPostgresProviderClass *klass)
 {
-	g_static_mutex_lock (&init_mutex);
+	InternalStatementItem i;
+	GdaSqlParser *parser;
 
-	if (!internal_stmt) {
-		InternalStatementItem i;
-		GdaSqlParser *parser;
-
-		parser = gda_server_provider_internal_get_parser ((GdaServerProvider*) postgres_prv);
-		internal_stmt = g_new0 (GdaStatement *, sizeof (internal_sql) / sizeof (gchar*));
-		for (i = I_STMT_BEGIN; i < sizeof (internal_sql) / sizeof (gchar*); i++) {
-			internal_stmt[i] = gda_sql_parser_parse_string (parser, internal_sql[i], NULL, NULL);
-			if (!internal_stmt[i])
-				g_error ("Could not parse internal statement: %s\n", internal_sql[i]);
-		}
+	parser = gda_server_provider_internal_get_parser ((GdaServerProvider*) postgres_prv);
+	internal_stmt = g_new0 (GdaStatement *, sizeof (internal_sql) / sizeof (gchar*));
+	for (i = I_STMT_BEGIN; i < sizeof (internal_sql) / sizeof (gchar*); i++) {
+		internal_stmt[i] = gda_sql_parser_parse_string (parser, internal_sql[i], NULL, NULL);
+		if (!internal_stmt[i])
+			g_error ("Could not parse internal statement: %s\n", internal_sql[i]);
 	}
 
 	/* meta data init */
 	_gda_postgres_provider_meta_init ((GdaServerProvider*) postgres_prv);
-
-	g_static_mutex_unlock (&init_mutex);
 }
 
 GType
@@ -427,7 +420,6 @@ gda_postgres_provider_open_connection (GdaServerProvider *provider, GdaConnectio
         const gchar *pq_pwd = NULL;
         const gchar *pq_hostaddr;
         const gchar *pq_requiressl;
-	const gchar *pq_connect_timeout;
         gchar *conn_string;
 	pq_host = gda_quark_list_find (params, "HOST");
         pq_hostaddr = gda_quark_list_find (params, "HOSTADDR");
@@ -462,7 +454,7 @@ gda_postgres_provider_open_connection (GdaServerProvider *provider, GdaConnectio
         pq_requiressl = gda_quark_list_find (params, "USE_SSL");
 	if (pq_requiressl && (*pq_requiressl != 'T') && (*pq_requiressl != 't'))
 		pq_requiressl = NULL;
-	pq_connect_timeout = gda_quark_list_find (params, "CONNECT_TIMEOUT");
+
 
 	/* TODO: Escape single quotes and backslashes in the user name and password: */
         conn_string = g_strconcat ("",
@@ -497,8 +489,6 @@ gda_postgres_provider_open_connection (GdaServerProvider *provider, GdaConnectio
                                    (pq_pwd && *pq_pwd) ? "'" : "",
                                    pq_requiressl ? " requiressl=" : "",
                                    pq_requiressl ? pq_requiressl : "",
-				   pq_connect_timeout ? " connect_timeout=" : "",
-				   pq_connect_timeout ? pq_connect_timeout : "",
                                    NULL);
 
 	/* open the real connection to the database */
@@ -1342,12 +1332,16 @@ gda_postgres_provider_get_data_handler (GdaServerProvider *provider, GdaConnecti
 		TO_IMPLEMENT; /* use @dbms_type */
 		dh = NULL;
 	}
-	else if (type == GDA_TYPE_BINARY) {
+	else if ((type == GDA_TYPE_BINARY) ||
+		 (type == GDA_TYPE_BLOB)) {
 		dh = gda_server_provider_handler_find (provider, cnc, type, NULL);
                 if (!dh) {
                         dh = gda_postgres_handler_bin_new (cnc);
-			gda_server_provider_handler_declare (provider, dh, cnc, GDA_TYPE_BINARY, NULL);
-			g_object_unref (dh);
+                        if (dh) {
+                                gda_server_provider_handler_declare (provider, dh, cnc, GDA_TYPE_BINARY, NULL);
+                                gda_server_provider_handler_declare (provider, dh, cnc, GDA_TYPE_BLOB, NULL);
+                                g_object_unref (dh);
+                        }
                 }
 	}
 	else if ((type == GDA_TYPE_TIME) ||
@@ -1365,7 +1359,7 @@ gda_postgres_provider_get_data_handler (GdaServerProvider *provider, GdaConnecti
                 }
 	}
 	else
-		dh = gda_server_provider_handler_use_default (provider, type);
+		dh = gda_server_provider_get_data_handler_default (provider, cnc, type, dbms_type);
 
 	return dh;
 }
@@ -1686,7 +1680,7 @@ make_last_inserted_set (GdaConnection *cnc, GdaStatement *stmt, Oid last_id)
 	gda_sql_statement_select_take_where_cond (sql_statement, where);
 
 	if (gda_sql_statement_check_structure (sql_statement, &lerror) == FALSE) {
-                g_warning (_("Can't build SELECT statement to get last inserted row: %s"),
+                g_warning (_("Can't build SELECT statement to get last inserted row: %s)"),
 			     lerror && lerror->message ? lerror->message : _("No detail"));
 		if (lerror)
 			g_error_free (lerror);
