@@ -144,8 +144,7 @@ static void gda_capi_free_cnc_data (CapiConnectionData *cdata);
  * TO_ADD: any prepared statement to be used internally by the provider should be
  *         declared here, as constants and as SQL statements
  */
-static GStaticMutex init_mutex = G_STATIC_MUTEX_INIT;
-static GdaStatement **internal_stmt = NULL;
+static GdaStatement **internal_stmt;
 
 typedef enum {
 	INTERNAL_STMT1
@@ -263,27 +262,21 @@ gda_capi_provider_class_init (GdaCapiProviderClass *klass)
 static void
 gda_capi_provider_init (GdaCapiProvider *capi_prv, G_GNUC_UNUSED GdaCapiProviderClass *klass)
 {
-	g_static_mutex_lock (&init_mutex);
+	InternalStatementItem i;
+	GdaSqlParser *parser;
 
-	if (!internal_stmt) {
-		InternalStatementItem i;
-		GdaSqlParser *parser;
-
-		parser = gda_server_provider_internal_get_parser ((GdaServerProvider*) capi_prv);
-		internal_stmt = g_new0 (GdaStatement *, sizeof (internal_sql) / sizeof (gchar*));
-		for (i = INTERNAL_STMT1; i < sizeof (internal_sql) / sizeof (gchar*); i++) {
-			internal_stmt[i] = gda_sql_parser_parse_string (parser, internal_sql[i], NULL, NULL);
-			if (!internal_stmt[i])
-				g_error ("Could not parse internal statement: %s\n", internal_sql[i]);
-		}
+	parser = gda_server_provider_internal_get_parser ((GdaServerProvider*) capi_prv);
+	internal_stmt = g_new0 (GdaStatement *, sizeof (internal_sql) / sizeof (gchar*));
+	for (i = INTERNAL_STMT1; i < sizeof (internal_sql) / sizeof (gchar*); i++) {
+		internal_stmt[i] = gda_sql_parser_parse_string (parser, internal_sql[i], NULL, NULL);
+		if (!internal_stmt[i]) 
+			g_error ("Could not parse internal statement: %s\n", internal_sql[i]);
 	}
 
 	/* meta data init */
 	_gda_capi_provider_meta_init ((GdaServerProvider*) capi_prv);
 
 	/* TO_ADD: any other provider's init should be added here */
-
-	g_static_mutex_unlock (&init_mutex);
 }
 
 GType
@@ -824,7 +817,7 @@ gda_capi_provider_get_data_handler (GdaServerProvider *provider, GdaConnection *
 		dh = NULL;
 	}
 	else
-		dh = gda_server_provider_handler_use_default (provider, type);
+		dh = gda_server_provider_get_data_handler_default (provider, cnc, type, dbms_type);
 
 	return dh;
 }
