@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2007 - 2012 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2007 - 2011 Vivien Malerba <malerba@gnome-db.org>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -23,41 +23,18 @@
 
 static GdaDataModel *run_sql_select (GdaConnection *cnc, const gchar *sql);
 static gboolean run_sql_non_select (GdaConnection *cnc, const gchar *sql);
-static gboolean test1 (void);
-static gboolean test2 (void);
 
 int 
 main (int argc, char **argv)
-{
-	gint nfailed = 0;
-	gda_init ();
-
-	if (! test1 ())
-		nfailed++;
-	if (! test2 ())
-		nfailed++;
-
-	if (nfailed == 0) {
-		g_print ("Ok, all tests passed\n");
-		return EXIT_SUCCESS;
-	}
-	else {
-		g_print ("%d failed\n", nfailed);
-		return EXIT_FAILURE;
-	} 
-}
-
-static gboolean
-test1 (void)
 {
 	GError *error = NULL;	
 	GdaConnection *cnc;
 	GdaVirtualProvider *provider;
 	GdaDataModel *rw_model;
 	gchar *file;
-	gboolean retval = FALSE;
+	
+	gda_init ();
 
-	g_print ("===== %s() =====\n", __FUNCTION__);
 	provider = gda_vprovider_data_model_new ();
 	cnc = gda_virtual_connection_open (provider, NULL);
 	g_assert (cnc);
@@ -76,7 +53,6 @@ test1 (void)
 	file = g_build_filename (CHECK_FILES, "tests", "data-models", "country.csv", NULL);
 	country_model = gda_data_model_import_new_file (file, TRUE, options);
 	g_free (file);
-	file = NULL;
 	g_object_unref (options);
 
 	/* Add data models to connection */
@@ -107,14 +83,11 @@ test1 (void)
 						  NULL, 0, NULL, 0, NULL);
 	file = g_build_filename (CHECK_FILES, "tests", "data-models", "check_virtual.csv", NULL);
 	if (!g_file_get_contents (file, &expected, NULL, NULL))
-		goto out;
-	if (strcmp (export, expected))
-		goto out;
-
-	retval = TRUE;
- out:
-
+		return EXIT_FAILURE;
 	g_free (file);
+	if (strcmp (export, expected))
+		return EXIT_FAILURE;
+
 	g_free (export);
 	g_free (expected);
 	g_object_unref (city_model);
@@ -122,57 +95,8 @@ test1 (void)
 	g_object_unref (cnc);
 	g_object_unref (provider);
 
-	g_print ("%s() is %s\n", __FUNCTION__, retval ? "Ok" : "NOT Ok");
-	return retval;
-}
-
-static gboolean
-test2 (void)
-{
-	GError *error = NULL;	
-	GdaConnection *cnc;
-	GdaVirtualProvider *provider;
-	gchar *file;
-	gboolean retval = FALSE;
-
-	g_print ("===== %s () =====\n", __FUNCTION__);
-	provider = gda_vprovider_data_model_new ();
-	cnc = gda_virtual_connection_open (provider, NULL);
-	g_assert (cnc);
-
-	/* load CSV data models */
-	GdaDataModel *country_model, *city_model;
-	GdaSet *options = gda_set_new_inline (1, "TITLE_AS_FIRST_LINE", G_TYPE_BOOLEAN, TRUE);
-	file = g_build_filename (CHECK_FILES, "tests", "data-models", "city.csv", NULL);
-	city_model = gda_data_model_import_new_file (file, TRUE, options);
-	g_free (file);
-	file = g_build_filename (CHECK_FILES, "tests", "data-models", "country.csv", NULL);
-	country_model = gda_data_model_import_new_file (file, TRUE, options);
-	g_free (file);
-	g_object_unref (options);
-
-	/* Add data models to connection */
-	if (!gda_vconnection_data_model_add_model (GDA_VCONNECTION_DATA_MODEL (cnc), city_model, "city", &error)) 
-		g_error ("Add city model error: %s\n", error && error->message ? error->message : "no detail");
-	if (!gda_vconnection_data_model_add_model (GDA_VCONNECTION_DATA_MODEL (cnc), country_model, "country", &error)) 
-		g_error ("Add country model error: %s\n", error && error->message ? error->message : "no detail");
-
-	/* test */
-	GdaDataModel *model;
-	model = run_sql_select (cnc, "SELECT c.*, o.name FROM city c INNER JOIN country o ON (c.countrycode = o.code)");
-	gda_data_model_dump (model, stdout);
-	g_object_unref (model);
-
-	retval = TRUE;
- out:
-
-	g_object_unref (city_model);
-	g_object_unref (country_model);
-	g_object_unref (cnc);
-	g_object_unref (provider);
-
-	g_print ("%s() is %s\n", __FUNCTION__, retval ? "Ok" : "NOT Ok");
-	return retval;
+	g_print ("Ok.\n");
+	return EXIT_SUCCESS;
 }
 
 static GdaDataModel *
@@ -187,7 +111,6 @@ run_sql_select (GdaConnection *cnc, const gchar *sql)
 	stmt = gda_sql_parser_parse_string (parser, sql, NULL, NULL);
 	g_object_unref (parser);
 
-	g_print ("EXECUTING [%s]\n", sql);
         res = gda_connection_statement_execute_select (cnc, stmt, NULL, &error);
         g_object_unref (stmt);
 	if (!res) 
@@ -209,7 +132,6 @@ run_sql_non_select (GdaConnection *cnc, const gchar *sql)
         stmt = gda_sql_parser_parse_string (parser, sql, NULL, NULL);
         g_object_unref (parser);
 
-	g_print ("EXECUTING [%s]\n", sql);
         nrows = gda_connection_statement_execute_non_select (cnc, stmt, NULL, NULL, &error);
         g_object_unref (stmt);
         if (nrows == -1) {
