@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2009 - 2012 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2009 - 2011 Vivien Malerba <malerba@gnome-db.org>
  * Copyright (C) 2010 David King <davidk@openismus.com>
  *
  * This program is free software; you can redistribute it and/or
@@ -22,7 +22,6 @@
 #include "browser-virtual-connection.h"
 #include "browser-connection-priv.h"
 #include <virtual/libgda-virtual.h>
-#include "../tool-utils.h"
 
 /* 
  * Main static functions 
@@ -60,7 +59,7 @@ browser_virtual_connection_get_type (void)
 	static GType type = 0;
 
 	if (G_UNLIKELY (type == 0)) {
-		static GMutex registering;
+		static GStaticMutex registering = G_STATIC_MUTEX_INIT;
 		static const GTypeInfo info = {
 			sizeof (BrowserVirtualConnectionClass),
 			(GBaseInitFunc) NULL,
@@ -74,10 +73,10 @@ browser_virtual_connection_get_type (void)
 			0
 		};
 
-		g_mutex_lock (&registering);
+		g_static_mutex_lock (&registering);
 		if (type == 0)
 			type = g_type_register_static (BROWSER_TYPE_CONNECTION, "BrowserVirtualConnection", &info, 0);
-		g_mutex_unlock (&registering);
+		g_static_mutex_unlock (&registering);
 	}
 	return type;
 }
@@ -314,10 +313,9 @@ sub_thread_open_cnc (BrowserVirtualConnectionSpecs *specs, GError **error)
 	}
 	
 	return virtual;
-#else /* DUMMY defined */
+#else
         sleep (5);
-        g_set_error (error, GDA_TOOLS_ERROR, TOOLS_INTERNAL_COMMAND_ERROR,
-		     "%s", "Timeout!!!");
+        g_set_error (error, 0, 0, "%s", "Timeout!!!");
         return NULL;
 #endif
 }
