@@ -318,7 +318,7 @@ cloud_object_selected_cb (G_GNUC_UNUSED ObjectsCloud *ocloud, G_GNUC_UNUSED Obje
 
 /**
  * browser_canvas_db_relations_new
- * @mstruct: a #GdaMetaStruct object, or %NULL
+ * @mstruct: (allow-none): a #GdaMetaStruct object, or %NULL
  *
  * Creates a new canvas widget to display the relations between the database's tables.
  *
@@ -402,7 +402,7 @@ canvas_entity_popup_func (BrowserCanvasTable *ce)
 }
 
 static void
-popup_func_declare_fk_cb (GtkMenuItem *mitem, BrowserCanvasTable *ce)
+popup_func_declare_fk_cb (G_GNUC_UNUSED GtkMenuItem *mitem, BrowserCanvasTable *ce)
 {
 	GtkWidget *dlg, *parent;
 	GdaMetaStruct *mstruct;
@@ -497,12 +497,11 @@ popup_func_add_depend_cb (G_GNUC_UNUSED GtkMenuItem *mitem, BrowserCanvasTable *
 		if (g_hash_table_lookup (dbrel->priv->hash_tables, fk->depend_on))
 			continue;
 
-		BrowserCanvasTable *new_item;
 		GValue *v1, *v2, *v3;
 		g_value_set_string ((v1 = gda_value_new (G_TYPE_STRING)), fk->depend_on->obj_catalog);
 		g_value_set_string ((v2 = gda_value_new (G_TYPE_STRING)), fk->depend_on->obj_schema);
 		g_value_set_string ((v3 = gda_value_new (G_TYPE_STRING)), fk->depend_on->obj_name);
-		new_item = browser_canvas_db_relations_add_table (dbrel, v1, v2, v3);
+		browser_canvas_db_relations_add_table (dbrel, v1, v2, v3);
 		gda_value_free (v1);
 		gda_value_free (v2);
 		gda_value_free (v3);
@@ -538,12 +537,12 @@ popup_func_add_ref_cb (G_GNUC_UNUSED GtkMenuItem *mitem, BrowserCanvasTable *ce)
 				continue;
 			if (g_hash_table_lookup (dbrel->priv->hash_tables, fkdbo))
 				continue;
-			BrowserCanvasTable *new_item;
+
 			GValue *v1, *v2, *v3;
 			g_value_set_string ((v1 = gda_value_new (G_TYPE_STRING)), fkdbo->obj_catalog);
 			g_value_set_string ((v2 = gda_value_new (G_TYPE_STRING)), fkdbo->obj_schema);
 			g_value_set_string ((v3 = gda_value_new (G_TYPE_STRING)), fkdbo->obj_name);
-			new_item = browser_canvas_db_relations_add_table (dbrel, v1, v2, v3);
+			browser_canvas_db_relations_add_table (dbrel, v1, v2, v3);
 			gda_value_free (v1);
 			gda_value_free (v2);
 			gda_value_free (v3);
@@ -837,7 +836,7 @@ popup_add_table_cb (G_GNUC_UNUSED GtkMenuItem *mitem, BrowserCanvasDbRelations *
 		
 		g_object_set_data (G_OBJECT (dbrels->priv->add_dialog), "__canvas", dbrels);
 
-		vbox = gtk_vbox_new (FALSE, 0);
+		vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
 		dcontents = gtk_dialog_get_content_area (GTK_DIALOG (dbrels->priv->add_dialog));
 		gtk_container_add (GTK_CONTAINER (dcontents), vbox);
 		
@@ -878,8 +877,8 @@ browser_canvas_db_relations_get_table_item  (BrowserCanvasDbRelations *canvas, G
 /**
  * browser_canvas_db_relations_add_table
  * @canvas: a #BrowserCanvasDbRelations canvas
- * @table_catalog: the catalog in which the table is, or %NULL
- * @table_schema: the schema in which the table is, or %NULL
+ * @table_catalog: (allow-none): the catalog in which the table is, or %NULL
+ * @table_schema: (allow-none): the schema in which the table is, or %NULL
  * @table_name: the table's name
  *
  * Add a table to @canvas.
