@@ -1,7 +1,6 @@
 /*
  * Copyright (C) 2009 - 2011 Vivien Malerba <malerba@gnome-db.org>
  * Copyright (C) 2010 David King <davidk@openismus.com>
- * Copyright (C) 2011 Murray Cumming <murrayc@murrayc.com>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -212,7 +211,7 @@ gdaui_data_import_init (GdauiDataImport * import)
 	g_signal_connect (G_OBJECT (entry), "toggled",
 			  G_CALLBACK (spec_changed_cb), import);
 
-	entry = gtk_radio_button_new_with_label_from_widget (GTK_RADIO_BUTTON (entry), _("Semi colon"));
+	entry = gtk_radio_button_new_with_label_from_widget (GTK_RADIO_BUTTON (entry), _("Semi column"));
 	import->priv->sep_array [SEP_SEMICOL] = entry;
 	gtk_table_attach (GTK_TABLE (table), entry, 2, 3, 3, 4, GTK_FILL, 0, 0, 0);
 	g_object_set_data (G_OBJECT (entry), "_sep", ";");
