@@ -1,6 +1,5 @@
 /*
- * Copyright (C) 2011 Murray Cumming <murrayc@murrayc.com>
- * Copyright (C) 2011 - 2012 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2011 Vivien Malerba <malerba@gnome-db.org>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -27,7 +26,7 @@
 #include "../dnd.h"
 #include "../support.h"
 #include "marshal.h"
-#include "../gdaui-bar.h"
+#include "../cc-gray-bar.h"
 #include <gdk/gdkkeysyms.h>
 #include <libgda-ui/internal/popup-container.h>
 
@@ -475,9 +474,9 @@ ldap_favorite_selector_new (BrowserConnection *bcnc)
 	GtkWidget *label;
 	gchar *str;
 	str = g_strdup_printf ("<b>%s</b>", _("Favorites"));
-	label = gdaui_bar_new (str);
+	label = cc_gray_bar_new (str);
 	g_free (str);
-	gdaui_bar_set_icon_from_pixbuf (GDAUI_BAR (label), browser_get_pixbuf_icon (BROWSER_ICON_BOOKMARK));
+	cc_gray_bar_set_icon_from_pixbuf (CC_GRAY_BAR (label), browser_get_pixbuf_icon (BROWSER_ICON_BOOKMARK));
         gtk_box_pack_start (GTK_BOX (fsel), label, FALSE, FALSE, 0);
         gtk_widget_show (label);
 
