@@ -1,5 +1,4 @@
 /*
- * Copyright (C) 2011 Murray Cumming <murrayc@murrayc.com>
  * Copyright (C) 2011 Vivien Malerba <malerba@gnome-db.org>
  *
  * This program is free software; you can redistribute it and/or
@@ -21,7 +20,7 @@
 #include <string.h>
 #include "ldap-search-page.h"
 #include "filter-editor.h"
-#include "../gdaui-bar.h"
+#include "../cc-gray-bar.h"
 #include "../browser-page.h"
 #include "../browser-window.h"
 #include "../browser-connection.h"
@@ -285,7 +284,7 @@ ldap_search_page_new (BrowserConnection *bcnc, const gchar *base_dn)
 	gchar *str;
 
 	str = g_strdup_printf ("<b>%s</b>", _("LDAP search page"));
-	label = gdaui_bar_new (str);
+	label = cc_gray_bar_new (str);
 	g_free (str);
         gtk_box_pack_start (GTK_BOX (epage), label, FALSE, FALSE, 0);
         gtk_widget_show (label);
