@@ -1,7 +1,6 @@
 /*
- * Copyright (C) 2009 - 2012 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2009 - 2011 Vivien Malerba <malerba@gnome-db.org>
  * Copyright (C) 2010 David King <davidk@openismus.com>
- * Copyright (C) 2011 Murray Cumming <murrayc@murrayc.com>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -23,7 +22,7 @@
 #include "query-console-page.h"
 #include "../dnd.h"
 #include "../support.h"
-#include "../gdaui-bar.h"
+#include "../cc-gray-bar.h"
 #include "query-exec-perspective.h"
 #include "../browser-window.h"
 #include "../browser-page.h"
@@ -97,7 +96,7 @@ struct _QueryConsolePagePrivate {
 
 	GtkActionGroup *agroup;
 
-	GdauiBar *header;
+	CcGrayBar *header;
 	GtkWidget *vpaned; /* top=>query editor, bottom=>results */
 
 	QueryEditor *editor;
@@ -289,11 +288,11 @@ query_console_page_new (BrowserConnection *bcnc)
         GtkWidget *label;
 	gchar *str;
 	str = g_strdup_printf ("<b>%s</b>", _("Query editor"));
-	label = gdaui_bar_new (str);
+	label = cc_gray_bar_new (str);
 	g_free (str);
         gtk_box_pack_start (GTK_BOX (tconsole), label, FALSE, FALSE, 0);
         gtk_widget_show (label);
-	tconsole->priv->header = GDAUI_BAR (label);
+	tconsole->priv->header = CC_GRAY_BAR (label);
 
 	/* main contents */
 	GtkWidget *vpaned;
@@ -346,7 +345,6 @@ query_console_page_new (BrowserConnection *bcnc)
 	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (sw),
 					GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
 	tconsole->priv->params_form_box = gtk_viewport_new (NULL, NULL);
-	gtk_widget_set_name (tconsole->priv->params_form_box, "gdaui-transparent-background");
 	gtk_viewport_set_shadow_type (GTK_VIEWPORT (tconsole->priv->params_form_box), GTK_SHADOW_NONE);
 	gtk_container_add (GTK_CONTAINER (sw), tconsole->priv->params_form_box);
 	gtk_box_pack_start (GTK_BOX (vbox), sw, TRUE, TRUE, 0);
@@ -715,7 +713,7 @@ sql_favorite_clicked_cb (G_GNUC_UNUSED GtkButton *button, QueryConsolePage *tcon
 	bfav = browser_connection_get_favorites (tconsole->priv->bcnc);
 	if (tconsole->priv->fav_id >= 0) {
 		ToolsFavoritesAttributes fav;
-		if (gda_tools_favorites_get (bfav, tconsole->priv->fav_id, &fav, NULL)) {
+		if (tools_favorites_get (bfav, tconsole->priv->fav_id, &fav, NULL)) {
 			gchar *str;
 			str = g_strdup_printf (_("Modify favorite '%s'"), fav.name);
 			mitem = gtk_menu_item_new_with_label (str);
@@ -728,12 +726,12 @@ sql_favorite_clicked_cb (G_GNUC_UNUSED GtkButton *button, QueryConsolePage *tcon
 					   GINT_TO_POINTER (tconsole->priv->fav_id));
 			gtk_widget_show (mitem);
 			gtk_menu_shell_append (GTK_MENU_SHELL (menu), mitem);
-			gda_tools_favorites_reset_attributes (&fav);
+			tools_favorites_reset_attributes (&fav);
 		}
 	}
 
 	GSList *allfav;
-	allfav = gda_tools_favorites_list (bfav, 0, GDA_TOOLS_FAVORITES_QUERIES, ORDER_KEY_QUERIES, NULL);
+	allfav = tools_favorites_list (bfav, 0, TOOLS_FAVORITES_QUERIES, ORDER_KEY_QUERIES, NULL);
 	if (allfav) {
 		GtkWidget *submenu;
 		GSList *list;
@@ -762,7 +760,7 @@ sql_favorite_clicked_cb (G_GNUC_UNUSED GtkButton *button, QueryConsolePage *tcon
 			gtk_widget_show (mitem);
 			gtk_menu_shell_append (GTK_MENU_SHELL (submenu), mitem);
 		}
-		gda_tools_favorites_free_list (allfav);
+		tools_favorites_free_list (allfav);
 	}
 
 	gtk_menu_popup (GTK_MENU (menu), NULL, NULL,
@@ -773,7 +771,7 @@ sql_favorite_clicked_cb (G_GNUC_UNUSED GtkButton *button, QueryConsolePage *tcon
 static void
 fav_form_name_activated_cb (G_GNUC_UNUSED GtkWidget *form, GtkWidget *dlg)
 {
-	gtk_dialog_response (GTK_DIALOG (dlg), GTK_RESPONSE_ACCEPT);
+	gtk_dialog_response (dlg, GTK_RESPONSE_ACCEPT);
 }
 
 static void
@@ -805,14 +803,14 @@ sql_favorite_new_mitem_cb (G_GNUC_UNUSED GtkMenuItem *mitem, QueryConsolePage *t
 
 	memset (&fav, 0, sizeof (fav));
 	fav.id = -1;
-	fav.type = GDA_TOOLS_FAVORITES_QUERIES;
+	fav.type = TOOLS_FAVORITES_QUERIES;
 	fav.contents = query_editor_get_all_text (tconsole->priv->editor);
 	cvalue = gda_set_get_holder_value (set, _("Favorite's name"));
 	fav.name = (gchar*) g_value_get_string (cvalue);
 
 	bfav = browser_connection_get_favorites (tconsole->priv->bcnc);
 
-	if (! gda_tools_favorites_add (bfav, 0, &fav, ORDER_KEY_QUERIES, G_MAXINT, &error)) {
+	if (! tools_favorites_add (bfav, 0, &fav, ORDER_KEY_QUERIES, G_MAXINT, &error)) {
 		browser_show_error ((GtkWindow*) gtk_widget_get_toplevel ((GtkWidget*) tconsole),
                                     _("Could not add favorite: %s"),
                                     error && error->message ? error->message : _("No detail"));
@@ -836,13 +834,13 @@ sql_favorite_modify_mitem_cb (G_GNUC_UNUSED GtkMenuItem *mitem, QueryConsolePage
 
 	memset (&fav, 0, sizeof (fav));
 	fav.id = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (mitem), "favid"));
-	fav.type = GDA_TOOLS_FAVORITES_QUERIES;
+	fav.type = TOOLS_FAVORITES_QUERIES;
 	fav.contents = query_editor_get_all_text (tconsole->priv->editor);
 	fav.name = g_object_get_data (G_OBJECT (mitem), "favname");
 
 	bfav = browser_connection_get_favorites (tconsole->priv->bcnc);
 
-	if (! gda_tools_favorites_add (bfav, 0, &fav, ORDER_KEY_QUERIES, G_MAXINT, &error)) {
+	if (! tools_favorites_add (bfav, 0, &fav, ORDER_KEY_QUERIES, G_MAXINT, &error)) {
 		browser_show_error ((GtkWindow*) gtk_widget_get_toplevel ((GtkWidget*) tconsole),
                                     _("Could not add favorite: %s"),
                                     error && error->message ? error->message : _("No detail"));
@@ -861,8 +859,7 @@ popup_container_position_func (PopupContainer *cont, gint *out_x, gint *out_y)
 
 	console = g_object_get_data (G_OBJECT (cont), "console");
 	top = gtk_widget_get_toplevel (console);	
-	gtk_widget_get_preferred_size ((GtkWidget*) cont, NULL, &req);
-
+        gtk_widget_size_request ((GtkWidget*) cont, &req);
 	GtkAllocation alloc;
         gdk_window_get_origin (gtk_widget_get_window (top), &x, &y);
 	gtk_widget_get_allocation (top, &alloc);
