@@ -35,15 +35,15 @@ typedef struct _FavoriteSelectorClass   FavoriteSelectorClass;
 typedef struct _FavoriteSelectorPrivate FavoriteSelectorPrivate;
 
 struct _FavoriteSelector {
-	GtkVBox               parent;
+	GtkBox               parent;
 	FavoriteSelectorPrivate *priv;
 };
 
 struct _FavoriteSelectorClass {
-	GtkVBoxClass          parent_class;
+	GtkBoxClass          parent_class;
 
 	void                (*selection_changed) (FavoriteSelector *sel, gint fav_id,
-						  BrowserFavoritesType fav_type, const gchar *fav_contents);
+						  ToolsFavoritesType fav_type, const gchar *fav_contents);
 };
 
 GType                    favorite_selector_get_type (void) G_GNUC_CONST;
