@@ -1,7 +1,6 @@
 /*
- * Copyright (C) 2009 - 2012 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2009 - 2011 Vivien Malerba <malerba@gnome-db.org>
  * Copyright (C) 2010 David King <davidk@openismus.com>
- * Copyright (C) 2011 Murray Cumming <murrayc@murrayc.com>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -23,7 +22,7 @@
 #include "table-info.h"
 #include "../dnd.h"
 #include "../support.h"
-#include "../gdaui-bar.h"
+#include "../cc-gray-bar.h"
 #include "table-columns.h"
 #include "table-preferences.h"
 #ifdef HAVE_GOOCANVAS
@@ -47,7 +46,7 @@ struct _TableInfoPrivate {
 	gchar *table_name;
 	gchar *table_short_name;
 
-	GdauiBar *header;
+	CcGrayBar *header;
 	GtkWidget *contents; /* notebook with pageO <=> @unknown_table_notice, page1 <=> @pages */
 	GtkWidget *unknown_table_notice;
 	GtkWidget *pages; /* notebook to store individual pages */
@@ -332,11 +331,11 @@ table_info_new (BrowserConnection *bcnc,
 	tmp = g_strdup_printf (_("In schema '%s'"), schema);
 	str = g_strdup_printf ("<b>%s</b>\n%s", table, tmp);
 	g_free (tmp);
-	label = gdaui_bar_new (str);
+	label = cc_gray_bar_new (str);
 	g_free (str);
         gtk_box_pack_start (GTK_BOX (tinfo), label, FALSE, FALSE, 0);
         gtk_widget_show (label);
-	tinfo->priv->header = GDAUI_BAR (label);
+	tinfo->priv->header = CC_GRAY_BAR (label);
 
 	/* main contents */
 	GtkWidget *top_nb;
@@ -457,13 +456,13 @@ action_add_to_fav_cb (G_GNUC_UNUSED GtkAction *action, TableInfo *tinfo)
 
         memset (&fav, 0, sizeof (ToolsFavoritesAttributes));
         fav.id = -1;
-        fav.type = GDA_TOOLS_FAVORITES_TABLES;
+        fav.type = TOOLS_FAVORITES_TABLES;
         fav.name = NULL;
         fav.descr = NULL;
         fav.contents = table_info_to_selection (tinfo);
 
         bfav = browser_connection_get_favorites (tinfo->priv->bcnc);
-        if (! gda_tools_favorites_add (bfav, 0, &fav, ORDER_KEY_SCHEMA, G_MAXINT, &error)) {
+        if (! tools_favorites_add (bfav, 0, &fav, ORDER_KEY_SCHEMA, G_MAXINT, &error)) {
                 browser_show_error ((GtkWindow*) gtk_widget_get_toplevel ((GtkWidget*) tinfo),
                                     _("Could not add favorite: %s"),
                                     error && error->message ? error->message : _("No detail"));
