@@ -1,23 +1,20 @@
-/* 
- * Copyright (C) 2009 - 2011 The GNOME Foundation.
+/*
+ * Copyright (C) 2009 - 2011 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2010 David King <davidk@openismus.com>
  *
- * AUTHORS:
- *      Vivien Malerba <malerba@gnome-db.org>
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
  *
- * This Program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of the
- * License, or (at your option) any later version.
- *
- * This Library is distributed in the hope that it will be useful,
+ * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
  *
- * You should have received a copy of the GNU Library General Public
- * License along with this Library; see the file COPYING.LIB.  If not,
- * write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
 #include <glib/gi18n-lib.h>
@@ -59,6 +56,7 @@ browser_connection_open (GError **error)
 		browser_core_take_window (nbwin);
 		browser_core_take_connection (bcnc);
 	}
+	gtk_widget_destroy (GTK_WIDGET (dialog));
 	return bcnc;
 }
 
@@ -204,7 +202,7 @@ browser_show_message (GtkWindow *parent, const gchar *format, ...)
 #ifdef HAVE_GDU
 /**
  * browser_show_help
- * @topic: the help topic, or %NULL for the global index
+ * @topic: (allow-none): the help topic, or %NULL for the global index
  */
 void
 browser_show_help (GtkWindow *parent, const gchar *topic)
@@ -286,24 +284,21 @@ _browser_make_tab_label (const gchar *label,
 			 GtkWidget **out_close_button)
 {
         GtkWidget  *hbox, *wid, *close_button, *image = NULL;
-	static gboolean rc_done = FALSE;
+	static GtkCssProvider *css_provider = NULL;
+
+	if (!css_provider) {
+		css_provider = gtk_css_provider_new ();
+		gtk_css_provider_load_from_data (css_provider,
+						 "* {\n"
+						 "-GtkWidget-focus-padding : 0;\n"
+						 "-GtkWidget-focus-line-width : 0}",
+						 -1, NULL);
+	}
 
 	if (out_close_button)
 		*out_close_button = NULL;
 
-	if (!rc_done) {
-		rc_done = TRUE;
-		gtk_rc_parse_string ("style \"browser-tab-close-button-style\"\n"
-				     "{\n"
-				     "GtkWidget::focus-padding = 0\n"
-				     "GtkWidget::focus-line-width = 0\n"
-				     "xthickness = 0\n"
-				     "ythickness = 0\n"
-				     "}\n"
-				     "widget \"*.browser-tab-close-button\" style \"browser-tab-close-button-style\"");
-	}
-
-        hbox = gtk_hbox_new (FALSE, 4);
+        hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
 
 	if (img)
 		gtk_box_pack_start (GTK_BOX (hbox), img, FALSE, FALSE, 0);
@@ -319,7 +314,9 @@ _browser_make_tab_label (const gchar *label,
 		close_button = gtk_button_new ();
 		gtk_button_set_relief (GTK_BUTTON (close_button), GTK_RELIEF_NONE);
 		gtk_button_set_focus_on_click (GTK_BUTTON (close_button), FALSE);
-		gtk_widget_set_name (close_button, "browser-tab-close-button");
+		gtk_style_context_add_provider (gtk_widget_get_style_context ((GtkWidget*) close_button),
+						GTK_STYLE_PROVIDER (css_provider),
+						GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
 
 		gtk_widget_set_tooltip_text (close_button, _("Close tab"));
 		
@@ -384,8 +381,6 @@ browser_get_pixbuf_icon (BrowserIconType type)
 		"gda-browser-diagram.png",
 		"gda-browser-query.png",
 		"gda-browser-action.png",
-		"gda-browser-grid.png",
-		"gda-browser-form.png",
 		"gda-browser-menu-ind.png",
 		"gda-browser-ldap-entry.png",
 		"gda-browser-ldap-group.png",
@@ -563,7 +558,7 @@ browser_make_small_button (gboolean is_toggle, gboolean with_arrow,
 	else
 		button = gtk_button_new ();
 	if ((label && stock_id) || with_arrow) {
-		hbox = gtk_hbox_new (FALSE, 0);
+		hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
 		gtk_container_add (GTK_CONTAINER (button), hbox);
 		gtk_widget_show (hbox);
 	}
