@@ -21,6 +21,7 @@
 
 #undef GDA_DISABLE_DEPRECATED
 #include "command-exec.h"
+#include <libgda/binreloc/gda-binreloc.h>
 #include <glib/gi18n-lib.h>
 #include <string.h>
 #include "tools-input.h"
@@ -251,46 +252,359 @@ default_gda_internal_commandargs_func (const gchar *string)
 	return array;
 }
 
+/*
+ * Same as append_to_string but cuts strings which are too long
+ */
+static void
+append_raw_to_string (GString *string, gchar *str, gint width, gint offset)
+{
+	g_assert (string);
+	if (!str)
+		return;
+	if ((width <= 0) && (offset <= 0)) {
+		g_string_append (string, str);
+		return;
+	}
+	if (offset < 0)
+		offset = 0;
+
+	/* start on a fresh line */
+	if ((string->str) && (string->len > 0) &&
+	    (string->str[string->len - 1] != '\n'))
+		g_string_append_c (string, '\n');
+
+	gchar *ptr;
+	gboolean startofline = TRUE;
+	for (ptr = str; *ptr; ) {
+		gchar *next, *pnext;
+		if (*ptr == '\n') {
+			g_string_append_c (string, '\n');
+			ptr++;
+			startofline = TRUE;
+			continue;
+		}
+		guint clen = 0;
+		for (next = ptr, pnext = ptr;
+		     *next && (*next != '\n');
+		     pnext = next + 1, next = g_utf8_next_char (next), clen++) {
+			if (startofline) {
+				if (offset > 0) {
+					gint i;
+					for (i = 0; i < offset; i++)
+						g_string_append_c (string, ' ');
+				}
+				startofline = FALSE;
+			}
+
+			if ((width > 0) && (clen >= width - offset)) {
+				g_string_append_c (string, '\n');
+				startofline = TRUE;
+				for (; *next && (*next != '\n'); next++);
+				if (*next == '\n')
+					next++;
+				break;
+			}
+			else {
+				for (; pnext <= next; pnext++)
+					g_string_append_c (string, *pnext);
+			}
+		}
+		ptr = next;
+	}
+}
+
+/*
+ * parses @str, and appends to @string lines which are @width large, if @offset is >0, then
+ * leave that amount of spaces. If @width <= 0, then only adds @offset spaces at the beginning of each
+ * new line.
+ */
+static void
+append_to_string (GString *string, gchar *str, gint width, gint offset)
+{
+	g_assert (string);
+	if (!str)
+		return;
+	if ((width <= 0) && (offset <= 0)) {
+		g_string_append (string, str);
+		return;
+	}
+	if (offset < 0)
+		offset = 0;
+
+	/* replace @WORD@ by <WORD> */
+	gchar *ptr;
+	gboolean in = FALSE;
+	for (ptr = str; *ptr; ptr++) {
+		if (*ptr == '@') {
+			if (in) {
+				*ptr = '>';
+				in = FALSE;
+			}
+			else {
+				*ptr = '<';
+				in = TRUE;
+			}
+		}
+	}
+
+	/* actual work */
+	gboolean firstword = TRUE;
+	gint clen = 0;
+	if ((string->str) && (string->len > 0) &&
+	    (string->str[string->len - 1] != '\n')) {
+		for (ptr = string->str + (string->len -1); (ptr >= string->str) && (*ptr != '\n'); ptr --)
+			clen++;
+	}
+	for (ptr = str; *ptr; ) {
+		/* skip spaces */
+		if ((*ptr == ' ') || (*ptr == '\t') || (*ptr == '\n') || (*ptr == '\r')) {
+			ptr++;
+			continue;
+		}
+
+		/* find end of next word */
+		gchar *next;
+		gint wlen;
+		for (wlen = 0, next = ptr;
+		     *next && (*next != ' ') && (*next != '\t') && (*next != '\n') && (*next != '\r');
+		     wlen ++, next = g_utf8_next_char (next));
+
+		if (wlen >= width - offset) {
+			const gchar *n2;
+			for (n2 = ptr; n2 < next; n2++) {
+				g_string_append_c (string, *n2);
+			}
+			ptr = next;
+			firstword = FALSE;
+			g_string_append_c (string, '\n');
+			clen = 0;
+			continue;
+		}
+		else if ((width > 0) && ((wlen + clen) >= width)) {
+			/* cut here */
+			g_string_append_c (string, '\n');
+			clen = 0;
+			continue;
+		}
+		else {
+			/* copy word */
+			if (clen == 0) {
+				if (offset > 0) {
+					gint i;
+					for (i = 0; i < offset; i++) {
+						g_string_append_c (string, ' ');
+						clen++;
+					}
+				}
+			}
+			else if (!firstword) {
+				g_string_append_c (string, ' ');
+				clen++;
+			}
+			const gchar *n2;
+			for (n2 = ptr; n2 < next; n2++) {
+				g_string_append_c (string, *n2);
+				clen++;
+			}
+			ptr = next;
+			firstword = FALSE;
+		}
+	}
+}
+
+static gchar *
+help_xml_doc_to_string (xmlDocPtr helpdoc, const gchar *command_name, gint width)
+{
+	xmlNodePtr node;
+	node = xmlDocGetRootElement (helpdoc);
+	if (!node)
+		return NULL;
+	for (node = node->children; node; node = node->next) {
+		if (strcmp ((gchar*) node->name, "command"))
+			continue;
+		xmlChar *prop;
+		prop = xmlGetProp (node, BAD_CAST "name");
+		if (prop && !strcmp ((gchar*) prop, command_name))
+			break;
+	}
+	if (!node)
+		return NULL;
+
+	/* create output string */
+	GString *string;
+	string = g_string_new ("");
+	for (node = node->children; node; node = node->next) {
+		xmlChar *data = NULL;
+		if (!strcmp ((gchar*) node->name, "shortdescription")) {
+			data = xmlNodeGetContent (node);
+			if (data) {
+				append_to_string (string, (gchar*) data, width, 0);
+				g_string_append (string, "\n\n");
+			}
+		}
+		else if (!strcmp ((gchar*) node->name, "usage") || !strcmp ((gchar*) node->name, "example")) {
+			if (!strcmp ((gchar*) node->name, "usage"))
+				append_to_string (string, _("Usage"), width, 0);
+			else
+				append_to_string (string, _("Example"), width, 0);
+			g_string_append (string, ":\n");
+			xmlNodePtr snode;
+			for (snode = node->children; snode; snode = snode->next) {
+				if (!strcmp ((gchar*) snode->name, "synopsis")) {
+					data = xmlNodeGetContent (snode);
+					if (data) {
+						append_to_string (string, "> ", width, 3);
+						append_to_string (string, (gchar*) data, width, 3);
+						g_string_append_c (string, '\n');
+					}
+				}
+				else if (!strcmp ((gchar*) snode->name, "comment")) {
+					data = xmlNodeGetContent (snode);
+					if (data) {
+						append_to_string (string, (gchar*) data, width, 6);
+						g_string_append_c (string, '\n');
+					}
+				}
+				else if (!strcmp ((gchar*) snode->name, "raw")) {
+					data = xmlNodeGetContent (snode);
+					if (data) {
+						append_raw_to_string (string, (gchar*) data, width, 6);
+						g_string_append (string, "\n\n");
+					}
+				}
+				if (data)
+					xmlFree (data);
+				data = NULL;
+			}
+		}
+		if (data)
+			xmlFree (data);
+	}
+
+	return g_string_free (string, FALSE);
+}
+
 GdaInternalCommandResult *
 gda_internal_command_help (SqlConsole *console, G_GNUC_UNUSED GdaConnection *cnc,
-			   G_GNUC_UNUSED const gchar **args, G_GNUC_UNUSED GError **error,
+			   const gchar **args, G_GNUC_UNUSED GError **error,
 			   GdaInternalCommandsList *clist)
 {
 	GdaInternalCommandResult *res;
 	GSList *list;
 	gchar *current_group = NULL;
 	GString *string = g_string_new ("");
+	xmlDocPtr helpdoc = NULL;
 #define NAMESIZE 18
 
+	/* get term size */
+	gint width;
+	input_get_size (&width, NULL);
+
 	res = g_new0 (GdaInternalCommandResult, 1);
 	res->type = GDA_INTERNAL_COMMAND_RESULT_TXT;
 
-	for (list = clist->group_ordered; list; list = list->next) {
-		GdaInternalCommand *command = (GdaInternalCommand*) list->data;
-
-		if (console && command->limit_to_main)
-			continue;
-
-		if (!current_group || strcmp (current_group, command->group)) {
-			current_group = command->group;
-			if (list != clist->group_ordered)
-				g_string_append_c (string, '\n');
-			g_string_append_printf (string, "%s\n", current_group);
-			
-		}
-		g_string_append_printf (string, "  \\%s", command->name);
-		if (strlen (command->name) < NAMESIZE) {
-			gint i;
-			for (i = strlen (command->name); i < NAMESIZE; i++)
-				g_string_append_c (string, ' ');
+	if (args[0] && *args[0]) {
+		const gchar *command_name = NULL;
+		GdaInternalCommand *command = NULL;
+		command_name = args[0];
+		for (list = clist->group_ordered; list; list = list->next) {
+			command = (GdaInternalCommand*) list->data;
+			gint clength;
+			clength = strlen (command_name);
+			if (!g_ascii_strncasecmp (command->name, command_name, clength) &&
+			    (command->name[clength] == ' '))
+				break;
+			command = NULL;
 		}
+		if (!command)
+			g_string_append_printf (string, _("Command '%s' not found\n"), command_name);
 		else {
+			if (!helpdoc) {
+				const gchar * const *langs = g_get_language_names ();
+				gchar *dirname, *helpfile;
+				gint i;
+				dirname = gda_gbr_get_file_path (GDA_DATA_DIR, "gnome", "help",
+								 "gda-sql", NULL);
+				for (i = 0; langs[i]; i++) {
+					helpfile = g_build_filename (dirname, langs[i], "gda-sql-help.xml", NULL);
+					if (g_file_test (helpfile, G_FILE_TEST_EXISTS))
+						helpdoc = xmlParseFile (helpfile);
+					g_free (helpfile);
+					if (helpdoc)
+						break;
+				}
+
+				if (!helpdoc) {
+					/* default to the "C" one */
+					helpfile = g_build_filename (dirname, "C", "gda-sql-help.xml", NULL);
+					if (g_file_test (helpfile, G_FILE_TEST_EXISTS))
+						helpdoc = xmlParseFile (helpfile);
+					g_free (helpfile);
+				}
+				g_free (dirname);
+			}
+			gboolean done = FALSE;
+			if (helpdoc) {
+				gchar *tmp;
+				tmp = help_xml_doc_to_string (helpdoc, command_name, width);
+				if (tmp) {
+					g_string_append (string, tmp);
+					g_free (tmp);
+					done = TRUE;
+				}
+			}
+			if (!done) {
+				append_to_string (string, command->description, width, 0);
+				g_string_append_printf (string, "\n\n%s:\n   .", _("Usage"));
+				append_to_string (string, command->name, width, 0);
+			}
+		}
+	}
+	else {
+		for (list = clist->group_ordered; list; list = list->next) {
+			GdaInternalCommand *command = (GdaInternalCommand*) list->data;
+			gint clen;
+			if (console && command->limit_to_main)
+				continue;
+
+			if (!current_group || strcmp (current_group, command->group)) {
+				current_group = command->group;
+				if (list != clist->group_ordered)
+					g_string_append_c (string, '\n');
+				if (width > 0) {
+					gint i, nb, remain;
+					nb = (width - g_utf8_strlen (current_group, -1) - 2) / 2;
+					remain = width - (2 * nb + 2 + g_utf8_strlen (current_group, -1));
+					for (i = 0; i < nb; i++)
+						g_string_append_c (string, '=');
+					g_string_append_c (string, ' ');
+					append_to_string (string, current_group, width, 0);
+					g_string_append_c (string, ' ');
+					for (i = 0; i < nb + remain; i++)
+						g_string_append_c (string, '=');
+					g_string_append_c (string, '\n');
+				}
+				else {
+					g_string_append (string, "=== ");
+					append_to_string (string, current_group, width, 0);
+					g_string_append (string, " ===\n");
+				}
+			}
+
+			g_string_append (string, "   .");
+			append_to_string (string, command->name, width, 3);
+			clen = g_utf8_strlen (command->name, -1);
+			if (clen >= NAMESIZE)
+				g_string_append_c (string, '\n');
+			else {
+				gint i, size;
+				size = NAMESIZE - clen - 1;
+				for (i = 0; i < size; i++)
+					g_string_append_c (string, ' ');
+			}
+			append_to_string (string, command->description, width, NAMESIZE + 3);
 			g_string_append_c (string, '\n');
-			gint i;
-			for (i = 0; i < NAMESIZE + 3; i++)
-				g_string_append_c (string, ' ');
 		}
-		g_string_append_printf (string, "%s\n", command->description);
 	}
 	res->u.txt = string;
 	return res;
