@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2007 - 2012 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2007 - 2010 Vivien Malerba <malerba@gnome-db.org>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -53,7 +53,7 @@ typedef struct {
  * Command definition
  */
 typedef GdaInternalCommandResult *(*GdaInternalCommandFunc) (SqlConsole *, GdaConnection *cnc,
-							     const gchar **, OutputFormat, GError **, gpointer);
+							     const gchar **, GError **, gpointer);
 typedef gchar                   **(*GdaInternalCommandArgsFunc) (const gchar *);
 typedef struct {
 	gchar    *name;
@@ -62,8 +62,7 @@ typedef struct {
 
 typedef struct {
 	gchar                     *group;
-	gchar                     *group_id; /* to be found in the help file */
-	gchar                     *name; /* without the '\' or '.' */
+	gchar                     *name; /* without the '\' */
 	gchar                     *description;
 	GSList                    *args; /* list of GdaInternalCommandArgument structures */
 	GdaInternalCommandFunc     command_func;
@@ -89,19 +88,19 @@ void                      gda_internal_command_exec_result_free (GdaInternalComm
 
 /* Available commands */
 GdaInternalCommandResult *gda_internal_command_help (SqlConsole *console, GdaConnection *cnc, const gchar **args,
-						     OutputFormat format, GError **error, GdaInternalCommandsList *clist);
+						     GError **error, GdaInternalCommandsList *clist);
 GdaInternalCommandResult *gda_internal_command_history (SqlConsole *console, GdaConnection *cnc, const gchar **args,
-							OutputFormat format, GError **error, gpointer data);
+							GError **error, gpointer data);
 GdaInternalCommandResult *gda_internal_command_dict_sync (SqlConsole *console, GdaConnection *cnc, const gchar **args,
-							  OutputFormat format, GError **error, gpointer data);
+							  GError **error, gpointer data);
 GdaInternalCommandResult *gda_internal_command_list_tables (SqlConsole *console, GdaConnection *cnc, const gchar **args,
-							    OutputFormat format, GError **error, gpointer data);
+							    GError **error, gpointer data);
 GdaInternalCommandResult *gda_internal_command_list_views (SqlConsole *console, GdaConnection *cnc, const gchar **args,
-							   OutputFormat format, GError **error, gpointer data);
+							   GError **error, gpointer data);
 GdaInternalCommandResult *gda_internal_command_list_schemas (SqlConsole *console, GdaConnection *cnc, const gchar **args,
-							     OutputFormat format, GError **error, gpointer data);
+							     GError **error, gpointer data);
 GdaInternalCommandResult *gda_internal_command_detail (SqlConsole *console, GdaConnection *cnc, const gchar **args,
-						       OutputFormat format, GError **error, gpointer data);
+						       GError **error, gpointer data);
 
 /* Misc */
 GdaMetaStruct            *gda_internal_command_build_meta_struct (GdaConnection *cnc, const gchar **args, GError **error);
